<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Elementor\Base_Data_Control' ) ) return;

/**
 * A Font Icon select box.
 */
class thepack_elementor_xtra_icon extends Base_Data_Control {

	public static function get_icons() {
		$tb_fonts = cs_get_option('tb_fonts','',TBOPT);
		$icons = [];
		
        if (is_array($tb_fonts)){

            foreach ($tb_fonts as $name){
            	require AE_PLUGIN_DIR.'/admin/controls/'.$name.'.php';
            }

        }

		return $icons;
	}

	/**
	 * Retrieve icon control type.
	 */
	public function get_type() {
		return 'icon';
	}

	/**
	 * Retrieve icons control default settings.
	 */
	protected function get_default_settings() {
		return [
			'options' => self::get_icons(),
		];
	}

	/**
	 * Render icons control output in the editor.
	 */
	public function content_template() {
		$control_uid = $this->get_control_uid();
		?>
		<div class="elementor-control-field">
			<label for="<?php echo $control_uid; ?>" class="elementor-control-title">{{{ data.label }}}</label>
			<div class="elementor-control-input-wrapper">
				<select id="<?php echo $control_uid; ?>" class="elementor-control-icon" data-setting="{{ data.name }}" data-placeholder="<?php _e( 'Select Icon', 'elementor' ); ?>">
					<option value=""><?php _e( 'Select Icon', 'elementor' ); ?></option>
					<# _.each( data.options, function( option_title, option_value ) { #>
					<option value="{{ option_value }}">{{{ option_title }}}</option>
					<# } ); #>
				</select>
			</div>
		</div>
		<# if ( data.description ) { #>
		<div class="elementor-control-field-description">{{ data.description }}</div>
		<# } #>
		<?php
	}
}


add_action('elementor/controls/thepack_controls_registered', function($el) {
	$el->register_control('icon', new thepack_elementor_xtra_icon);
});