<?php

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;
use Elementor\Scheme_Typography;
use Elementor\Utils;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_button3 extends Widget_Base {

    public function get_name() {
        return 'tb_btn3';
    }

    public function get_title() {
        return   esc_html__('BUTTON 3', 'thepack');
    }

    public function get_icon() {
        return 'eicon-button';
    }
    
    public function get_categories() {
        return array('ashelement-addons');
    } 

    protected function _register_controls() {

        $this->start_controls_section(
            'section_heading',
            [
                'label' =>   esc_html__('Button', 'thepack'),
            ]
        );


        $this->add_control(
            'text',
            [
                'type' => 'text',
                'label' =>   esc_html__('Button label', 'thepack'),
                'label_block' => true,
                'default' =>   esc_html__('START NEW PROJECT', 'thepack'),
            ]
        );
        $this->add_control(
            'link',
            [
                'label' =>   esc_html__( 'Link', 'elementor' ),
                'type' => Controls_Manager::URL,
                'placeholder' => 'http://your-link.com',
                'default' => [
                    'url' => '#',
                ],
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'section_subtitle',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
          'g_pad',
          [
             'label' =>   esc_html__( 'Padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             
             'selectors' => [
                    '{{WRAPPER}} .ash-btn3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'typo',
                'selector' => '{{WRAPPER}} .ash-btn3',
                'label' =>   esc_html__( 'Typography', 'thepack' ),              
            ]
        );

        $this->add_control(
            'txtcol',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ash-btn3' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'tmr',
            [
                'label' =>   esc_html__( 'Right spacing', 'elementor' ),
                'type' => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .ash-btn3:before' => 'margin-right: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_icon',
            [
                'label' =>   esc_html__('Line bar', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,              
            ]
        );

        $this->add_control(
            'ibxsz',
            [
                'label' =>   esc_html__( 'Bar width', 'elementor' ),
                'type' => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .ash-btn3:before' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'bhw',
            [
                'label' =>   esc_html__( 'Bar hover width', 'elementor' ),
                'type' => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .ash-btn3:hover:before' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'icol',
            [
                'label' =>   esc_html__( 'Bar color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ash-btn3:before' => 'background: {{VALUE}};',
                ],
            ]
        );  

        $this->add_control(
            'icolh',
            [
                'label' =>   esc_html__( 'Bar hover color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ash-btn3:hover:before' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'bvp',
            [
                'label' =>   esc_html__( 'Vertical position', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => -20,
                        'max' => 20,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .ash-btn3:before' => 'top: {{SIZE}}{{UNIT}};',
                ],

            ]
        );
        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';
    }

}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_button3());