<?php
namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;
use Elementor\Scheme_Typography;
use Elementor\Utils;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_button4 extends Widget_Base {

    public function get_name() {
        return 'tb_btn4';
    }

    public function get_title() {
        return   esc_html__('BUTTON 4', 'thepack');
    }

    public function get_icon() {
        return 'eicon-button';
    }
    
    public function get_categories() {
        return array('ashelement-addons');
    } 

    protected function _register_controls() {

        $this->start_controls_section(
            'section_heading',
            [
                'label' =>   esc_html__('Button', 'thepack'),
            ]
        );


        $this->add_control(
            'text',
            [
                'type' => 'text',
                'label' =>   esc_html__('Button label', 'thepack'),
                'label_block' => true,
                'default' =>   esc_html__('START NEW PROJECT', 'thepack'),
            ]
        );
        $this->add_control(
            'link',
            [
                'label' =>   esc_html__( 'Link', 'elementor' ),
                'type' => Controls_Manager::URL,
                'placeholder' => 'http://your-link.com',
                'default' => [
                    'url' => '#',
                ],
            ]
        );

        $this->add_control(

            'effect', [
                'type' => Controls_Manager::SELECT,
                'label' =>   esc_html__('Button style', 'thepack'),
                'default' => 'btn-bloom btn-l-r',
                'options' => [
                    'btn-bloom btn-l-r' =>   esc_html__('Style 1', 'thepack'),
                    'btn-ezra btn-r-l' =>   esc_html__('Style 2', 'thepack'),
                    'btn-apollo btn-t-b' =>   esc_html__('Style 3', 'thepack'),
                    'btn-desert btn-b-t' =>   esc_html__('Style 4', 'thepack'),

                    'btn-bloom btn-i-o' =>   esc_html__('Style 5', 'thepack'),
                    'btn-ezra btn-o-i' =>   esc_html__('Style 6', 'thepack'),
                    'btn-apollo btn-i-o-r' =>   esc_html__('Style 7', 'thepack'),

                ],
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'section_subtitle',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'eoverly',
            [
                'label' =>   esc_html__( 'Width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 800,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} .btn4' => 'width: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
          'g_pad',
          [
             'label' =>   esc_html__( 'Padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             
             'selectors' => [
                    '{{WRAPPER}} .btn4' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_control( 
            'inpalign',
            [
                'label' =>   esc_html__('Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ]
                ],
                'default' => 'center',
                'selectors' => [
                    '{{WRAPPER}} .ash-btn-wrap' => 'text-align: {{VALUE}};',
                ],                 
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'typo',
                'selector' => '{{WRAPPER}} .btn4',
                'label' =>   esc_html__( 'Typography', 'thepack' ),              
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_xtra',
            [
                'label' =>   esc_html__('Other settings', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,              
            ]
        );

        $this->add_control(
            'txtcol',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn4' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'txtcolh',
            [
                'label' =>   esc_html__( 'Hover color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn4:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'tmr',
            [
                'label' =>   esc_html__( 'Border width', 'elementor' ),
                'type' => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .btn4' => 'border-width: {{SIZE}}{{UNIT}};border-style:solid;',
                ],
            ]
        );

        $this->add_control(
            'brad',
            [
                'label' =>   esc_html__( 'Border radius', 'elementor' ),
                'type' => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .btn4' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'bdrcl',
            [
                'label' =>   esc_html__( 'Border color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn4' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'backg',
            [
                'label' =>   esc_html__( 'Background color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn4' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'backgh',
            [
                'label' =>   esc_html__( 'Hover ackground color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn-bloom::before,{{WRAPPER}} .btn-bloom::after,{{WRAPPER}} .btn-ezra::before,{{WRAPPER}} .btn-ezra::after,{{WRAPPER}} .btn-apollo::before,{{WRAPPER}} .btn-apollo::after,{{WRAPPER}} .btn-desert::before,{{WRAPPER}} .btn-desert::after' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .btn4:hover' => 'border-color: {{VALUE}};',
                ],
            ]
        ); 

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';
    }

}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_button4());