<?php

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Utils;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly
 

class thepack_dualbtn extends Widget_Base {

    public function get_name() {
        return 'tbdlbtn';
    }

    public function get_title() {
        return   esc_html__('DUAL BUTTON', 'thepack');
    }

    public function get_icon() {
        return ' eicon-youtube';
    }

    public function get_categories() {
        return array('ashelement-addons');
    } 

    protected function _register_controls() {

        $this->start_controls_section(
            'section_heading',
            [
                'label' =>   esc_html__('Content', 'thepack'),
            ]
        );

        
        $this->add_control(
            'tmpl',
            [
                'label' =>   esc_html__('Template', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'one' => [
                        'title' =>   esc_html__('Dual button', 'thepack'),
                        'icon' => 'fa fa-folder',
                    ],
                    'two' => [
                        'title' =>   esc_html__('Video Icon', 'thepack'),
                        'icon' => 'fa fa-folder-o',
                    ],

                    'three' => [
                        'title' =>   esc_html__('Text', 'thepack'),
                        'icon' => 'fa fa-folder-open',
                    ],

                ],
                'default' => 'one',               
            ]
        );

        $this->add_control(
            'btn1',
            [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('First button label', 'thepack'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'url1', [
                'label' =>   esc_html__('First button link', 'thepack'),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'placeholder' =>   esc_html__('http://your-link.com', 'thepack'),
            ]
        );  

        $this->add_control(
            'btn2',
            [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Second button label', 'thepack'),
                'label_block' => true,
                'condition' => [
                    'tmpl' => 'one',
                ],                 
            ]
        );

        $this->add_control(
            'url2', [
                'label' =>   esc_html__('Second button link', 'thepack'),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'placeholder' =>   esc_html__('http://your-link.com', 'thepack'),
                'condition' => [
                    'tmpl' => 'one',
                ],                 
            ]
        );

        $this->add_control(
            'icon',
            [
                'type' => Controls_Manager::ICON,
                'label' =>   esc_html__('Play Icon', 'thepack'),
                'label_block' => true,
                'condition' => [
                    'tmpl' => 'two',
                ],                 
            ]
        );

        $this->add_control(
            'vidurl', [
                'label' =>   esc_html__('Video url', 'thepack'),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'condition' => [
                    'tmpl' => 'two',
                ],                 
            ]
        );

        $this->add_control(
            'txt',
            [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Text', 'thepack'),
                'label_block' => true,
                'condition' => [
                    'tmpl' => 'three',
                ],                 
            ]
        );

        $this->add_control(
            'septxt',
            [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Separator text', 'thepack'),
                'label_block' => true,
                'condition' => [
                    'tmpl' => 'three',
                ],                 
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        

        $this->add_responsive_control(
            'align',
            [
                'label' =>   esc_html__('Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' =>   esc_html__('Justified', 'thepack'),
                        'icon' => 'fa fa-align-justify',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .dualbtninr' => 'text-align: {{VALUE}};',
                ],                               
            ]
        );  

        $this->add_responsive_control(
            'oupd',
            [
                'label' =>   esc_html__('Padding', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%','em' ],
                'selectors' => [
                    '{{WRAPPER}} .dualbtnwrp>div' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .dualbtnwrp' => 'margin-left: -{{LEFT}}{{UNIT}};margin-right: -{{RIGHT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_fbtn',
            [
                'label' =>   esc_html__('First button', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'fbw',
            [
                'label' =>   esc_html__( 'Button width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px','%' ],
                'selectors' => [
                    '{{WRAPPER}} .dual1' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'fbpd',
            [
                'label' =>   esc_html__('Padding', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%','em' ],
                'selectors' => [
                    '{{WRAPPER}} .dual1' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'fbclr',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .dual1' => 'color: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'fbbg',
            [
                'label' =>   esc_html__( 'Background', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .dual1' => 'background: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'fbbclr',
            [
                'label' =>   esc_html__( 'Border  color', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .dual1' => 'border-color: {{VALUE}};border-style:solid;'
                ],
            ]
        );

        $this->add_responsive_control(
            'fbbrd',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .dual1' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'fbbw',
            [
                'label' =>   esc_html__( 'Border width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .dual1' => 'border-width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'fbtyp',
                'selector' => '{{WRAPPER}} .dual1',
                'label' =>   esc_html__( 'Typography', 'thepack' ),              
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_sep',
            [
                'label' =>   esc_html__('Separator', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'tmpl' => 'three',
                ],                
            ]
        );

        $this->add_control(
            'sep_c',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .dualsep' => 'color: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'sep_width',
            [
                'label' =>   esc_html__( 'Vertical position', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .dualsep' => 'line-height: {{SIZE}}px;',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'septyp',
                'selector' => '{{WRAPPER}} .dualsep',
                'label' =>   esc_html__( 'Typography', 'thepack' ),              
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_sbtn',
            [
                'label' =>   esc_html__('Second button', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'tmpl' => array('one','three'),
                ],                 
            ]
        );

        $this->add_responsive_control(
            'sbw',
            [
                'label' =>   esc_html__( 'Button width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px','%' ],
                'selectors' => [
                    '{{WRAPPER}} .dual2' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'sbpd',
            [
                'label' =>   esc_html__('Padding', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%','em' ],
                'selectors' => [
                    '{{WRAPPER}} .dual2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'sbclr',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .dual2' => 'color: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'sbg',
            [
                'label' =>   esc_html__( 'Background', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .dual2' => 'background: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'sbbclr',
            [
                'label' =>   esc_html__( 'Border  color', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .dual2' => 'border-color: {{VALUE}};border-style:solid;'
                ],
            ]
        );

        $this->add_responsive_control(
            'sbbrd',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .dual2' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'sbbw',
            [
                'label' =>   esc_html__( 'Border width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .dual2' => 'border-width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'sbtyp',
                'selector' => '{{WRAPPER}} .dual2',
                'label' =>   esc_html__( 'Typography', 'thepack' ),              
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_icon',
            [
                'label' =>   esc_html__('Video button', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'tmpl' => 'two',
                ],                
            ]
        );

        $this->add_control(
            'icon_bg',
            [
                'label' =>   esc_html__( 'Background', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .vidbtn' => 'background: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'icon_c',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .vidbtn i' => 'color: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'icon_width',
            [
                'label' =>   esc_html__( 'Width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .vidbtn' => 'width: {{SIZE}}px;height: {{SIZE}}px;',
                ],
            ]
        );

        $this->add_control(
            'icon_lheight',
            [
                'label' =>   esc_html__( 'Icon line-height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .vidbtn' => 'line-height: {{SIZE}}px;',
                ],
            ]
        );

        $this->add_control(
            'btn_size',
            [
                'label' =>   esc_html__( 'Icon font size', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .vidbtn'=>'font-size: {{SIZE}}px;',
                ],
            ]
        );

        $this->add_control(
            'btn_rad',
            [
                'label' =>   esc_html__( 'Button border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .vidbtn'=>'border-radius: {{SIZE}}px;',
                ],
            ]
        );

        $this->add_control(
            'btn_brads',
            [
                'label' =>   esc_html__( 'Button border width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .vidbtn'=>'border-width: {{SIZE}}px;',
                ],
            ]
        );

        $this->add_control(
            'icon_bdrcl',
            [
                'label' =>   esc_html__( 'Border color', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .vidbtn' => 'border-color: {{VALUE}};border-style:solid;'
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';

    }
}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_dualbtn());