<?php

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
 
if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_cf7 extends Widget_Base {

    public function get_name() {
        return 'ae-cf7';
    }

    public function get_title() {
        return   esc_html__('CONTACT-FORM 7', 'thepack');
    }

    public function get_icon() {
        return 'eicon-form-horizontal';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_pricing_table',
            [
                'label' =>   esc_html__('Contact form 7', 'thepack'),
            ]
        );

        $this->add_control(
            'cform',
            [
                'label' =>   esc_html__( 'Select Form', 'thepack' ),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'options' => thepack_drop_posts('wpcf7_contact_form')
                
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_dimension',
            [
                'label' =>   esc_html__( 'Input', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'fmwid',
            [
                'label' =>   esc_html__('Form max width', 'thepack'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 1200,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => ['px','%'],                
                'selectors' => [
                    '{{WRAPPER}} .ae-cf7 form.wpcf7-form' => 'max-width: {{SIZE}}{{UNIT}};display:inline-block;width: 100%;',
                ],
            ]
        );

        $this->add_control( 
            'wrpalgn',
            [
                'label' =>   esc_html__('Form Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ]
                ],
                'default' => 'center',
                'condition' => [
                    'fmwid!' => '',
                ],                 
                'selectors' => [
                    '{{WRAPPER}} .ae-cf7' => 'text-align: {{VALUE}};',
                ],                 
            ]
        );

        $this->add_control( 
            'inpalign',
            [
                'label' =>   esc_html__('Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ]
                ],
                'default' => 'center',
                'selectors' => [
                    '{{WRAPPER}} .ae-cf7 .wpcf7-form-control' => 'text-align: {{VALUE}};',
                ],                 
            ]
        );

        $this->add_control(
            'input_padding',
            [
                'label' =>   esc_html__('Padding', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                 
                'size_units' => [ 'px', '%','em' ],
                'selectors' => [
                    '{{WRAPPER}} .ae-cf7 .wpcf7-form-control' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'input_height',
            [
                'label' =>   esc_html__('Input height', 'thepack'),
                'type' => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .ae-cf7 .wpcf7-form-control' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'input_margin',
            [
                'label' =>   esc_html__('Margin', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%','em' ],
                'selectors' => [
                    '{{WRAPPER}} .ae-cf7 .wpcf7-form-control' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'input_bg',
            [
                'label' =>   esc_html__('Input background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ae-cf7 .wpcf7-form-control' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'input_color',
            [
                'label' =>   esc_html__('Text color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ae-cf7 .wpcf7-form-control' => 'color: {{VALUE}};',
                    '{{WRAPPER}} ::placeholder' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'input_border',
            [
                'label' =>   esc_html__('Input border color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ae-cf7 .wpcf7-form-control' => 'border-color: {{VALUE}};border-style:solid;',
                ],
            ]
        );

        $this->add_control(
            'input_border_width',
            [
                'label' =>   esc_html__('Border width', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .ae-cf7 .wpcf7-form-control' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'input_border_radius',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .ae-cf7 .wpcf7-form-control' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'textarea_height',
            [
                'label' =>   esc_html__( 'Textarea height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .wpcf7-form-control.wpcf7-textarea' => 'height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'label-col',
            [
                'label' =>   esc_html__('Label color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ae-cf7 label' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_button',
            [
                'label' =>   esc_html__('Button', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'c_button',
            [
                'label' =>   esc_html__( 'Center align button', 'thepack' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__( 'Yes', 'thepack' ),
                'label_off' =>   esc_html__( 'No', 'thepack' ),
                'selectors' => [
                    '{{WRAPPER}} .xlcfsend' => 'text-align: center;',
                    '{{WRAPPER}} #submit' => 'margin: 0px auto;',
                ],                
            ]
        );

        $this->add_control(
            'button-bg',
            [
                'label' =>   esc_html__( 'Button background', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #submit' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button-color',
            [
                'label' =>   esc_html__( 'Button text color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #submit' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button-border_color',
            [
                'label' =>   esc_html__( 'Border color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #submit' => 'border-color: {{VALUE}};',
                ],
            ]
        ); 

        $this->add_control(
            'button-bgh',
            [
                'label' =>   esc_html__( 'Button background hover', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #submit:hover' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button-colorh',
            [
                'label' =>   esc_html__( 'Button text color hover', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #submit:hover .submit-text' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button-border_colorh',
            [
                'label' =>   esc_html__( 'Border color hover', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #submit:hover' => 'border-color: {{VALUE}};',
                ],
            ]
        ); 

        $this->add_responsive_control(
            'button-width',
            [
                'label' =>   esc_html__( 'Width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} #submit' => 'width: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'btn-margin-top',
            [ 
                'label' =>   esc_html__( 'Margin top', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => -100,
                        'max' => 500,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} #submit' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],

            ]
        );


        $this->add_control(
            'btn-padding',
            [
                'label' =>   esc_html__('Padding', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%','em' ],
                'selectors' => [
                    '{{WRAPPER}} #submit' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'button-border-radius',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} #submit' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'button-border-width',
            [
                'label' =>   esc_html__( 'Border width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} #submit' => 'border-width: {{SIZE}}{{UNIT}};border-style:solid;',
                ],

            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'section_typo',
            [
                'label' =>   esc_html__('Typography', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'input_typo',
                'selector' => '{{WRAPPER}} .wpcf7-form-control',
                'label' =>   esc_html__( 'Input', 'thepack' ),              
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typo',
                'selector' => '{{WRAPPER}} #submit',
                'label' =>   esc_html__( 'Button', 'thepack' ),              
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'lbk_typo',
                'selector' => '{{WRAPPER}} label',
                'label' =>   esc_html__( 'Label', 'thepack' ),              
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_misc',
            [
                'label' =>   esc_html__('Misc', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );


        $this->add_control(
            'loader_color',
            [
                'label' =>   esc_html__( 'First loader color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .submit-busy' => 'border-top: 3px solid {{VALUE}};border-right: 3px solid {{VALUE}};border-bottom: 3px solid {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'loader_color_2',
            [
                'label' =>   esc_html__( 'Second loader color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .submit-busy' => 'border-left: 3px solid {{VALUE}};',
                ],
            ]
        );        

        $this->add_control(
            'animation',
            [
                'label' =>   esc_html__('Animation', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'options' =>  thepack_animations(), 
                'multiple' => false,
                'label_block' => true 
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {

        $settings = $this->get_settings();

        ?>

        <div class="ae-cf7 aecf-<?php echo $this->get_id(); ?>">
            <?php if ($this->get_settings( 'cform' ) != null) { echo do_shortcode( '[contact-form-7 id="'.$this->get_settings( 'cform' ).'"]' ); } ?> 
        </div>

        <?php
    }

}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_cf7());