<?php

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;  
use Elementor\utils;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_changelog extends Widget_Base {

    public function get_name() {
        return 'tbchangelog';
    }

    public function get_title() {
        return   esc_html__('CHANGELOG', 'thepack');
    }

    public function get_icon() {
        return 'eicon-sync';
    }

    public function get_categories() {
        return array('demo-landing');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_process_1',
            [
                'label' =>   esc_html__('Content', 'thepack'),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'type', [
                'label' =>   esc_html__('Type', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'title' => [
                        'title' =>   esc_html__('Title', 'thepack'),
                        'icon' => ' eicon-document-file',
                    ],
                    'des' => [
                        'title' =>   esc_html__('Icon', 'thepack'),
                        'icon' => 'eicon-image-rollover',
                    ]
                ],
                'default' => 'title',
                'label_block' => true,                
            ]
        );

        $repeater->add_control(
            'title', [
                'label' =>   esc_html__( 'Title', 'thepack' ),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true, 
                'condition' => [
                    'type' => 'title',
                ],                               
            ]
        );

        $repeater->add_control(
            'label', [
                'label' =>   esc_html__( 'Label', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,   
                'condition' => [
                    'type' => 'des',
                ],                            
            ]
        );

        $repeater->add_control(
            'lblbg', [
                'label' =>   esc_html__( 'Label background', 'thepack' ),
                'type' => Controls_Manager::COLOR,  
                'condition' => [
                    'type' => 'des',
                ],                            
            ]
        );
        
        $repeater->add_control(
            'desc', [
                'label' =>   esc_html__( 'Description', 'thepack' ),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,   
                'condition' => [
                    'type' => 'des',
                ],                            
            ]
        );

        $this->add_control(
            'items',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(), 
                'prevent_empty' => false,
                'default' => [
                    [
                        'type' =>   esc_html__( 'Frontend Web Developer', 'thepack' ),
                    ]
                ],
                'title_field' => '{{{ type }}}',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'thm',
            [
                'label' =>   esc_html__('Timeline theme', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbchangelog::before,{{WRAPPER}} .title:before' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'lsp',
            [
                'label' =>   esc_html__( 'Content left spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .tbchangelog-content,{{WRAPPER}} .title' => 'padding-left: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'vsp',
            [
                'label' =>   esc_html__( 'Content vertical spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .tbchangelog-block' => 'padding: {{SIZE}}{{UNIT}} 0px;',
                ],

            ]
        );

        $this->end_controls_section(); 

        $this->start_controls_section(
            'section_title',
            [
                'label' =>   esc_html__('Title', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            't_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .title' => 'color: {{VALUE}};',
                ],
            ]
        );


        $this->add_control(
          't_mg',
          [
             'label' =>   esc_html__( 'Margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             
             'selectors' => [
                    '{{WRAPPER}} .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};display:inline-block;',
             ],
          ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 't_typo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .title',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_lbl',
            [
                'label' =>   esc_html__('Label', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
          'st_pd',
          [
             'label' =>   esc_html__( 'Padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             
             'selectors' => [
                    '{{WRAPPER}} .cglabel' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};display:inline-block;',
             ],
          ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'st_typo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .cglabel',
            ]
        );

        $this->add_responsive_control(
            'stbr',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .cglabel' => 'border-radius: {{SIZE}}px;',
                ],

            ]
        );

        $this->add_responsive_control(
            'stwd',
            [
                'label' =>   esc_html__( 'Width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .cglabel' => 'width: {{SIZE}}px;',
                ],

            ]
        );

        $this->add_responsive_control(
            'stmrf',
            [
                'label' =>   esc_html__( 'Margin right', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .cglabel' => 'margin-right: {{SIZE}}px;',
                ],

            ]
        );

        $this->add_responsive_control(
            'stvp',
            [
                'label' =>   esc_html__( 'Vertical position', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .cglabel' => 'bottom: -{{SIZE}}px;',
                ],

            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_des',
            [
                'label' =>   esc_html__('Description', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'd_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .description' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'd_typo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .description',
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {
        $settings = $this->get_settings();      
        require dirname(__FILE__) .'/view.php';
    }


    private function content($content) { 
        
        foreach ($content as $item){

            if ($item['type']=='title'){

                $title = $item['title'] ? '<h3 class="title">'.$item['title']. '</h3>' : '';

            } else {

                $title = '';
                $lbbg = $item['lblbg'] ? 'style=background:'.$item['lblbg'].';' : '';
                $label = $item['label'] ? '<span '.$lbbg.' class="cglabel">'.$item['label']. '</span>' : '';   
                $desc = $item['desc'] ? '<p class="description">'.$item['desc']. '</p>' : '';
                $inr = '<div class="tbchangelog-content">'.$label.$desc.'</div>';

            }

            if(!next($content)) {
                $last = 'lastitm';
            }
            ( $item['label']);
            $out .= '
                <div class="tbchangelog-block">
                  '.$title.'
                  '.$inr.'
                </div>            
            '; 
        }

        return $out;
        
    }
     

}

 $widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_changelog());