<?php

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Utils;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_cookie_consnt extends Widget_Base {

    public function get_name() {
        return 'cookie_consent';
    }

    public function get_title() {
        return   esc_html__('COOKIE CONSENT', 'thepack');
    }

    public function get_icon() {
        return ' eicon-youtube';
    }

    public function get_categories() {
        return array('ashelement-addons');
    } 

    protected function _register_controls() {

        $this->start_controls_section(
            'section_heading',
            [
                'label' =>   esc_html__('Content', 'thepack'),
            ]
        );

        $this->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' =>   esc_html__('Title', 'thepack'),
                'label_block' => true,
                'default' => '&#x1F36A; Accept Cookies & Privacy Policy?',
            ]
        );

        $this->add_control(
            'message',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' =>   esc_html__('Message', 'thepack'),
                'label_block' => true,
                'default' => 'There are no cookies used on this site, but if there were this message could be customised to provide more details. Click the <strong>accept</strong> button below to see the optional callback in action...',
            ]
        );

        $this->add_control(
            'expires',
            [
                'label' =>   esc_html__( 'Expiry in days', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,                                       
            ]
        );

        $this->add_control(
            'link',
            [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Link', 'thepack'),
                'label_block' => true,
                'default' => '#',
            ]
        );

        $this->add_control(
            'acceptBtnLabel',
            [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Accept button label', 'thepack'),
                'label_block' => true,
                'default' => 'Accept Cookies',
            ]
        );

        $this->add_control(
            'moreInfoLabel',
            [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('More info button label', 'thepack'),
                'label_block' => true,
                'default' => 'More information',
            ]
        );

        $this->add_control(
            'cookieTypesTitle',
            [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Coookie type label', 'thepack'),
                'label_block' => true,
                'default' => 'Select which cookies you want to accept',
            ]
        );

        $this->add_control(
            'fixedCookieTypeLabel',
            [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Fixed cookie label', 'thepack'),
                'label_block' => true,
                'default' => 'Essential',
            ]
        );

        $this->add_control(
            'fixedCookieTypeDesc',
            [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Fixed cookie description', 'thepack'),
                'label_block' => true,
                'default' => 'These are essential for the website to work correctly.',
            ]
        );
                        
        $this->end_controls_section();


        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'position',
            [
                'label' =>   esc_html__('Position', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ],
                ],                             
            ]
        );

        $this->add_responsive_control(
            'rsp',
            [
                'label' =>   esc_html__( 'Right spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} #gdpr-cookie-message' => 'right: {{SIZE}}{{UNIT}};bottom: {{SIZE}}{{UNIT}};margin-left: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'position' => 'right',
                ],
            ]
        );

        $this->add_responsive_control(
            'lsp',
            [
                'label' =>   esc_html__( 'Left spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} #gdpr-cookie-message' => 'left: {{SIZE}}{{UNIT}};bottom: {{SIZE}}{{UNIT}};margin-right: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'position' => 'left',
                ],
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label' =>   esc_html__('Content align', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' =>   esc_html__('Justified', 'thepack'),
                        'icon' => 'fa fa-align-justify',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} #gdpr-cookie-message' => 'text-align: {{VALUE}};',
                ],                              
            ]
        );

        $this->add_responsive_control(
            'width',
            [
                'label' =>   esc_html__( 'Max width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    'em' => [
                        'min' => 0,
                        'max' => 10,
                    ],
                ],
                'size_units' => [ 'px', 'em','%' ],
                'selectors' => [
                    '{{WRAPPER}} #gdpr-cookie-message' => 'max-width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );  

        $this->add_responsive_control(
          'pad',
          [
             'label' =>   esc_html__( 'Padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px', '%', 'em' ],
             'selectors' => [
                    '{{WRAPPER}} #gdpr-cookie-message' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_control(
          'b3',
          [
             'type'    => Controls_Manager::RAW_HTML,
             'raw' =>   esc_html__( '<b>Background</b>', 'thepack' ),
          ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'bg',
                'label' =>   esc_html__( 'Background', 'elementor' ),
                'types' => [ 'none', 'classic','gradient' ],
                'selector' => '{{WRAPPER}} #gdpr-cookie-message',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_ttl',
            [
                'label' =>   esc_html__('Title', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'tclr',  
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} #gdpr-cookie-message h4' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 't_typo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} #gdpr-cookie-message h4',
            ]
        );

        $this->add_control(
          'tmar',
          [
             'label' =>   esc_html__( 'Margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             'selectors' => [
                    '{{WRAPPER}} #gdpr-cookie-message h4' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_cnt',
            [
                'label' =>   esc_html__('Content', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'cclr',  
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} #gdpr-cookie-message p,{{WRAPPER}} #gdpr-cookie-message ul,{{WRAPPER}} #gdpr-cookie-message a,{{WRAPPER}} #gdpr-cookie-message h5' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'c_typo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} #gdpr-cookie-message p,{{WRAPPER}} #gdpr-cookie-message ul',
            ]
        );

        $this->add_control(
          'cmar',
          [
             'label' =>   esc_html__( 'Margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             'selectors' => [
                    '{{WRAPPER}} #gdpr-cookie-message p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_btn',
            [
                'label' =>   esc_html__('Button', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'btnclr',  
            [
                'label' =>   esc_html__( 'Background', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} #gdpr-cookie-message button' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btnclr2',  
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} #gdpr-cookie-message button' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .tbcokiebtnwrp button',
            ]
        );

        $this->add_control(
          'btnpd',
          [
             'label' =>   esc_html__( 'Padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             'selectors' => [
                    '{{WRAPPER}} .tbcokiebtnwrp button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_responsive_control(
            'btntpmr',
            [
                'label' =>   esc_html__( 'Top margin', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .tbcokiebtnwrp' => 'margin-top: {{SIZE}}px;',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';

    }
}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_cookie_consnt());