<?php

namespace WebangonAddon\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Utils;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_cta extends Widget_Base {

    public function get_name() {
        return 'aecta';
    }
 
    public function get_title() {
        return   esc_html__('CTA', 'thepack');
    }

    public function get_icon() {
        return 'eicon-call-to-action';
    }

    public function get_categories() {
        return array('ashelement-addons');
    } 
    
    protected function _register_controls() {

        $this->start_controls_section(
            'section_heading',
            [
                'label' =>   esc_html__('CTA1', 'thepack'),
            ]
        );


        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'title', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Heading', 'thepack'),
                'label_block' => true,
                'default' => 'Year',               
            ]
        );

        $repeater->add_control(
            'ikn', [
                'type' => Controls_Manager::ICON,
                'label' =>   esc_html__('Icon', 'thepack'),
                'label_block' => true,               
            ]
        );

        $repeater->add_control(
            'sub_title', [
                'type' => Controls_Manager::TEXTAREA,
                'label' =>   esc_html__('Sub title', 'thepack'),
                'label_block' => true,              
            ]
        );

        $repeater->add_control(
            'link', [
                'label' =>   esc_html__('Link', 'thepack'),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'placeholder' => 'http://your-link.com',
                'default' => [
                    'url' => 'https://themeforest.net/user/xldevelopment',
                ],              
            ]
        );

        $repeater->add_control(
            'bgcolor', [
                'type' => Controls_Manager::COLOR,
                'label' =>   esc_html__('Background color', 'thepack'),
                'label_block' => true,              
            ]
        );
                                        
        $this->add_control(
            'ae_lists',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'prevent_empty' => false,
                'default' => [
                    [
                        'title' =>   esc_html__( 'Year', 'thepack' ),
                    ]
                ],
                'title_field' => '{{{ title }}}',
            ]
        );

        $this->add_control(
            'ttag',
            [
                'type' => Controls_Manager::SELECT,
                'label' =>   esc_html__('Title tag', 'thepack'),
                'default' => 'h2',
                'options' => [
                    'h1' =>   esc_html__('H1', 'thepack'),
                    'h2' =>   esc_html__('H2', 'thepack'),
                    'h3' =>   esc_html__('H3', 'thepack'),
                    'h4' =>   esc_html__('H4', 'thepack'),
                    'span' =>   esc_html__('Span', 'thepack'),
                    'p' =>   esc_html__('p', 'thepack'),
                ],
            ]
        );

        $this->add_control(
            'stag',
            [
                'type' => Controls_Manager::SELECT,
                'label' =>   esc_html__('Sub Title tag', 'thepack'),
                'default' => 'h2',
                'options' => [
                    'h1' =>   esc_html__('H1', 'thepack'),
                    'h2' =>   esc_html__('H2', 'thepack'),
                    'h3' =>   esc_html__('H3', 'thepack'),
                    'h4' =>   esc_html__('H4', 'thepack'),
                    'span' =>   esc_html__('Span', 'thepack'),
                    'p' =>   esc_html__('p', 'thepack'),
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label' =>   esc_html__('Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'default' => 'center',
                'selectors' => [
                    '{{WRAPPER}} .fullcta' => 'text-align: {{VALUE}};',
                ],                
            ]
        );

        $this->add_control(
            'padding',
            [
                'label' =>   esc_html__( 'Padding', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .wa-equal-item a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'animation',
            [
                'label' =>   esc_html__('Animation', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'options' =>  thepack_animations(), 
                'multiple' => false,
                'label_block' => true                              
            ]
        );  

        $this->end_controls_section();

        $this->start_controls_section(
            'section_title',
            [
                'label' =>   esc_html__('Title', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'titletypo',
                'selector' => '{{WRAPPER}} .title',
                'label' =>   esc_html__( 'Typo', 'thepack' ),              
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'tmargin',
            [
                'label' =>   esc_html__( 'Margin', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_subtitle',
            [
                'label' =>   esc_html__('Sub Title', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'sbtitletypo',
                'selector' => '{{WRAPPER}} .subtitle',
                'label' =>   esc_html__( 'Typo', 'thepack' ),              
            ]
        );

        $this->add_control(
            'sbtitle_color',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .subtitle' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'sbtmargin',
            [
                'label' =>   esc_html__( 'Margin', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .subtitle' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();   

        $this->start_controls_section(
            'section_icons',
            [
                'label' =>   esc_html__('Icons', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'ivps',
            [
                'label' =>   esc_html__( 'Vertical position', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => ['%','px'],
                'selectors' => [
                    '{{WRAPPER}} .tbicon' => 'top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'ihps',
            [
                'label' =>   esc_html__( 'Horizontal position', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} .tbicon' => 'left: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'avtr_lpad',
            [
                'label' =>   esc_html__( 'Size', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => ['%','px'],
                'selectors' => [
                    '{{WRAPPER}} .tbicon' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'i_clr',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbicon' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';
    }
   
}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_cta());