<?php

/*
Widget Name: Webangon full social
Description: Full width social.
Author: Ashraf
Author URI: https://www.webangon.com
*/
  
namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
 
if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_galslk_sync extends Widget_Base {

    public function get_name() {
        return 'tb_slkgalsyn';
    }

    public function get_title() {
        return   esc_html__('GALLERY SYNC', 'thepack');
    }

    public function get_icon() {
        return 'eicon-image-hotspot';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_pricing_table',
            [
                'label' =>   esc_html__('Gallery', 'thepack'),
            ]
        );

        $this->add_control(
            'tmpl',
            [
                'label' =>   esc_html__('Template', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'one' => [
                        'title' =>   esc_html__('One', 'thepack'),
                        'icon' => 'fa fa-folder',
                    ],
                    'two' => [
                        'title' =>   esc_html__('Two', 'thepack'),
                        'icon' => 'fa fa-folder-o',
                    ],

                ],
                'default' => 'one',               
            ]
        );

        $this->add_control(
            'galleries',
            [
                'label' =>   esc_html__('Gallery', 'thepack'),
                'type' => Controls_Manager::GALLERY,
            ]
        );

        $this->add_control(
            'img_size',
            [
                'label' =>   esc_html__('Image size', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' =>  thepack_image_size_choose(), 
                'multiple' => false,                                
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'section_carousel',
            [
                'label' =>   esc_html__('Carousel', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,              
            ]
        );


        $this->add_control(
            'auto',
            [
                'label' =>   esc_html__('Autoplay', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );

        $this->add_control(
            'center',
            [
                'label' =>   esc_html__('Center mode', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                 
            ]
        );

        $this->add_control(
            'item',
            [
                'label' =>   esc_html__( 'Item per slide', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 10,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'size' => 3,
                ],                
                'size_units' => [ 'px'],              
            ]
        );

        $this->add_control(
            'speed',
            [
                'label' =>   esc_html__( 'Slide speed', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 8000,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'size' => 3000,
                ],                 
                'size_units' => [ 'px'],               
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_thmb',
            [
                'label' =>   esc_html__('Thumbnail', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,                 
            ]
        );

        $this->add_responsive_control(
            'thmpd',
            [
                'label' =>   esc_html__( 'Thumb padding', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 800,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .thmbwrpr .slick-slide' => 'padding: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'thmwrwd',
            [
                'label' =>   esc_html__( 'Wrapper width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 800,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} .thmbwrpr .slick-list' => 'max-width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'thmwrht',
            [
                'label' =>   esc_html__( 'Wrapper height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 800,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} .thmbgalslik.two .thmbwrpr' => 'height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'tmpl' => 'two',
                ], 
            ]
        );

        $this->add_responsive_control(
            'thmwdf',
            [
                'label' =>   esc_html__( 'Thumbnail width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} .thmbgalslik.two .thmbwrpr img' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'tmpl' => 'two',
                ],                 

            ]
        );

        $this->add_responsive_control(
            'thmxp',
            [
                'label' =>   esc_html__( 'Thumbnail horizontal position', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    '%' => [
                        'max' => 100,
                        'min' => -100,
                        'step' => 1,
                    ]
                ],
                'size_units' => ['%'],
                'selectors' => [
                    '{{WRAPPER}} .thmbgalslik.two .thmbwrpr' => 'right: {{SIZE}}%;',
                ],
                'condition' => [
                    'tmpl' => 'two',
                ],                 

            ]
        );

        $this->add_responsive_control(
            'thmbbps',
            [
                'label' =>   esc_html__( 'Wrapper bottom spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 500,
                        'min' => -500,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'condition' => [
                    'tmpl' => 'one',
                ],                
                'selectors' => [
                    '{{WRAPPER}} .thmbwrpr .slick-list' => 'bottom: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'nbdr',
            [
                'label' =>   esc_html__('Border color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thmbwrpr img' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'abdr',
            [
                'label' =>   esc_html__('Active border color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thmbwrpr .slick-current img' => 'border-color: {{VALUE}};',
                ],
            ]
        );        

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';
    }

}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_galslk_sync());