<?php

/*
Widget Name: Webangon full social
Description: Full width social.
Author: Ashraf
Author URI: https://www.webangon.com
*/
 
namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Scheme_Typography; 
 
if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_gallery_tickr extends Widget_Base {

    public function get_name() {
        return 'gallry_tickr';
    }

    public function get_title() {
        return   esc_html__('GALLERY TICKER', 'thepack');
    }

    public function get_icon() {
        return 'eicon-image-hotspot';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_content',
            [
                'label' =>   esc_html__('Content', 'thepack'),
            ]
        );

        $this->add_control(
            'galleries',
            [
                'label' =>   esc_html__('Gallery', 'thepack'),
                'type' => Controls_Manager::GALLERY,
            ]
        );

        $this->add_control(
            'img_size',
            [
                'label' =>   esc_html__('Image size', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' =>  thepack_image_size_choose(), 
                'multiple' => false,                                
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__( 'General', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'tmpl',
            [
                'label' =>   esc_html__('Template', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'grid' => [
                        'title' =>   esc_html__('Grid', 'thepack'),
                        'icon' => 'eicon-gallery-grid',
                    ],
                    'masonry' => [
                        'title' =>   esc_html__('Masonry', 'thepack'),
                        'icon' => 'eicon-gallery-masonry',
                    ],                    

                    'justified' => [
                        'title' =>   esc_html__('Justified', 'thepack'),
                        'icon' => 'fa fa-folder-open',
                    ],

                ],
                'default' => 'grid',               
            ]
        );

        $this->add_control(
            'eoverly',
            [
                'label' =>   esc_html__('Disable overlay', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'return_value' => 'yes',
                'default' => 'yes',   
                 'selectors' => [
                        '{{WRAPPER}} .overlay' => 'display:none;',
                 ],                              
            ]
        );

        $this->add_responsive_control(
            'width',
            [
                'label' =>   esc_html__( 'Column width in %', 'thepack' ),
                'type' =>  Controls_Manager::NUMBER, 
                'default' => '33.33',
                 'selectors' => [
                        '{{WRAPPER}} .gallery-item' => 'width: {{VALUE}}%;',
                 ],  
                'condition' => [
                    'tmpl!' => array('justified'),
                ],                                             
            ]
        );
        
        $this->add_control(
            'animation',
            [
                'label' =>   esc_html__('Animation', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'options' =>  thepack_animations(), 
                'multiple' => false,
                'label_block' => true 
            ]
        );

        $this->add_control(
            'grid_pad',
            [
                'label' =>   esc_html__('Padding', 'thepack'),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],   
                'selectors' => [
                    '{{WRAPPER}} .gallery-item' => 'padding:{{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .aegrid-gallery' => 'margin-left:-{{SIZE}}{{UNIT}};margin-right:-{{SIZE}}{{UNIT}};',
                ],                            
            ]
        );

        $this->add_control(
            'jght',
            [
                'label' =>   esc_html__('Justified gallery height', 'thepack'),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 800,
                        'step' => 1,
                    ],
                ],
                'condition' => [
                    'tmpl' => array('justified'),
                ],                             
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_overlay',
            [
                'label' =>   esc_html__('Overlay', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'eoverly!' => array('yes'),
                ],                 
            ]
        );

        $this->add_control(
          'g_pad',
          [
             'label' =>   esc_html__( 'Overlay padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             
             'selectors' => [
                    '{{WRAPPER}} .overlay' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'overlay_color',
                'label' =>   esc_html__( 'Overlay color', 'elementor' ),
                'types' => [ 'none', 'classic','gradient' ],
                'selector' => '{{WRAPPER}} .content-center',
            ]
        );

        $this->add_control(
            'g_bg',
            [
                'label' =>   esc_html__('Icon color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbicon' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'ifntsze',
            [
                'label' =>   esc_html__('Icon font size', 'thepack'),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 50,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],  
                'selectors' => [
                    '{{WRAPPER}} .tbicon' => 'font-size: {{SIZE}}{{UNIT}};',
                ],                             
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';
    }

}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_gallery_tickr());