<?php

/*
Widget Name: Webangon full social
Description: Full width social.
Author: Ashraf
Author URI: https://www.webangon.com
*/

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
 
if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_gmap extends Widget_Base {

    public function get_name() {
        return 'ae-gmap';
    }

    public function get_title() {
        return   esc_html__('GOOGLE MAP', 'thepack');
    }

    public function get_icon() {
        return ' eicon-google-maps';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_pricing_table',
            [
                'label' =>   esc_html__('Google map', 'thepack'),
            ]
        );

        $this->add_control(

            'style',
            [
                'type' => Controls_Manager::SELECT,
                'label' =>   esc_html__('Choose Style', 'thepack'),
                'default' => 'style-one',
                'label_block' => true,
                'options' => [
                    'style_one' =>   esc_html__('Style 1', 'thepack'),
                    'style_two' =>   esc_html__('Style 2', 'thepack'),
                ],
            ]
        );

        $this->add_control(
            'lat', // id
            [
                'label' =>   esc_html__( 'Lattitude', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'default' => '24.2529212',
                'label_block' => true,
                
            ]
        );

        $this->add_control(
            'long', // id
            [
                'label' =>   esc_html__( 'Lattitude', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'default' => '89.9056218',
                'label_block' => true,
                
            ]
        );

        $this->add_control(
            'items',
            [
                'label' =>   esc_html__('Content box', 'thepack'),
                'type' => Controls_Manager::REPEATER,
                'fields' => [

                    [
                        'name' => 'type',
                        'label' =>   esc_html__('Content type', 'thepack'),
                        'type' => Controls_Manager::CHOOSE,
                        'options' => [
                            'heading' => [
                                'title' =>   esc_html__('Heading', 'thepack'),
                                'icon' => ' eicon-document-file',
                            ],
                            'iconbox' => [
                                'title' =>   esc_html__('Iconbox', 'thepack'),
                                'icon' => 'eicon-image-rollover',
                            ], 
                            'openhrs' => [
                                'title' =>   esc_html__('Open hours', 'thepack'),
                                'icon' => 'eicon-image-rollover',
                            ]                                                       
                        ],
                        'default' => 'heading',
                        'label_block' => true,
                    ],

                    [
                        'name' => 'head',
                        'label' =>   esc_html__('Heading', 'thepack'),
                        'type' => Controls_Manager::TEXT,
                        'condition' => [
                            'type' => 'heading',
                        ],                        
                        'label_block' => true,
                    ],

                    [
                        'name' => 'content',
                        'label' =>   esc_html__('Content', 'thepack'),
                        'type' => Controls_Manager::TEXT,
                        'condition' => [
                            'type' => 'iconbox',
                        ],                        
                        'label_block' => true,
                    ],                    

                    [
                        'name' => 'icon',
                        'label' =>   esc_html__('Icon', 'thepack'),
                        'type' => Controls_Manager::ICON,
                        'condition' => [
                            'type' => 'iconbox',
                        ],                        
                        'label_block' => true,
                    ], 

                    [
                        'name' => 'range',
                        'label' =>   esc_html__('Day range', 'thepack'),
                        'type' => Controls_Manager::TEXT,
                        'condition' => [
                            'type' => 'openhrs',
                        ],                        
                        'label_block' => true,
                    ],                    

                    [
                        'name' => 'open',
                        'label' =>   esc_html__('Time', 'thepack'),
                        'type' => Controls_Manager::TEXT,
                        'condition' => [
                            'type' => 'openhrs',
                        ],                        
                        'label_block' => true,
                    ],
                ],
                'title_field' => '{{{ type }}}',
            ]
        );

        $this->add_control(
            'desc',
            [
                'label' =>   esc_html__( 'Info windo text', 'thepack' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => 'Here we go. Find us here',
                'label_block' => true,
                
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_dimension',
            [
                'label' =>   esc_html__( 'General', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'max_widh',
            [
                'label' =>   esc_html__('Max wrapper width', 'thepack'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'default' => [
                    'size' => 400,
                ],
                'range' => [
                    'px' => [
                        'max' => 1200,
                        'min' => 1,
                        'step' => 1,
                    ],                   
                ],
                'selectors' => [
                    '{{WRAPPER}} .map-info' => 'max-width: {{SIZE}}{{UNIT}};',
                ]                
            ]
        );

        $this->add_responsive_control(
            'margin_left',
            [
                'label' =>   esc_html__('Left margin', 'thepack'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'default' => [
                    'size' => 40,
                ],
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => -100,
                        'step' => 1,
                    ],                   
                ],
                'selectors' => [
                    '{{WRAPPER}} .map-info' => 'margin-left: {{SIZE}}%;',
                ]                
            ]
        );

        $this->add_control(
            'zoom',
            [
                'label' =>   esc_html__('Zoom level', 'thepack'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'default' => [
                    'size' => 15,
                ],
                'range' => [
                    'px' => [
                        'max' => 20,
                        'min' => 1,
                        'step' => 1,
                    ],                   
                ],
            ]
        );

        $this->add_control(
            'show_zoom',
            [
                'label' =>   esc_html__( 'Show zoom control', 'thepack' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__( 'Yes', 'thepack' ),
                'label_off' =>   esc_html__( 'No', 'thepack' ),
            ]
        );
 
        $this->add_responsive_control(
            'height',
            [
                'label' =>   esc_html__('Map height', 'thepack'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'default' => [
                    'size' => 400,
                ],
                'range' => [
                    'px' => [
                        'max' => 1200,
                        'min' => 1,
                        'step' => 1,
                    ],                   
                ],
                'selectors' => [
                    '{{WRAPPER}} .ae-gmap' => 'height: {{SIZE}}{{UNIT}};',
                ]                
            ]
        );

        $this->add_control(
            'padding',
            [
                'label' =>   esc_html__( 'Padding', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .map-info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_title',
            [
                'label' =>   esc_html__('Title', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'titletypo',
                'selector' => '{{WRAPPER}} .title',
                'label' =>   esc_html__( 'Typo', 'thepack' ),              
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'tmargin',
            [
                'label' =>   esc_html__( 'Margin', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_contents',
            [
                'label' =>   esc_html__('Contents', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'contenttypo',
                'selector' => '{{WRAPPER}} .iconinfo,{{WRAPPER}} .openhrs',
                'label' =>   esc_html__( 'Typo', 'thepack' ),              
            ]
        );

        $this->add_control(
            'content_color',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .iconinfo,{{WRAPPER}} .openhrs' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'contentmargin',
            [
                'label' =>   esc_html__( 'Margin', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .iconinfo,{{WRAPPER}} .openhrs' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings();
        $gmapkey = cs_get_option('gmapkey','',TBOPT);
        $zoom = $settings['show_zoom'] ? '<div id="wa-zoom-in">+</div><div id="wa-zoom-out">-</div>' : '';
       ($settings['show_zoom']);
        ?>

        <div class="ae-gmap">
            <div id="google-container-<?php echo $this->get_id(); ?>"></div>
            <?php  echo $zoom;?>
            <?php if ($settings['style']=='style_two'){?>
                <div class="map-info"><?php $this->show_info($settings['items']) ?></div> 
            <?php }?>
               
        </div>
    <script type='text/javascript' src='//maps.googleapis.com/maps/api/js?key=<?php echo $gmapkey;?>'></script>    
    <script type='text/javascript'>
        (function($) {
            $(document).ready(function() {
                if (typeof google !== 'undefined'){


                //set your google maps parameters
                var latitude = '<?php echo $settings['lat'];?>',
                    longitude = '<?php echo $settings['long'];?>',
                    map_zoom = <?php echo $settings['zoom']['size'];?>;
                
                var style= [{"featureType":"water","elementType":"geometry","stylers":[{"color":"#e9e9e9"},{"lightness":17}]},{"featureType":"landscape","elementType":"geometry","stylers":[{"color":"#f5f5f5"},{"lightness":20}]},{"featureType":"road.highway","elementType":"geometry.fill","stylers":[{"color":"#ffffff"},{"lightness":17}]},{"featureType":"road.highway","elementType":"geometry.stroke","stylers":[{"color":"#ffffff"},{"lightness":29},{"weight":0.2}]},{"featureType":"road.arterial","elementType":"geometry","stylers":[{"color":"#ffffff"},{"lightness":18}]},{"featureType":"road.local","elementType":"geometry","stylers":[{"color":"#ffffff"},{"lightness":16}]},{"featureType":"poi","elementType":"geometry","stylers":[{"color":"#f5f5f5"},{"lightness":21}]},{"featureType":"poi.park","elementType":"geometry","stylers":[{"color":"#dedede"},{"lightness":21}]},{"elementType":"labels.text.stroke","stylers":[{"visibility":"on"},{"color":"#ffffff"},{"lightness":16}]},{"elementType":"labels.text.fill","stylers":[{"saturation":36},{"color":"#333333"},{"lightness":40}]},{"elementType":"labels.icon","stylers":[{"visibility":"off"}]},{"featureType":"transit","elementType":"geometry","stylers":[{"color":"#f2f2f2"},{"lightness":19}]},{"featureType":"administrative","elementType":"geometry.fill","stylers":[{"color":"#fefefe"},{"lightness":20}]},{"featureType":"administrative","elementType":"geometry.stroke","stylers":[{"color":"#fefefe"},{"lightness":17},{"weight":1.2}]}]

                //set google map options
                var map_options = {
                    center: new google.maps.LatLng(latitude, longitude),
                    zoom: map_zoom,
                    panControl: false,
                    zoomControl: false,
                    mapTypeControl: false,
                    streetViewControl: false,
                    mapTypeId: google.maps.MapTypeId.ROADMAP,
                    scrollwheel: false,
                    styles: style,

                }

                //inizialize the map
                var map = new google.maps.Map(document.getElementById('google-container-<?php echo $this->get_id(); ?>'), map_options);
                //add a custom marker to the map                
                var marker = new google.maps.Marker({
                    position: new google.maps.LatLng(latitude, longitude),
                    map: map,
                    visible: true,
                    clickable: true,

                });

                marker.info = new google.maps.InfoWindow({
                  content: '<?php echo $settings['desc'];?>'
                });

                google.maps.event.addListener(marker, 'click', function() {
                  marker.info.open(map, marker);
                });                
            //add custom buttons for the zoom-in/zoom-out on the map
            function CustomZoomControl(controlDiv, map) {
                //grap the zoom elements from the DOM and insert them in the map 
                var controlUIzoomIn= document.getElementById('wa-zoom-in'),
                    controlUIzoomOut= document.getElementById('wa-zoom-out');
                controlDiv.appendChild(controlUIzoomIn);
                controlDiv.appendChild(controlUIzoomOut);

                // Setup the click event listeners and zoom-in or out according to the clicked element
                google.maps.event.addDomListener(controlUIzoomIn, 'click', function() {
                    map.setZoom(map.getZoom()+1)
                });
                google.maps.event.addDomListener(controlUIzoomOut, 'click', function() {
                    map.setZoom(map.getZoom()-1)
                });
            }

            var zoomControlDiv = document.createElement('div');
            var zoomControl = new CustomZoomControl(zoomControlDiv, map);
            var controlUIzoomIn= document.getElementById('wa-zoom-in');

            map.controls[google.maps.ControlPosition.LEFT_TOP].push(zoomControlDiv);
            
                }
            });

        })(jQuery); 
    </script>
        

        <?php
    }

    private function show_info($label){
        if(!is_array($label)){
            return;
        }
        foreach ($label as $a){
            $type = $a['type'];

            switch ($type) {
                case "heading":
                    echo '<h3 class="title">'.$a['head'].'</h3>';
                    break;
                case "iconbox":
                    echo '<div class="iconinfo"><i class="'.$a['icon'].'"></i>'.$a['content'].'</div>';
                    break;
                case "openhrs":
                    echo '<div class="openhrs"><span class="range">'.$a['range'].'</span><span class="open">'.$a['open'].'</span></div>';
                    break;
            }

        }
    }

}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_gmap());