<?php

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_heading_2 extends Widget_Base {

    public function get_name() {
        return 'lae-heading';
    }

    public function get_title() {
        return   esc_html__('HEADING 2', 'thepack');
    }

    public function get_icon() {
        return 'eicon-editor-h1';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_heading',
            [
                'label' =>   esc_html__('Heading', 'thepack'),
            ]
        );

        $this->add_control(
            'heading',
            [
                'type' => 'textarea',
                'label' =>   esc_html__('Heading Title', 'thepack'),
                'label_block' => true,
                'separator' => 'before',
                'default' =>   esc_html__('Heading Title', 'thepack'),
            ]
        );

        $this->add_control(
            'ftag',
            [
                'type' => Controls_Manager::SELECT,
                'label' =>   esc_html__('Header tag', 'thepack'),
                'default' => 'h2',
                'options' => [
                    'h1' =>   esc_html__('H1', 'thepack'),
                    'h2' =>   esc_html__('H2', 'thepack'),
                    'h3' =>   esc_html__('H3', 'thepack'),
                    'h4' =>   esc_html__('H4', 'thepack'),
                    'span' =>   esc_html__('Span', 'thepack'),
                    'p' =>   esc_html__('p', 'thepack'),
                ],
            ]
        );

        $this->add_control(
            'sub_head',
            [
                'type' => 'textarea',
                'label' =>   esc_html__('Sub Heading', 'thepack'),
                'label_block' => true,
                'separator' => 'before',
                'default' =>   esc_html__('Nullam vestibulum nibh quis nisl condimentum molestie.', 'thepack'),
            ]
        );

        $this->add_control(
            'rtag',
            [
                'type' => Controls_Manager::SELECT,
                'label' =>   esc_html__('Sub header tag', 'thepack'),
                'default' => 'h2',
                'options' => [
                    'h1' =>   esc_html__('H1', 'thepack'),
                    'h2' =>   esc_html__('H2', 'thepack'),
                    'h3' =>   esc_html__('H3', 'thepack'),
                    'h4' =>   esc_html__('H4', 'thepack'),
                    'span' =>   esc_html__('Span', 'thepack'),
                    'p' =>   esc_html__('p', 'thepack'),
                ],
            ]
        );

        $this->add_control(
            'align',
            [
                'label' =>   esc_html__('Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' =>   esc_html__('Justified', 'thepack'),
                        'icon' => 'fa fa-align-justify',
                    ],
                ],
                'default' => 'center',
                'selectors' => [
                    '{{WRAPPER}} .lae-heading' => 'text-align: {{VALUE}};',
                ],                 
            ]
        );

        $this->add_control(
            'bar',
            [
                'label' =>   esc_html__('Line bar', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    '' => [
                        '' =>   esc_html__('None', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'leftbar' => [
                        'title' =>   esc_html__('Leftbar', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'rightbar' => [
                        'title' =>   esc_html__('Rightbar', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ],
                ],               
            ]
        );

        $this->add_control(
            'show_vbar',
            [
                'label' =>   esc_html__( 'Vertical bar', 'thepack' ),
                'type' => Controls_Manager::SWITCHER,
            ]
        );

        $this->end_controls_section();



        $this->start_controls_section(
            'section_styling',
            [
                'label' =>   esc_html__('Title', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
 
        $this->add_responsive_control(
            'title-mar',
            [
                'label' =>   esc_html__('Title margin', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .main-head' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'heading_color',
            [
                'label' =>   esc_html__('Heading Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .main-head' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'heading_typography',
                'label' =>   esc_html__('Typography', 'thepack'),
                'selector' => '{{WRAPPER}} .main-head',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'sub_styling',
            [
                'label' =>   esc_html__('Subtitle', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'subtitle-mar',
            [
                'label' =>   esc_html__('Title margin', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .sub-heading' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'sub_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .sub-heading' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'sub_typography',
                'label' =>   esc_html__('Typography', 'thepack'),
                'selector' => '{{WRAPPER}} .sub-heading',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_vbar',
            [
                'label' =>   esc_html__('Vertical line', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'show_vbar' => 'yes',
                ],                
            ]
        );

        $this->add_responsive_control(
            'dv-wd',
            [
                'label' =>   esc_html__( 'Width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 20,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .vbar' => 'width: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'dhv-wd',
            [
                'label' =>   esc_html__( 'Height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .vbar' => 'height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'dv-clr',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .vbar' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'sub_leftbar',
            [
                'label' =>   esc_html__('Bar', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'bar_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .leftbar .main-head:before,{{WRAPPER}} .rightbar .main-head:after' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'bar_width',
            [
                'label' =>   esc_html__('Bar width', 'thepack'),
                'type' => Controls_Manager::SLIDER,
                'default' => [
                    'size' => 18,
                ],
                'selectors' => [
                    '{{WRAPPER}} .leftbar .main-head:before,{{WRAPPER}} .rightbar .main-head:after' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';
    }

    protected function content_template() {
    }

}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_heading_2());