<?php

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Background;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_heading_3 extends Widget_Base {

    public function get_name() {
        return 'heading3';
    }

    public function get_title() {
        return   esc_html__('HEADING 3', 'thepack');
    }

    public function get_icon() {
        return 'eicon-editor-h1';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_heading',
            [
                'label' =>   esc_html__('Heading', 'thepack'),
            ]
        );

        $this->add_control(
            'heading',
            [
                'type' => 'textarea',
                'label' =>   esc_html__('Heading Title', 'thepack'),
                'label_block' => true,
                'separator' => 'before',
                'default' =>   esc_html__('Heading Title', 'thepack'),
            ]
        );

        $this->add_control(
            'ftag',
            [
                'type' => Controls_Manager::SELECT,
                'label' =>   esc_html__('Header tag', 'thepack'),
                'default' => 'h2',
                'options' => [
                    'h1' =>   esc_html__('H1', 'thepack'),
                    'h2' =>   esc_html__('H2', 'thepack'),
                    'h3' =>   esc_html__('H3', 'thepack'),
                    'h4' =>   esc_html__('H4', 'thepack'),
                    'span' =>   esc_html__('Span', 'thepack'),
                    'p' =>   esc_html__('p', 'thepack'),
                ],
            ]
        );

        $this->end_controls_section();



        $this->start_controls_section(
            'section_gen',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'tmpl',
            [
                'label' =>   esc_html__('Template', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'one' => [
                        'title' =>   esc_html__('Normal', 'thepack'),
                        'icon' => 'fa fa-folder',
                    ],
                    'two' => [
                        'title' =>   esc_html__('Text clip', 'thepack'),
                        'icon' => 'fa fa-folder-o',
                    ],
                ],
                'default' => 'one',               
            ]
        );

        $this->add_responsive_control(
            'title-mar',
            [
                'label' =>   esc_html__('Padding', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .main-head' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'heading_typography',
                'label' =>   esc_html__('Typography', 'thepack'),
                'selector' => '{{WRAPPER}} .main-head',
            ]
        );

        $this->add_control(
            'align',
            [
                'label' =>   esc_html__('Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' =>   esc_html__('Justified', 'thepack'),
                        'icon' => 'fa fa-align-justify',
                    ],
                ],
                'default' => 'center',
                'selectors' => [
                    '{{WRAPPER}} .tbheading3' => 'text-align: {{VALUE}};',
                ],                 
            ]
        );

        $this->add_control(
            'bdclr',
            [
                'label' =>   esc_html__('Border Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .main-head' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'bdwd',
            [
                'label' =>   esc_html__( 'Border width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 20,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .main-head' => 'border-width: {{SIZE}}{{UNIT}};border-style:solid;',
                ],

            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'sub_styling',
            [
                'label' =>   esc_html__('Background & color', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );


        $this->add_control(
            'tclr',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .main-head' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'tmpl' => 'one',
                ],                
            ]
        );

        $this->add_control(
            'tstrk',
            [
                'label' =>   esc_html__('Text stroke color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .main-head' => '-webkit-text-stroke-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'tstrkwd',
            [
                'label' =>   esc_html__( 'Text stroke width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 20,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .main-head' => '-webkit-text-stroke-width: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
          'html_msg',
          [
             'type'    => Controls_Manager::RAW_HTML,
             'raw' =>   esc_html__( '<b>Text background</b>', 'thepack' ),
          ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'bgrt',
                'label' =>   esc_html__( 'Background', 'elementor' ),
                'types' => [ 'none', 'classic','gradient' ],
                'selector' => '{{WRAPPER}} .main-head',                
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';
    }

    protected function content_template() {
    }

}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_heading_3());