<?php

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Border;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_iknbox extends Widget_Base {

    public function get_name() {
        return 'tb-ikbx';
    }

    public function get_title() {
        return   esc_html__('ICONBOX', 'thepack');
    }

    public function get_icon() {
        return 'eicon-image-box';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_team',
            [
                'label' =>   esc_html__('Iconbox', 'thepack'),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'type', [
                'type' => Controls_Manager::CHOOSE,
                'label' =>   esc_html__('Icon/Image', 'thepack'),
                'options' => [
                    'icon' => [
                        'title' =>   esc_html__('Icon', 'thepack'),
                        'icon' => ' eicon-document-file',
                    ],
                    'image' => [
                        'title' =>   esc_html__('Image', 'thepack'),
                        'icon' => 'eicon-image-rollover',
                    ]
                ],
                'default' => 'icon',               
            ]
        );

        $repeater->add_control(
            'ico', [
                'type' => Controls_Manager::ICON,
                'label' =>   esc_html__('Icon', 'thepack'),
                'label_block' => true,
                'condition' => [
                    'type' => 'icon',
                ],             
            ]
        );

        $repeater->add_control(
            'img', [
                'type' => Controls_Manager::MEDIA,
                'label' =>   esc_html__('Image', 'thepack'),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'type' => 'image',
                ],                        
                'label_block' => true,               
            ]
        );
        
        $repeater->add_control(
            'title', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Title', 'thepack'),
                'label_block' => true,               
            ]
        );

        $repeater->add_control(
            'sub', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Sub title', 'thepack'),
                'label_block' => true,               
            ]
        );

        $repeater->add_control(
            'description', [
                'type' => Controls_Manager::TEXTAREA,
                'label' =>   esc_html__('Description', 'thepack'),
                'label_block' => true,               
            ]
        );

        $repeater->add_control(
            'link-title', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Link title', 'thepack'),
                'label_block' => true,               
            ]
        );

        $repeater->add_control(
            'link', [
                'type' => Controls_Manager::URL,
                'label' =>   esc_html__('Link', 'thepack'),
                'label_block' => true,
                'placeholder' => 'http://your-link.com',
                'default' => [
                    'url' => '#',
                ],                                
            ]
        );


        $this->add_control(
            'services',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'prevent_empty' => false,
                'default' => [
                    [
                        'title' =>   esc_html__( 'Year', 'thepack' ),
                    ]
                ],
                'title_field' => '{{{ title }}}',
            ]
        );

        $this->add_control(
            'ico_position',
            [
                'label' =>   esc_html__('Icon Position', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'icenter' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'ileft' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'itop' => [
                        'title' =>   esc_html__('Top', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ],                    
                ],
                'default' => 'center',               
            ]
        );

        $this->add_control(
            'align_txt',
            [
                'label' =>   esc_html__('Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' =>   esc_html__('Justified', 'thepack'),
                        'icon' => 'fa fa-align-justify',
                    ],
                ],
                'default' => 'center',   
                'selectors' => [
                    '{{WRAPPER}} .service-wrap' => 'text-align: {{VALUE}};',
                ],                            
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_team_display',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'show_label' => false,
            ]
        );

        $this->add_responsive_control(
            'width',
            [
                'label' =>   esc_html__( 'Column width', 'thepack' ),
                'type' =>  Controls_Manager::NUMBER, 
                'default' => '33.33',
                 'selectors' => [
                        '{{WRAPPER}} .equalHMV' => 'width: {{VALUE}}%;',
                 ],                              
            ]
        ); 

        $this->add_responsive_control(
            'gpadr',
            [
                'label' =>   esc_html__( 'Column spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ]
                ],
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} .equalHMV' => 'padding: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .equalHMVWrap' => 'margin:0px -{{SIZE}}{{UNIT}};',
                ],

            ]
        );
        $this->add_responsive_control(
            'min-height',
            [
                'label' =>   esc_html__( 'Height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 1000,
                        'step' => 1,
                    ]
                ],
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} .equalHMV' => 'height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'itmbsp',
            [
                'label' =>   esc_html__( 'Bottom spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 500,
                        'step' => 1,
                    ]
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .equalHMV' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'team_box',
            [
                'label' =>   esc_html__('Inner Padding', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .service-wrap' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );

        $this->add_control(
            'team_box_bg',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-wrap' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            '3_border_bottom',
            [
                'label' =>   esc_html__('Bottom border color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-wrap' => 'border-bottom:3px solid {{VALUE}};',
                ],
                'condition' => [
                    'style'    => 'style_three',
                ],                
            ]
        );

        $this->add_control(
            'animation',
            [
                'label' =>   esc_html__('Animation', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'options' =>  thepack_animations(), 
                'multiple' => false,
                'label_block' => true,               
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_figure',
            [
                'label' =>   esc_html__('Icon/Image', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'fig_width',
            [
                'label' =>   esc_html__( 'Width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ]
                ],
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} .figure' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'fig_rad',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ]
                ],
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} .figure' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'fig_fontsize',
            [
                'label' =>   esc_html__( 'Font size', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,

                'selectors' => [
                    '{{WRAPPER}} .figure' => 'font-size: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'fig_top',
            [
                'label' =>   esc_html__( 'Top Distance', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,

                'selectors' => [
                    '{{WRAPPER}} .figwrap' => 'top: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'fig_left',
            [
                'label' =>   esc_html__( 'Left Distance', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,

                'selectors' => [
                    '{{WRAPPER}} .figwrap' => 'left: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'fig_right',
            [
                'label' =>   esc_html__( 'Right Distance', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,

                'selectors' => [
                    '{{WRAPPER}} .figwrap' => 'right: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'fig_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .figure' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'fig_bg',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .figure' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_team_member_title',
            [
                'label' =>   esc_html__('Title', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .title' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'title_margin',
            [
                'label' =>   esc_html__('Margin', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .title',
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'section_team_member_stitle',
            [
                'label' =>   esc_html__('Sub title', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'stitle_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sub' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'stitle_margin',
            [
                'label' =>   esc_html__('Margin', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .sub' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'stitle_typography',
                'selector' => '{{WRAPPER}} .sub',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_team_member_details',
            [
                'label' =>   esc_html__('Details', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'text_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .description' => 'color: {{VALUE}};',
                ],
            ]
        ); 
        $this->add_responsive_control(
            'details_margin',
            [
                'label' =>   esc_html__('Margin', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'text_typography',
                'selector' => '{{WRAPPER}} .description',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_button',
            [
                'label' =>   esc_html__('Button', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typo',
                'selector' => '{{WRAPPER}} .ash-btn',
                'label' =>   esc_html__( 'Typo', 'thepack' ),              
            ]
        );

        $this->add_responsive_control(
            'btn_padding',
            [
                'label' =>   esc_html__( 'Padding', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .ash-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'btn_margin',
            [
                'label' =>   esc_html__( 'Button Margin', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%','em' ],
                'selectors' => [
                    '{{WRAPPER}} .ash-btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'btn_border-width',
            [
                'label' =>   esc_html__( 'Border width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .ash-btn' => 'border-width: {{SIZE}}{{UNIT}};border-style:solid;',
                ],

            ]
        ); 


        $this->add_control(
            'btn_border-radius',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .ash-btn' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'btn_color',
            [
                'label' =>   esc_html__( 'Button background', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ash-btn' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btntxt_color',
            [
                'label' =>   esc_html__( 'Button text color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ash-btn' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btnborder_color',
            [
                'label' =>   esc_html__( 'Border color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ash-btn' => 'border-color: {{VALUE}};',
                ],
            ]
        );  

        $this->add_control(
            'btnbg_color_hover',
            [
                'label' =>   esc_html__( 'Hover Button background', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ash-btn:hover' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btntxt_color_hover',
            [
                'label' =>   esc_html__( 'Hover Button text color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ash-btn:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btnborder_color_hover',
            [
                'label' =>   esc_html__( 'Hover Border color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ash-btn:hover' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {
        $settings = $this->get_settings();
         
        require dirname(__FILE__) .'/view.php';
    }

}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_iknbox());