<?php

/*
Widget Name: Webangon Imagelayer
Description: Create image layers
Author: Webangon
Author URI: https://www.webangon.com
*/

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Scheme_Typography;
use Elementor\Utils;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_image_layer extends Widget_Base {

    public function get_name() {
        return 'ue_image_layer';
    }

    public function get_title() {
        return   esc_html__('IMAGE LAYER', 'thepack');
    }

    public function get_icon() {
        return 'eicon-insert-image';
    }
    
    public function get_categories() {
        return array('ashelement-addons');
    } 

    protected function _register_controls() {

        $this->start_controls_section(
            'section_heading',
            [
                'label' =>   esc_html__('Button', 'thepack'),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'zindex', [
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'label' =>   esc_html__('Z-index', 'thepack'),             
            ]
        );

        $repeater->add_control(
            'position', [
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px'],
                'isLinked' => false,
                'label' =>   esc_html__('Margin', 'thepack'),
            ]
        );       

        $repeater->add_control(
            'animation', [
                'label' =>   esc_html__('Animation', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'options' =>  thepack_animations(), 
                'multiple' => false,
                'label_block' => true 
            ]
        );

        $repeater->add_control(
            'img', [
                'label' =>   esc_html__( 'Image', 'thepack' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'label_block' => true,
            ]
        );

        $this->add_control(
            'image_layers',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(), 
                'prevent_empty' => false,
                'default' => [
                    [
                        'zindex' =>   esc_html__( '01', 'thepack' ),
                    ]
                ],
                'title_field' => '{{{ zindex }}}',
            ]
        );


/*        $this->add_control(
            'icon_align',
            [
                'label' =>   esc_html__( 'Icon Position', 'elementor' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'left',
                'options' => [
                    'left' =>   esc_html__( 'Before', 'elementor' ),
                    'right' =>   esc_html__( 'After', 'elementor' ),
                ],
                'condition' => [
                    'icon!' => '',
                ],
            ]
        );*/

/*        $this->add_control(
            'box_shadow',
            [
                'label' =>   esc_html__( 'Box Shadow', 'thepack' ),
                'type' => Controls_Manager::BOX_SHADOW,
                'default' => [
                    'color' => 'rgba(0,0,0,.5)',
                ],
                'selectors' => [
                    '{{WRAPPER}} .layer-item img' => 'box-shadow: {{HORIZONTAL}}px {{VERTICAL}}px {{BLUR}}px {{SPREAD}}px {{COLOR}};',
                ],
            ]
        );*/

        $this->end_controls_section();


        $this->start_controls_section(
            'section_subtitle',
            [
                'label' =>   esc_html__('Style', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label' =>   esc_html__('Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' =>   esc_html__('Justified', 'thepack'),
                        'icon' => 'fa fa-align-justify',
                    ],
                ],
                'default' => 'center',
                'selectors' => [
                    '{{WRAPPER}} .layer-img' => 'text-align: {{VALUE}};',
                ],                
            ]
        );

        $this->add_control(
            'img_size',
            [
                'label' =>   esc_html__('Image size', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' =>  thepack_image_size_choose(), 
                'multiple' => false,                                
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings();
        $layers = $settings['image_layers'];
        $img_size = $settings['img_size'];
        if (empty($layers))
            return;        
        echo '<div class="layer-img">';
             foreach ($layers as $item): 
                $id = $item['img']['id'];
                $animation = $item['animation'];

                $zindex = $item['zindex']['size'];
                $u = 'px;';
                $t = $item['position']['top'];
                $b = $item['position']['bottom'];
                $l = $item['position']['left'];
                $r = $item['position']['right'];

                $top=( isset($t) && $t) ? 'top:'.$t.$u.'' : '';
                $bottom=( isset($b) && $b) ? 'bottom:'.$b.$u.'' : '';
                $left=( isset($l) && $l) ? 'left:'.$l.$u.'' : '';
                $right=( isset($r) && $r) ? 'right:'.$r.$u.'' : '';

                $zindex=( isset($zindex) && $zindex) ? 'z-index:'.$zindex.'' : '';

                $img= wp_get_attachment_image($id, $img_size);
                echo '<div style="'.$top.$bottom.$left.$right.$zindex.'" class="layer-item '.$animation.'">';
                echo $img;
                //echo '<a href="#">'.$img.'</a>';
                echo '</div>';
                ($top);
                
            ?>
            <?php endforeach;?>
        </div>

    <?php }

    protected function content_template() {
    }

}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_image_layer());