<?php

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Scheme_Typography;
use Elementor\utils;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_imgbox1 extends Widget_Base {

    public function get_name() {
        return 'tb_imgbox1';
    }

    public function get_title() {
        return   esc_html__('IMAGEBOX 1', 'thepack');
    }

    public function get_icon() {
        return 'eicon-sync';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_process_1',
            [
                'label' =>   esc_html__('Content', 'thepack'),
            ]
        );


        $this->add_control(
            'tmpl',
            [
                'label' =>   esc_html__('Template', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'one' => [
                        'title' =>   esc_html__('One', 'thepack'),
                        'icon' => 'fa fa-folder',
                    ],
                    'two' => [
                        'title' =>   esc_html__('Two', 'thepack'),
                        'icon' => 'fa fa-folder-o',
                    ],

                    'three' => [
                        'title' =>   esc_html__('Three', 'thepack'),
                        'icon' => 'fa fa-folder-open',
                    ],

                ], 
                'default' => 'one',               
            ]
        );

        $repeater1 = new \Elementor\Repeater();

        $repeater1->add_control(
            'img', [
                'type' => Controls_Manager::MEDIA,
                'label' =>   esc_html__('Image', 'thepack'),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $repeater1->add_control(
            'label', [
                'label' =>   esc_html__( 'Heading', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Awards & Accolades',               
            ]
        );

        $repeater1->add_control(
            'tikn', [
                'label' =>   esc_html__( 'Icon', 'thepack' ),
                'type' => Controls_Manager::ICON,
                'label_block' => true,              
            ]
        );

        $repeater1->add_control(
            'desc', [
                'label' =>   esc_html__( 'Description', 'thepack' ),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,               
            ]
        );

        $repeater1->add_control(
            'btn', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Button Label', 'thepack'),
                'label_block' => true,              
            ]
        );

        $repeater1->add_control(
            'icon', [
                'label' =>   esc_html__( 'Button icon', 'thepack' ),
                'type' => Controls_Manager::ICON,
                'label_block' => true,
                'default' => 'fa fa-plus',                               
            ]
        );

        $repeater1->add_control(
            'url', [
                'label' =>   esc_html__('Button url', 'thepack'),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'placeholder' =>   esc_html__('http://your-link.com', 'thepack'),
            ]
        );

        $this->add_control(
            'items',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater1->get_controls(), 
                'prevent_empty' => false,
                'default' => [
                    [
                        'label' =>   esc_html__( 'Awards & Accolades', 'thepack' ),
                    ]
                ],
                'title_field' => '{{{label}}}',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'display',
            [
                'label' =>   esc_html__('Display - Carousel or grid', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'grid' => [
                        'title' =>   esc_html__('Grid', 'thepack'),
                        'icon' => 'fa fa-th-large',
                    ],
                    'carousel' => [
                        'title' =>   esc_html__('Carousel', 'thepack'),
                        'icon' => 'fa fa-window-restore',
                    ],
                ],  

                'default' => 'grid',                 
            ]
        );

        $this->add_control(
            'align',
            [
                'label' =>   esc_html__('Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ]
                ], 
                'selectors' => [
                    '{{WRAPPER}} .items-wrap' => 'text-align: {{VALUE}};',
                ],                 
            ]
        );

        $this->add_control(
            'grid_col',
            [
                'label' =>   esc_html__('Items per row', 'thepack'),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 6,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],               
            ]
        );

        $this->add_control(
            'animation',
            [
                'label' =>   esc_html__('Animation', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'options' =>  thepack_animations(), 
                'label_block' => true 
            ]
        );

        $this->add_control(
            'g_bg',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .items-wrap' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
          'g_pad',
          [
             'label' =>   esc_html__( 'Padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             
             'selectors' => [
                    '{{WRAPPER}} .desc-wrap' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
                [
                    'label'         =>   esc_html__('Box Shadow','thepack'),
                    'name'          => 'img_box_sha',
                    'selector'      => '{{WRAPPER}} .items-wrap',
                ]
        );
        $this->end_controls_section(); 

        $this->start_controls_section(
            'section_iknbx',
            [
                'label' =>   esc_html__('Icon Box', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,                 
            ]
        );

        $this->add_responsive_control(
            'ikn_wd',
            [
                'label' =>   esc_html__( 'Width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .top-ikon' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'ikn_fs',
            [
                'label' =>   esc_html__( 'Font size', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                        'step' => 1,
                    ],                   
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .top-ikon' => 'font-size: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'ikn_vp',
            [
                'label' =>   esc_html__( 'Iconbox vertical position', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => -500,
                        'max' => 500,
                        'step' => 1,
                    ],                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .top-ikon' => 'top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'ikn_lh',
            [
                'label' =>   esc_html__( 'Icon position', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                        'step' => 1,
                    ],                   
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .top-ikon' => 'line-height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'ikbg_clr',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .top-ikon' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'iktx_clr',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .top-ikon' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'ikn_br',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                        'step' => 1,
                    ],                   
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .top-ikon' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_head',
            [
                'label' =>   esc_html__('Title', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,                 
            ]
        );

        $this->add_control(
            'h_clr',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .heading' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'h_mr',
            [
                'label' =>   esc_html__( 'Margin', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .heading' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'h_typo',
                'label' =>   esc_html__('Typography', 'thepack'),
                'selector' => '{{WRAPPER}} .heading',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_desc',
            [
                'label' =>   esc_html__('Description', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,                 
            ]
        );


        $this->add_control(
            'desc_clr',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .desc' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'desc_pad',
            [
                'label' =>   esc_html__( 'Padding', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .desc' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'desc_typo',
                'label' =>   esc_html__('Typography', 'thepack'),
                'selector' => '{{WRAPPER}} .desc',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_btn',
            [
                'label' =>   esc_html__('Link button', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,                 
            ]
        );


        $this->add_control(
            'btnlbl_clr',
            [
                'label' =>   esc_html__('Label Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn-text' => 'color: {{VALUE}};',
                ],
            ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btnlbl_typo',
                'label' =>   esc_html__('Typography', 'thepack'),
                'selector' => '{{WRAPPER}} .btn-text',
            ]
        );

        $this->add_control(
            'btnico_clr',
            [
                'label' =>   esc_html__('Icon Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btnimgbx1-icon' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {
        $settings = $this->get_settings();      
        require dirname(__FILE__) .'/view.php';
    }


    private function content($content,$template,$column) {

        foreach ($content as $item){

            $id = $item['img']['id'];
            $img = $id ? '<figure>'.wp_get_attachment_image($id, 'full'). '</figure>' : '';
            $label = $item['label'] ? '<h2 class="heading">'.$item['label']. '</h2>' : '';
            $desc = $item['desc'] ? '<p class="desc">'.$item['desc']. '</p>' : '';

            $url = $item['url']['url'];
            $ext = $item['url']['is_external'];
            $nofollow = $item['url']['nofollow'];
            $url = ( isset($url) && $url ) ? 'href='.esc_url($url). '' : '';
            $ext = ( isset($ext) && $ext ) ? 'target= _blank' : '';
            $nofollow = ( isset($url) && $url ) ? 'rel=nofollow' : '';
            $link = $url.' '.$ext.' '.$nofollow;
            $icon = $item['icon'] ? '<span class="btnimgbx1-icon"><i class="'.$item['icon'].'"></i></span>' : '';

            $btn = $item['btn'] ? '<a '.$link.' class="btnimgbx1"><span class="btn-text">'.$item['btn'].'</span>'.$icon.'</a>' : '';

            $tikn = $item['tikn'] ? '<span class="top-ikon"><i class="'.$item['tikn'].'"></i></span>' : '';

            $out1 .= '
             <div class="items '.$column.'">
                <div class="items-wrap">
                '.$img.'
                <div class="desc-wrap">
                '.$tikn.'
                '.$label.$desc.'
                </div>
                '.$btn.'
                </div>
            </div>
            '; 

            $out2 .= '
                <li><a class="ulink '.$column.'" href="#" target="_blank">'.$item['title'].'</a></li>
            ';

            $out3 .= '
                <li><a class="'.$column.'" href="#" target="_blank"><span class="icon '.$item['icon'].'"></span></a></li>
            ';

        }
        if ($template == 'one'){
            return $out1;
        } elseif ($template == 'two') {
            return '<ul>'.$out2.'</ul>';
        } elseif ($template == 'three') {
            return '<ul>'.$out3.'</ul>';
        } else {

        }
        
    }
    

}

 $widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_imgbox1());