<?php

/*
Widget Name: Livemesh Stats Bars
Description: Display multiple stats bars that talk about skills or other percentage stats.
Author: LiveMesh
Author URI: https://www.livemeshthemes.com
*/


namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Background;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_insta_feed extends Widget_Base {

    public function get_name() {
        return 'ae-instafeed';
    }

    public function get_title() {
        return   esc_html__('INSTAGRAM', 'thepack');
    }

    public function get_icon() {
        return 'eicon-skill-bar';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_progress_bar',
            [
                'label' =>   esc_html__('Instagram', 'thepack'),
            ]
        );

        $this->add_control(
            'username',
            [
                'label' =>   esc_html__('Username', 'thepack'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'images',
            [
                'label' =>   esc_html__( 'No of images', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,               
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px']
            ]
        );

        $this->add_control(

            'size', [
                'type' => Controls_Manager::SELECT,
                'label' =>   esc_html__('Image size', 'thepack'),
                'default' => 'thumbnail',
                'options' => [
                    'thumbnail' =>   esc_html__('Thumbnail', 'thepack'),
                    'small' =>   esc_html__('Small', 'thepack'),
                    'large' =>   esc_html__('Large', 'thepack'),
                    'original' =>   esc_html__('Original', 'thepack'),
                ],
            ]
        );

        $this->add_control(

            'link', [
                'type' => Controls_Manager::SELECT,
                'label' =>   esc_html__('Link to', 'thepack'),
                'default' => 'url',
                'options' => [
                    'image' =>   esc_html__('Image', 'thepack'),
                    'url' =>   esc_html__('Instagram site', 'thepack'),
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'overlytpl',
            [
                'label' =>   esc_html__('Overlay template', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'clike' => [
                        'title' =>   esc_html__('Comment like', 'thepack'),
                        'icon' => 'eicon-gallery-grid',
                    ],
                    'zplus' => [
                        'title' =>   esc_html__('Zoom plus', 'thepack'),
                        'icon' => 'eicon-gallery-masonry',
                    ]

                ],
                'default' => 'grid',               
            ]
        );

        $this->add_control(
            'disp',
            [
                'label' =>   esc_html__('Display style', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'grid' => [
                        'title' =>   esc_html__('Grid', 'thepack'),
                        'icon' => 'fa fa-folder',
                    ],
                    'carousel' => [
                        'title' =>   esc_html__('Carousel', 'thepack'),
                        'icon' => 'fa fa-folder-o',
                    ]

                ],
                'default' => 'grid',               
            ]
        );

        $this->add_control(
            'mason',
            [
                'label' =>   esc_html__( 'Enable masonry', 'elementor' ),
                'type' => Controls_Manager::SWITCHER,
                'return_value' => 'masonon',
                'condition' => [
                    'disp' => 'grid',
                ],                
            ]
        );

        $this->add_responsive_control(
            'width',
            [
                'label' =>   esc_html__( 'Column width', 'thepack' ),
                'type' =>  Controls_Manager::NUMBER, 
                'default' => '33.33',
                'condition' => [
                    'disp' => 'grid',
                ],                 
                 'selectors' => [
                        '{{WRAPPER}} .insta-item' => 'width: {{VALUE}}%;',
                 ],                              
            ]
        );

        $this->add_control(
            'pad',
            [
                'label' =>   esc_html__( 'Padding', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 20,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .insta-item' => 'padding:{{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .insta-item-wrap1' => 'margin:0px -{{SIZE}}{{UNIT}};'
                ],

            ]
        );

        $this->add_control(
            'icom', [
                'label' =>   esc_html__( 'Comment icon', 'thepack' ),
                'type' => Controls_Manager::ICON,
                'label_block' => true,
                'default' => 'fa fa-plus', 
                'condition' => [
                    'overlytpl' => 'clike',
                ],                                                
            ]
        );

        $this->add_control(
            'ilik', [
                'label' =>   esc_html__( 'Like icon', 'thepack' ),
                'type' => Controls_Manager::ICON,
                'label_block' => true,
                'default' => 'fa fa-plus',
                'condition' => [
                    'overlytpl' => 'clike',
                ],                                               
            ]
        );

        $this->add_control(
            'picon', [
                'label' =>   esc_html__( 'Plus icon', 'thepack' ),
                'type' => Controls_Manager::ICON,
                'label_block' => true,
                'default' => 'fa fa-plus',
                'condition' => [
                    'overlytpl' => 'zplus',
                ],                                               
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_xtra',
            [
                'label' =>   esc_html__('Overlay', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'imgovrli',
            [
                'label' =>   esc_html__( 'Background overlay', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .insta-item a::before' => 'background: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'cpclr',
            [
                'label' =>   esc_html__( 'Caption color', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .insta-clike,{{WRAPPER}} .content-center .tbicon' => 'color: {{VALUE}};'
                ],
            ]
        );

        $this->add_responsive_control(
            'cpsze',
            [
                'label' =>   esc_html__( 'Caption font size', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,              
                'selectors' => [
                    '{{WRAPPER}} .insta-clike,{{WRAPPER}} .content-center .tbicon' => 'font-size: {{SIZE}}px;',
                ],                             
            ]
        );

        $this->add_control(
          'm1',
          [
             'type'    => Controls_Manager::RAW_HTML,
             'raw' =>   esc_html__( 'Overlay hover background', 'thepack' ),
             'separator ' => 'after',
            'condition' => [
                'overlytpl' => 'zplus',
            ],              
          ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'overlay_color',
                'label' =>   esc_html__( 'Background', 'elementor' ),
                'types' => [ 'none', 'classic','gradient' ],
                'selector' => '{{WRAPPER}} .content-center',
                'condition' => [
                    'overlytpl' => 'zplus',
                ],                
            ]
        );

        $this->end_controls_section();  

        $this->start_controls_section(
            'section_caro',
            [
                'label' =>   esc_html__('Slider control', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'disp' => 'carousel',
                ],                 
            ]
        );

        $this->add_control(
            'dot',
            [
                'label' =>   esc_html__('Display dot', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );

        $this->add_control(
            'auto',
            [
                'label' =>   esc_html__('Autoplay', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );

        $this->add_control(
            'cntr',
            [
                'label' =>   esc_html__('Center mode', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );

        $this->add_control(
            'nav',
            [
                'label' =>   esc_html__('Display arrow', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );


        $this->add_control(
            'mouse',
            [
                'label' =>   esc_html__('Mouse control', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );

        $this->add_control(
            'item',
            [
                'label' =>   esc_html__( 'Item per slide', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'default' => [
                    'size' => 4,
                ],                
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 5,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],               
            ]
        );

        $this->add_control(
            'item_tab',
            [
                'label' =>   esc_html__( 'Item per slide tablets', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'default' => [
                    'size' => 2,
                ],                 
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 5,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],               
            ]
        );

        $this->add_control(
            'speed',
            [
                'label' =>   esc_html__( 'Slide speed', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'default' => [
                    'size' => 2500,
                ],                
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 8000,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],               
            ]
        );

        $this->add_responsive_control(
            'wrpng',
            [
                'label' =>   esc_html__( 'Wrapper negative spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 500,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .slick-list' => 'margin-left: -{{SIZE}}{{UNIT}};margin-right: -{{SIZE}}{{UNIT}};overflow: visible;',
                ],

            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'section_pagi',
            [
                'label' =>   esc_html__('Slider Arrow', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'nav' => 'yes',
                ],                 
            ]
        );

        $this->add_control(
            'prv', [
                'type' => Controls_Manager::ICON,
                'label' =>   esc_html__('Prev icon', 'thepack'),
                'label_block' => true,
                'default' => 'fa-chevron-left',               
            ]
        );

        $this->add_control(
            'nxt', [
                'type' => Controls_Manager::ICON,
                'label' =>   esc_html__('Next icon', 'thepack'),
                'label_block' => true,
                'default' => 'fa-chevron-right',               
            ]
        );

        $this->add_control(
            'pgi_bg',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slknav li' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'pgi_c',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slknav li' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'pgwd',
            [
                'label' =>   esc_html__( 'Width and height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .slknav li' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'lheight',
            [
                'label' =>   esc_html__( 'Line-height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .slknav li' => 'line-height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'pgbrad',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .slknav li' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'avps',
            [
                'label' =>   esc_html__( 'Vertical position', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'size_units' => [ '%'],
                'selectors' => [
                    '{{WRAPPER}} .slknav' => 'top: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_nav',
            [
                'label' =>   esc_html__('Slider Navigation', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'dot' => 'yes',
                ],                
            ]
        );

        $this->add_responsive_control(
            'navpos',
            [
                'label' =>   esc_html__( 'Postion', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 300,
                        'min' => -300,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .slick-dots' => 'bottom: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'navcol',
            [
                'label' =>   esc_html__('Dot color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-dots li button' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'navacol',
            [
                'label' =>   esc_html__('Dot active color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-dots li.slick-active button' => 'box-shadow:0 0 0 2px {{VALUE}};background: #2220;',
                ],
            ]
        );

        $this->end_controls_section();

    }


    protected function render() {

            $settings = $this->get_settings();
            require dirname(__FILE__) .'/view.php';

    }
} 

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_insta_feed());