<?php

/*
Widget Name: Webangon full social
Description: Full width social.
Author: Ashraf
Author URI: https://www.webangon.com
*/ 

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
 
if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_list_2 extends Widget_Base {

    public function get_name() {
        return 'tb_lyst2';
    }

    public function get_title() {
        return   esc_html__('LIST 2', 'thepack');
    }

    public function get_icon() {
        return 'eicon-editor-list-ul';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_pricing_table',
            [
                'label' =>   esc_html__('Lists', 'thepack'),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'title', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Title', 'thepack'),
                'label_block' => true,
                'default' => 'Year',               
            ]
        );

        $repeater->add_control(
            'type', [
                'type' => Controls_Manager::CHOOSE,
                'label' =>   esc_html__('Type', 'thepack'),
                'options' => [
                    'icon' => [
                        'title' =>   esc_html__('Icon', 'thepack'),
                        'icon' => 'fa fa-folder',
                    ],
                    'text' => [
                        'title' =>   esc_html__('Text', 'thepack'),
                        'icon' => 'fa fa-folder-o',
                    ],
                    'default' => 'text',

                ],              
            ]
        );

        $repeater->add_control(
            'icon', [
                'type' => Controls_Manager::ICON,
                'label' =>   esc_html__('Icon', 'thepack'),
                'label_block' => true,
                'condition' => [
                    'type' => 'icon',
                ],                                
            ]
        );

        $repeater->add_control(
            'text', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Text', 'thepack'),
                'label_block' => true,
                'condition' => [
                    'type' => 'text',
                ],                                
            ]
        );

        $this->add_control(
            'lists',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'prevent_empty' => false,
                'default' => [
                    [
                        'title' =>   esc_html__( 'Year', 'thepack' ),
                    ]
                ],
                'title_field' => '{{{ title }}}',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__( 'General', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'animation',
            [
                'label' =>   esc_html__('Animation', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'options' =>  thepack_animations(), 
                'label_block' => true 
            ]
        );
                
        $this->add_responsive_control(
            'margin_bottom',
            [
                'label' =>   esc_html__( 'Margin bottom', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} li' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'padding',
            [
                'label' =>   esc_html__( 'Padding', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'evbg',
            [
                'label' =>   esc_html__( 'Even list background', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} li:nth-child(even)' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'oddbg',
            [
                'label' =>   esc_html__( 'Odd list background', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} li:nth-child(odd)' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_subtitle',
            [
                'label' =>   esc_html__('Heading', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        
        $this->add_control(
            'subtitle_color',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'h_typo',
                'label' =>   esc_html__('Typography', 'thepack'),
                'selector' => '{{WRAPPER}} .title',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_ikn',
            [
                'label' =>   esc_html__('Icon', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'iknris',
            [
                'label' =>   esc_html__( 'Right spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .buletwrp' => 'margin-right:{{SIZE}}px;',
                ],

            ]
        );

        $this->add_responsive_control(
            'wpwid',
            [
                'label' =>   esc_html__( 'Width and height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .buletwrp' => 'width:{{SIZE}}px;height:{{SIZE}}px;',
                ],

            ]
        );

        $this->add_responsive_control(
            'wpbdr',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .buletwrp' => 'border-radius:{{SIZE}}px;',
                ],

            ]
        );

        $this->add_responsive_control(
            'wpbdwid',
            [
                'label' =>   esc_html__( 'Border width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .buletwrp' => 'border-width:{{SIZE}}px;',
                ],

            ]
        );

        $this->add_control(
            'iknbdclr',
            [
                'label' =>   esc_html__( 'Border color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .buletwrp' => 'border-color: {{VALUE}};border-style:solid;',
                ],
            ]
        );

        $this->add_control(
            'iknclr',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .buletwrp' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'iknbg',
            [
                'label' =>   esc_html__( 'Background', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .buletwrp' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typo',
                'selector' => '{{WRAPPER}} .buletwrp',
                'label' =>   esc_html__( 'Typo', 'thepack' ),
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';
    }

}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_list_2());