<?php

/*
Widget Name: ContentBox
Description: Capture services in a multi-column grid.
Author: Webangon
Author URI: https://www.webangon.com
*/ 
 
namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\utils;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly

class thepack_minibox extends Widget_Base {

    public function get_name() {
        return 'tb-cntbx';
    }

    public function get_title() {
        return   esc_html__('MINI BOX', 'thepack');
    }

    public function get_icon() {
        return 'eicon-document-file';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_services',
            [
                'label' =>   esc_html__('Services', 'thepack'),
            ]
        );

        $this->add_control(
            'tmpl',
            [
                'label' =>   esc_html__('Template', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'one' => [
                        'title' =>   esc_html__('One', 'thepack'),
                        'icon' => 'fa fa-folder',
                    ],
                    'two' => [
                        'title' =>   esc_html__('Two', 'thepack'),
                        'icon' => 'fa fa-folder-o',
                    ]

                ],
                'default' => 'one',               
            ]
        );


        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'title', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Heading', 'thepack'),
                'label_block' => true,
                'default' => 'Year',               
            ]
        );

        $repeater->add_control(
            'type', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Heading', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'icon' => [
                        'title' =>   esc_html__('Icon', 'thepack'),
                        'icon' => ' eicon-document-file',
                    ],
                    'image' => [
                        'title' =>   esc_html__('Image', 'thepack'),
                        'icon' => 'eicon-image-rollover',
                    ]
                ],
                'default' => 'icon',
                'label_block' => true,              
            ]
        );

        $repeater->add_control(
            'ico', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Icon', 'thepack'),
                'type' => Controls_Manager::ICON,
                'condition' => [
                    'type' => 'icon',
                ],                        
                'label_block' => true,            
            ]
        );

        $repeater->add_control(
            'img', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Image', 'thepack'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'type' => 'image',
                ],                        
                'label_block' => true,          
            ]
        );

        $repeater->add_control(
            'link', [
                'label' =>   esc_html__('Link', 'thepack'),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'placeholder' => 'http://your-link.com',
                'default' => [
                    'url' => 'https://themeforest.net/user/xldevelopment',
                ],              
            ]
        );
                                
        $this->add_control(
            'items',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'prevent_empty' => false,
                'default' => [
                    [
                        'title' =>   esc_html__( 'Year', 'thepack' ),
                    ]
                ],
                'title_field' => '{{{ title }}}',
            ]
        );

        
        $this->end_controls_section();

        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'show_label' => false,
            ]
        );

        $this->add_control(
            'align',
            [
                'label' =>   esc_html__('Align', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ]
                ],
                'default' => 'center',
                'selectors' => [
                    '{{WRAPPER}} .contentbox' => 'text-align: {{VALUE}};',
                ],                
            ]
        );

        $this->add_control(
            'animation',
            [
                'label' =>   esc_html__('Animation', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'options' =>  thepack_animations(), 
                'multiple' => false,             
            ]
        );

        $this->add_responsive_control(
            'width',
            [
                'label' =>   esc_html__( 'Column width', 'thepack' ),
                'type' =>  Controls_Manager::NUMBER, 
                'default' => '33.33',
                 'selectors' => [
                        '{{WRAPPER}} .mini-box' => 'width: {{VALUE}}%;',
                 ], 
                'condition' => [
                    'tmpl' => array('one'),
                ],                                              
            ]
        );

        $this->add_responsive_control(
            'mnhgt',
            [
                'label' =>   esc_html__( 'Minimum height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .contentbox' => 'height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'tmpl' => array('one'),
                ], 
            ]
        );

        $this->add_responsive_control(
            'mbspc',
            [
                'label' =>   esc_html__( 'Item spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .mini-box' => 'padding: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .minibox1-wrap' => 'margin:0px -{{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'tmpl' => array('one'),
                ], 
            ]
        );
        $this->end_controls_section();        

        $this->start_controls_section(
            'section_box',
            [
                'label' =>   esc_html__('Box', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'show_label' => false,
            ]
        );

        $this->add_control(
            'box_bg',
            [
                'label' =>   esc_html__( 'Background', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .contentbox' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'box_bgh',
            [
                'label' =>   esc_html__( 'Hover Background', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .contentbox:hover' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'bclr',
            [
                'label' =>   esc_html__( 'Border color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .contentbox' => 'border-top: 1px solid {{VALUE}};border-left: 1px solid {{VALUE}};border-right: 1px solid {{VALUE}};',
                ],
                'condition' => [
                    'tmpl' => array('one'),
                ],                 
            ]
        );

        $this->add_control(
            'box_border_color',
            [
                'label' =>   esc_html__( 'Bottom border color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .contentbox' => 'border-bottom-color: {{VALUE}};border-bottom-style:solid;',
                ],
                'condition' => [
                    'tmpl' => array('one'),
                ],                 
            ]
        );

        $this->add_control(
            'box_border_width',
            [
                'label' =>   esc_html__( 'Botttom border width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 10,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .contentbox' => 'border-bottom-width: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'tmpl' => array('one'),
                ],                 

            ]
        );


        $this->end_controls_section();


        $this->start_controls_section(
            'section_img',
            [
                'label' =>   esc_html__('Image/Icon', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'show_label' => false,
            ]
        );

        $this->add_control(
            'img-absolute',
            [
                'label' =>   esc_html__('Position', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'allowed_dimensions' => [ 'top', 'left'],
                'selectors' => [
                    '{{WRAPPER}} .contentbox-2 .img-wrap' => 'top: {{TOP}}{{UNIT}};left: {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'style' => 'style-two',
                ],                
            ]
        );

        $this->add_control(
            'img-absolute-2',
            [
                'label' =>   esc_html__('Position', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'allowed_dimensions' => [ 'top', 'right'],
                'selectors' => [
                    '{{WRAPPER}} .contentbox-3 .img-wrap' => 'top: {{TOP}}{{UNIT}};right: {{RIGHT}}{{UNIT}};',
                ],
                'condition' => [
                    'style' => 'style-three',
                ],                
            ]
        );
        $this->add_control(
            'img-width',
            [
                'label' =>   esc_html__( 'Width & height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .img-wrap' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'img-pad',
            [
                'label' =>   esc_html__( 'Padding', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .img-wrap' => 'padding: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'img-radius',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .img-wrap' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'img-fontsize',
            [
                'label' =>   esc_html__( 'Font size', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .img-wrap' => 'font-size: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'img-lineheight',
            [
                'label' =>   esc_html__( 'Line height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .img-wrap' => 'line-height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'box-bg',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .img-wrap' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'box-color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .img-wrap' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section(); 

        $this->start_controls_section(
            'section_title_typo',
            [
                'label' =>   esc_html__('Title', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'show_label' => false,
            ]
        );

        $this->add_control(
            'title-margin',
            [
                'label' =>   esc_html__('Margin', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'title-color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' =>   esc_html__('Typography', 'thepack'),
                'selector' => '{{WRAPPER}} .title',
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/'. $settings['tmpl'] .'.php';

    }

    private function icon_image($icon) {

        $type = $icon['type'];
        if ($type == 'image'){
            $id = $icon['img'];
            echo '<span class="img-wrap">'.wp_get_attachment_image($id['id'], 'full', false, array('class' => 'xlteam full')).'</span>';
        } else {
            echo '<span class="img-wrap"><i class="'.$icon['ico'].'"></i></span>';
        }

    }


}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_minibox());