<?php

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\utils;
use Elementor\Group_Control_Background;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_pageloader extends Widget_Base {

    public function get_name() {
        return 'tb_pageloader';
    }

    public function get_title() {
        return   esc_html__('PAGE LOADER', 'thepack');
    }

    public function get_icon() {
        return 'eicon-sync';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_process_1',
            [
                'label' =>   esc_html__('Content', 'thepack'),
            ]
        );

        $this->add_control(
          'tmpl',
          [
             'label'       =>   esc_html__( 'Template', 'thepack' ),
             'type' => Controls_Manager::SELECT,
             'default' => 'one',
             'label_block' => true,
             'options' => [
                'one'  =>   esc_html__( 'One', 'thepack' ),
                'two' =>   esc_html__( 'Two', 'thepack' ),
                'three' =>   esc_html__( 'Three', 'thepack' ),
                'four' =>   esc_html__( 'Four', 'thepack' ),
                'five'   =>   esc_html__( 'Five', 'thepack' ),
                'six'   =>   esc_html__( 'Six', 'thepack' ),
                'seven'   =>   esc_html__( 'Seven', 'thepack' ),
             ]
          ]
        );

        $this->add_control(
            'img', [
                'type' => Controls_Manager::MEDIA,
                'label' =>   esc_html__('Image', 'thepack'),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'tmpl' => array('two'),
                ],                 
            ]
        );

        $this->add_control(
            'ftxt', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Label', 'thepack'),
                'label_block' => true,
                'default' =>'XLD',
                'condition' => [
                    'tmpl' => array('four','five'),
                ],                  
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'delay',
            [
                'label' =>   esc_html__( 'Delay in ms', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 10000,
                        'step' => 1,
                    ]   
                ],
                'default' => [
                    'size' => 10000,
                ],                
            ]
        );

        $this->add_control(
          'b3',
          [
             'type'    => Controls_Manager::RAW_HTML,
             'raw' =>   esc_html__( '<b>Background</b>', 'thepack' ),
          ]
        );
        
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'ovrly_bg',
                'label' =>   esc_html__( 'Overlay background', 'elementor' ),
                'types' => [ 'none', 'classic','gradient' ],
                'selector' => '{{WRAPPER}} .tbpreloader,{{WRAPPER}} .centered',
            ]
        );

        $this->end_controls_section(); 

        $this->start_controls_section(
            'section_second',
            [
                'label' =>   esc_html__('Second Loader', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'tmpl' => 'two',
                ],                                  
            ]
        );

        $this->add_responsive_control(
            'swrwid',
            [
                'label' =>   esc_html__( 'Wrapper width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} #preloader' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'slogow',
            [
                'label' =>   esc_html__( 'Logo width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} #preloader > img' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'sbdrclr',
            [
                'label' =>   esc_html__('Border color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #preloader:before' => 'border-color: {{VALUE}};border-top-color:transparent;',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_third',
            [
                'label' =>   esc_html__('Third Loader', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'tmpl' => 'three',
                ],                                  
            ]
        );

        $this->add_responsive_control(
            'thlogow',
            [
                'label' =>   esc_html__( 'Wrapper width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .three #preloader' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'thdrclr',
            [
                'label' =>   esc_html__('Border color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .three #preloader' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_fourth',
            [
                'label' =>   esc_html__('Fourth Loader', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'tmpl' => 'four',
                ],                                  
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'foutypo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .txt-loading',
            ]
        );

        $this->add_control(
            'foumth',
            [
                'label' =>   esc_html__('Primary color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .letters-loading' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'fousth',
            [
                'label' =>   esc_html__('Secondary color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .letters-loading:before' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_fift',
            [
                'label' =>   esc_html__('Fifth Loader', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'tmpl' => 'five',
                ],                                  
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'fiftypo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .loading-text',
            ]
        );

        $this->add_control(
            'fifmth',
            [
                'label' =>   esc_html__('Primary color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .loading-text' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_six',
            [
                'label' =>   esc_html__('Sixth Loader', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'tmpl' => 'six',
                ],                                  
            ]
        );

        $this->add_control(
            'sifmth',
            [
                'label' =>   esc_html__('Primary color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blobs .blob-center,{{WRAPPER}} .blob' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_seven',
            [
                'label' =>   esc_html__('Seventh Loader', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'tmpl' => 'seven',
                ],                                  
            ]
        );

        $this->add_responsive_control(
            'svbw',
            [
                'label' =>   esc_html__( 'Ball width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .centered>div' => 'width: {{SIZE}}px;height: {{SIZE}}px;',
                ],
            ]
        );

        $this->add_control(
            'svfmth',
            [
                'label' =>   esc_html__('Primary color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blob-2' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {
        $settings = $this->get_settings();      
        require dirname(__FILE__) .'/'. $settings['tmpl'] .'.php';
    }
}

 $widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_pageloader());