<?php

/*
Widget Name: Webangon full social
Description: Full width social.
Author: Ashraf
Author URI: https://www.webangon.com
*/

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;

 
if (!defined('ABSPATH'))
    exit; // Exit if accessed directly
 

class thepack_folio_parallax extends Widget_Base {

    public function get_name() {
        return 'tp-folioparallax';
    }

    public function get_title() {
        return   esc_html__('PORTFOLIO PARALLAX', 'thepack');
    }

    public function get_icon() {
        return ' eicon-slideshow';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_pricing_table',
            [
                'label' =>   esc_html__('Slides', 'thepack'),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'title', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Label', 'thepack'),
                'label_block' => true,
                'default' => 'Leader in Business',               
            ]
        );

        $repeater->add_control(
            'cat', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Category', 'thepack'),
                'label_block' => true,
                'default' => 'Interior',               
            ]
        );

        $repeater->add_control(
            'desc', [
                'type' => Controls_Manager::TEXTAREA,
                'label' =>   esc_html__('Description', 'thepack'),
            ]
        );

        $repeater->add_control(
            'url', [
                'label' =>   esc_html__('Button url', 'thepack'),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'placeholder' =>   esc_html__('http://your-link.com', 'thepack'),
            ]
        );
        $repeater->add_control(
            'btn', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Button label', 'thepack'),
                'label_block' => true,              
            ]
        );

        $repeater->add_control(
            'bg', [
                'type' => Controls_Manager::MEDIA,
                'label' =>   esc_html__('Background', 'thepack'),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );
                
        $this->add_control(
            'lists',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'prevent_empty' => false,
                'default' => [
                    [
                        'title' =>   esc_html__( 'Leader in Business', 'thepack' ),
                    ]
                ],
                'title_field' => '{{{ title }}}',
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__( 'General', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );


        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'overlay_color',
                'label' =>   esc_html__( 'Overlay', 'elementor' ),
                'types' => [ 'none', 'classic','gradient' ],
                'selector' => '{{WRAPPER}} .foliobg::before',
            ]
        );

        $this->add_control(
          'g_pad',
          [
             'label' =>   esc_html__( 'Wrapper padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             
             'selectors' => [
                    '{{WRAPPER}} .foliobg' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_responsive_control(
            'g-align',
            [
                'label' =>   esc_html__('Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' =>   esc_html__('Justified', 'thepack'),
                        'icon' => 'fa fa-align-justify',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .foliobg' => 'text-align: {{VALUE}};',
                ],                              
            ]
        );

        $this->add_control(
            'wmaxwid',
            [
                'label' =>   esc_html__( 'Wrapper max width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1500,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .inner-wrap' => 'max-width: {{SIZE}}px;margin:0px auto;',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_pre',
            [
                'label' =>   esc_html__('Pre Title', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'pre_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cat' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'pre_bg',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cat' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
          'pre_pad',
          [
             'label' =>   esc_html__( 'Padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             
             'selectors' => [
                    '{{WRAPPER}} .cat' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'pre_typo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .cat',
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_title',
            [
                'label' =>   esc_html__('Title', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            't_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
          't_margin',
          [
             'label' =>   esc_html__( 'Margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             
             'selectors' => [
                    '{{WRAPPER}} .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 't_typo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .title',
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_desc',
            [
                'label' =>   esc_html__('Description', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'des_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .desc' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
          'des_margin',
          [
             'label' =>   esc_html__( 'Margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             
             'selectors' => [
                    '{{WRAPPER}} .desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'des_typo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .desc',
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_btn',
            [
                'label' =>   esc_html__('Button', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'btn_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tb-underline' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .tb-underline::after' => 'background: {{VALUE}};',
                ],
            ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .tb-underline',
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_caro',
            [
                'label' =>   esc_html__('Parallax control', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'prlx',
            [
                'label' =>   esc_html__('Parallax', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );


        $this->add_control(
            'speed',
            [
                'label' =>   esc_html__( 'Parallax speed', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'default' => [
                    'size' => .05,
                ],                
                'range' => [
                    'px' => [
                        'min' => .05,
                        'max' => 1,
                        'step' => .05,
                    ],
                ],
                'size_units' => [ 'px'],
            'condition' => [
                'prlx' => array('yes'),
            ],                               
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/list.php';
    }

}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_folio_parallax());