<?php

/*
Widget Name: Webangon pricelist
Description: Display one or more piecharts depicting a percentage value in a multi-column grid.
Author: LiveMesh
Author URI: https://www.webangon.com
*/

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\utils;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_price_list extends Widget_Base {

    public function get_name() {
        return 'tb_price_list';
    }

    public function get_title() {
        return   esc_html__('PRICE LIST', 'thepack');
    }

    public function get_icon() {
        return 'eicon-price-list';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_price_list',
            [
                'label' =>   esc_html__('Price list', 'thepack'),
            ]
        );

        $this->add_control(
            'type',
            [
                'label' =>   esc_html__('Price type', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'thumb' =>   esc_html__('Thumb', 'thepack'),
                    'button' =>   esc_html__('Button', 'thepack')
                ],
            ]
        );


        $repeater1 = new \Elementor\Repeater();

        $repeater1->add_control(
            'label', [
                'label' =>   esc_html__( 'Label', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'My pumpkin',                               
            ]
        );

        $repeater1->add_control(
            'desc', [
                'label' =>   esc_html__( 'Description', 'thepack' ),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );

        $repeater1->add_control(
            'price', [
                'label' =>   esc_html__( 'Price', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,                              
            ]
        );

        $repeater1->add_control(
            'image', [
                'label' =>   esc_html__('Thumb', 'thepack'),
                'type' => Controls_Manager::MEDIA,
                'label_block' => true,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );       

        $this->add_control(
            'pricelists',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater1->get_controls(), 
                'prevent_empty' => false,
                'condition' => [
                    'type' => 'thumb',
                ],                
                'default' => [
                    [
                        'label' =>   esc_html__( 'My pumpkin', 'thepack' ),
                    ]
                ],
                'title_field' => 'label',
            ]
        );

/*        $this->add_control(
            'pricelist_btn',
            [
                'type' => Controls_Manager::REPEATER,
                'condition' => [
                    'type' => 'button',
                ],                
                'fields' => [
                    [
                        'name' => 'btn_label',
                        'label' =>   esc_html__('Label', 'thepack'),
                        'label_block' => true ,
                        'type' => Controls_Manager::TEXT,
                    ],                     

                    [
                        'name' => 'btn_desc',
                        'label' =>   esc_html__('Description', 'thepack'),
                        'type' => 'textarea',
                    ], 

                    [
                        'name' => 'btn_price',
                        'label' =>   esc_html__('Price', 'thepack'),
                        'label_block' => true ,
                        'type' => Controls_Manager::TEXT,
                    ],

                    [
                        'name' => 'btn_url',
                        'label' =>   esc_html__('Button url', 'thepack'),
                        'type' => Controls_Manager::URL,
                        'label_block' => true,
                        'default' => [
                            'url' => '',
                            'is_external' => 'true',
                        ],
                        'placeholder' =>   esc_html__('http://client-link.com', 'thepack'),
                    ],                   
                ],
                'title_field' => '{{{ btn_label }}}',                
            ]

        );*/

        $this->end_controls_section();

        $this->start_controls_section(
            'section_gnrl',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'mbtm',
            [
                'label' =>   esc_html__( 'Item bottom spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .price-list li' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'animation',
            [
                'label' =>   esc_html__('Animation', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'options' =>  thepack_animations(), 
                'multiple' => false,
                'label_block' => true 
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_title',
            [
                'label' =>   esc_html__('Title', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control( 
            't_clr',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .item-name,{{WRAPPER}} .price' => 'color: {{VALUE}};'
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 't_typo',
                'selector' => '{{WRAPPER}} .item-name,{{WRAPPER}} .price',
                'label' =>   esc_html__( 'Typo', 'thepack' ),
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_desc',
            [
                'label' =>   esc_html__('Description', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
          'd_mar',
          [
             'label' =>   esc_html__( 'Margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'em','px'],
             'selectors' => [
                    '{{WRAPPER}} .desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_control(
            'd_clr',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .desc' => 'color: {{VALUE}};'
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'd_typo',
                'selector' => '{{WRAPPER}} .desc',
                'label' =>   esc_html__( 'Typo', 'thepack' ),
            ]
        );

        $this->end_controls_section(); 


        $this->start_controls_section(
            'section_img',
            [
                'label' =>   esc_html__('Thumbnail', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'thmbwid',
            [
                'label' =>   esc_html__( 'Width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .price-list li img' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'thmmr',
            [
                'label' =>   esc_html__( 'Right spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .price-list li img' => 'margin-right: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'thmrad',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .price-list li img' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings();
        if (empty($settings['pricelists']))
            return;        

        $column = thepack_get_column_class(intval($settings['per_line']));
        $animation = $settings['animation'];
        $class = $column.' '.$animation; 

        ?>
        <?php if ($settings['type'] == 'thumb') : ?>

            <ul class="price-list">
                <?php foreach ($settings['pricelists'] as $item): 
                $img = $item['image'];
                ?>
                <li class="<?php echo $settings['animation'];?>">
                    <?php echo wp_get_attachment_image($img['id'], 'full', false, array('class' => 'price-list full')); ?>

                    <span class="wrapper"><span class="inner"><span class="item-name"><?php echo $item['label'];?></span>

                    <span class="price"><?php echo $item['price'];?></span> </span> <span class="desc"><?php echo $item['desc'];?></span></span>
                </li>

            <?php endforeach;?>
            </ul>
        <?php endif; ?>


        <?php if ($settings['type'] == 'button') : ?>

            <ul class="price-list list-button">
               <?php foreach ($settings['pricelist_btn'] as $item):?>
                <li class="<?php echo $settings['animation'];?>">
                    <span class="inner">
                      <span class="item-price"><?php echo $item['btn_price'];?></span>
                    <span class="item-name"><?php echo $item['btn_label'];?></span>
                    <span class="desc"><?php echo $item['btn_desc'];?></span>
                    </span>
                    <span class="button-wrapper">
                      <a href="#" class="price-button">Buy Now</a>
                    </span>
                </li>

            <?php endforeach;?>
            </ul>
        <?php endif; ?>

        <?php
    }

    protected function content_template() {
    }

}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_price_list());