<?php

/*
Widget Name: Webangon full social
Description: Full width social.
Author: Ashraf
Author URI: https://www.webangon.com
*/

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;

 
if (!defined('ABSPATH'))
    exit; // Exit if accessed directly
 

class thepack_slide1 extends Widget_Base {

    public function get_name() {
        return 'tp-slide1';
    }

    public function get_title() {
        return   esc_html__('SLIDESHOW', 'thepack');
    }

    public function get_icon() {
        return ' eicon-slideshow';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_pricing_table',
            [
                'label' =>   esc_html__('Slides', 'thepack'),
            ]
        );
 
        $this->add_control(

            'style', [
                'type' => Controls_Manager::SELECT,
                'label' =>   esc_html__('Style', 'thepack'),
                'default' => 'hero-slider-style-1',
                'options' => [
                    'hero-slider-style-1' =>   esc_html__('Style 1', 'thepack'),
                    'hero-slider-style-2' =>   esc_html__('Style 2', 'thepack'),
                    'hero-slider-style-3' =>   esc_html__('Style 3', 'thepack'),

                ],
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'title', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Label', 'thepack'),
                'label_block' => true,
                'default' => 'Leader in Business',               
            ]
        );

        $repeater->add_control(
            'cat', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Category', 'thepack'),
                'label_block' => true,
                'default' => 'Interior',               
            ]
        );

        $repeater->add_control(
            'desc', [
                'type' => Controls_Manager::TEXTAREA,
                'label' =>   esc_html__('Description', 'thepack'),
                'label_block' => true, 
            ]
        );

        $repeater->add_control(
            'btn', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Button Label', 'thepack'),
                'label_block' => true,              
            ]
        );

        $repeater->add_control(
            'url', [
                'label' =>   esc_html__('Button url', 'thepack'),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'placeholder' =>   esc_html__('http://your-link.com', 'thepack'),
            ]
        );


        $repeater->add_control(
            'bg', [
                'type' => Controls_Manager::MEDIA,
                'label' =>   esc_html__('Background', 'thepack'),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );
                
        $this->add_control(
            'lists',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'prevent_empty' => false,
                'default' => [
                    [
                        'title' =>   esc_html__( 'Leader in Business', 'thepack' ),
                    ]
                ],
                'title_field' => '{{{ title }}}',
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__( 'General', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'backgr-col',
            [
                'label' =>   esc_html__( 'Background color', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .social-btn a' => 'background: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'backgr-col-h',
            [
                'label' =>   esc_html__( 'Background hover', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .social-btn a:hover' => 'background: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'txt-col',
            [
                'label' =>   esc_html__( 'Text color', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .social-btn a' => 'color: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'txt-col-h',
            [
                'label' =>   esc_html__( 'Text color hover', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .social-btn a:hover' => 'color: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'border-col',
            [
                'label' =>   esc_html__( 'Border color', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .social-btn a' => 'border-color: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'border-col-h',
            [
                'label' =>   esc_html__( 'Border hover color', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .social-btn a:hover' => 'border-color: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'list-border-wid',
            [
                'label' =>   esc_html__( 'Border width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,               
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .social-btn a' => 'border-width: {{SIZE}}{{UNIT}};border-style:solid',
                ],

            ]
        );

        $this->add_control(
            'list-border-radius',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,               
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .social-btn a' => 'border-radius: {{SIZE}}{{UNIT}}',
                ],

            ]
        );

        $this->add_control(
            'item_height',
            [
                'label' =>   esc_html__( 'Item height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,                
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .social-btn a' => 'height: {{SIZE}}{{UNIT}};line-height:{{SIZE}}{{UNIT}}',
                    '{{WRAPPER}} .social-btn.box a' => 'width: {{SIZE}}{{UNIT}}',
                ],

            ]
        );

        $this->add_responsive_control(
            'padding',
            [
                'label' =>   esc_html__('Padding', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%','em' ],
                'selectors' => [
                    '{{WRAPPER}} .social-btn li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .social-btn' => 'margin-left:-{{LEFT}}{{UNIT}};margin-right:- {{RIGHT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'margin_btm',
            [
                'label' =>   esc_html__('Bottom margin', 'thepack'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'default' => [
                    'size' => 16,
                ],
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => -100,
                        'step' => 1,
                    ],                   
                ],
                'selectors' => [
                    '{{WRAPPER}} .social-btn li' => 'margin-bottom: {{SIZE}}%;',
                ]                
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'social_typo',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
                'selector' => '{{WRAPPER}} .social-btn li',              
            ]
        );

        $this->add_responsive_control(
            'list-align',
            [
                'label' =>   esc_html__('Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' =>   esc_html__('Justified', 'thepack'),
                        'icon' => 'fa fa-align-justify',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .social-btn' => 'text-align: {{VALUE}};',
                ],                              
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/list.php';
    }

}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_slide1());