<?php

/*
Widget Name: Webangon full social
Description: Full width social.
Author: Ashraf
Author URI: https://www.webangon.com
*/

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
 
if (!defined('ABSPATH'))
    exit; // Exit if accessed directly
 

class thepack_thumbslider extends Widget_Base {

    public function get_name() {
        return 'tp-thmbslidr';
    }

    public function get_title() {
        return   esc_html__('SLIDER THUMBNAIL', 'thepack');
    }

    public function get_icon() {
        return ' eicon-slideshow';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_pricing_table',
            [
                'label' =>   esc_html__('Slides', 'thepack'),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'title', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Label', 'thepack'),
                'label_block' => true,
                'default' => 'Leader in Business',               
            ]
        );

        $repeater->add_control(
            'cat', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Category', 'thepack'),
                'label_block' => true,
                'default' => 'Interior',               
            ]
        );

        $repeater->add_control(
            'desc', [
                'type' => Controls_Manager::TEXTAREA,
                'label' =>   esc_html__('Description', 'thepack'),
                'label_block' => true, 
            ]
        );

        $repeater->add_control(
            'info', [
                'type' => Controls_Manager::TEXTAREA,
                'label' =>   esc_html__('Extra information', 'thepack'),
                'label_block' => true, 
            ]
        );

        $repeater->add_control(
            'btn', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Button Label', 'thepack'),
                'label_block' => true,              
            ]
        );
 
        $repeater->add_control(
            'url', [
                'label' =>   esc_html__('Button url', 'thepack'),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'placeholder' =>   esc_html__('http://your-link.com', 'thepack'),
            ]
        );


        $repeater->add_control(
            'bg', [
                'type' => Controls_Manager::MEDIA,
                'label' =>   esc_html__('Background', 'thepack'),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );
                
        $this->add_control(
            'lists',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'prevent_empty' => false,
                'default' => [
                    [
                        'title' =>   esc_html__( 'Leader in Business', 'thepack' ),
                    ]
                ],
                'title_field' => '{{{ title }}}',
            ]
        );  

        $this->end_controls_section();

        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__( 'General', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'overlay_color',
                'label' =>   esc_html__( 'Overlay', 'elementor' ),
                'types' => [ 'none', 'classic','gradient' ],
                'selector' => '{{WRAPPER}} .slide-bgimg::before',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_caro',
            [
                'label' =>   esc_html__('Slider control', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );


        $this->add_control(
            'nav',
            [
                'label' =>   esc_html__('Display arrow', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );

        $this->add_control(
            'auto',
            [
                'label' =>   esc_html__('Autoplay', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );

        $this->add_control(
            'thmb',
            [
                'label' =>   esc_html__('Display thumbnails', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );

        $this->add_control(
            'mouse',
            [
                'label' =>   esc_html__('Mouse control', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );

        $this->add_control(
            'speed',
            [
                'label' =>   esc_html__( 'Slide speed', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'default' => [
                    'size' => 2500,
                ], 
                'condition' => [
                    'auto' => 'yes',
                ],                               
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 8000,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],               
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_thmb',
            [
                'label' =>   esc_html__('Thumb', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'thmb' => 'yes',
                ],                 
            ]
        );

        $this->add_control(
            'thmbcenter',
            [
                'label' =>   esc_html__('Centered slide', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );

        $this->add_control(
          'thmb_pad',
          [
             'label' =>   esc_html__( 'Wrapper Padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             
             'selectors' => [
                    '{{WRAPPER}} .thmb-container.nav-slider' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_responsive_control(
            'wpwid',
            [
                'label' =>   esc_html__( 'Wrapper width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 100,
                        'max' => 1500,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} .thmb-container.nav-slider' => 'width:{{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'thmbitem',
            [
                'label' =>   esc_html__( 'Items', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'default' => [
                    'size' => 6,
                ],                
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 20,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],               
            ]
        );

        $this->add_control(
            'thmbspace',
            [
                'label' =>   esc_html__( 'Item spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'default' => [
                    'size' => 10,
                ],                
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],               
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_pagi',
            [
                'label' =>   esc_html__('Slider arrow', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'nav' => 'yes',
                ],                 
            ]
        );

        $this->add_control(
            'picon', [
                'type' => Controls_Manager::ICON,
                'label' =>   esc_html__('Prev icon', 'thepack'),
                'label_block' => true,
                'default' => 'fa-chevron-left',               
            ]
        );

        $this->add_control(
            'nicon', [
                'type' => Controls_Manager::ICON,
                'label' =>   esc_html__('Next icon', 'thepack'),
                'label_block' => true,
                'default' => 'fa-chevron-right',               
            ]
        );

        $this->add_control(
            'pgi_bg',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .no-bg' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'pgi_c',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .no-bg' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'pgwd',
            [
                'label' =>   esc_html__( 'Width and height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .no-bg' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'lheight',
            [
                'label' =>   esc_html__( 'Line-height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .no-bg' => 'line-height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'fsize',
            [
                'label' =>   esc_html__( 'Font size', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .no-bg' => 'font-size: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'pgbrad',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .no-bg' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->end_controls_section();

    } 

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';
    }

}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_thumbslider());