<?php

/*
Widget Name: Webangon full social
Description: Full width social.
Author: Ashraf
Author URI: https://www.webangon.com
*/
 
namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;

 
if (!defined('ABSPATH'))
    exit; // Exit if accessed directly
 

class thepack_carousel1 extends Widget_Base {

    public function get_name() {
        return 'tp-carousel1';
    }

    public function get_title() {
        return   esc_html__('CAROUSEL SLIDE', 'thepack');
    }

    public function get_icon() {
        return ' eicon-slideshow';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_pricing_table',
            [
                'label' =>   esc_html__('Slides', 'thepack'),
            ]
        );

        $this->add_control(
            'tmpl',
            [
                'label' =>   esc_html__('Template', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'one' => [
                        'title' =>   esc_html__('One', 'thepack'),
                        'icon' => 'fa fa-folder',
                    ],
                    'two' => [
                        'title' =>   esc_html__('Two', 'thepack'),
                        'icon' => 'fa fa-folder-o',
                    ]

                ],
                'default' => 'one',               
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'title', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Label', 'thepack'),
                'label_block' => true,
                'default' => 'Leader in Business',               
            ]
        );

        $repeater->add_control(
            'cat', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Category', 'thepack'),
                'label_block' => true,
                'default' => 'Interior',               
            ]
        );

        $repeater->add_control(
            'url', [
                'label' =>   esc_html__('Link', 'thepack'),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'placeholder' =>   esc_html__('http://your-link.com', 'thepack'),
            ]
        );


        $repeater->add_control(
            'bg', [
                'type' => Controls_Manager::MEDIA,
                'label' =>   esc_html__('Image', 'thepack'),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );
                
        $this->add_control(
            'lists',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'prevent_empty' => false,
                'default' => [
                    [
                        'title' =>   esc_html__( 'Leader in Business', 'thepack' ),
                    ]
                ],
                'title_field' => '{{{ title }}}',
            ]
        );

        $this->add_control(
            'img_size',
            [
                'label' =>   esc_html__('Image size', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' =>  thepack_image_size_choose(), 
                'multiple' => false,                                
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__( 'General', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'g-align',
            [
                'label' =>   esc_html__('Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' =>   esc_html__('Justified', 'thepack'),
                        'icon' => 'fa fa-align-justify',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .inner-wrap' => 'text-align: {{VALUE}};',
                ],                              
            ]
        );

        $this->add_control(
            'ovly_color',
            [
                'label' =>   esc_html__('Wrapper overlay background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tb-foliolnk' => 'background: {{VALUE}};',
                ],
                'condition' => [
                    'tmpl' => 'two',
                ],                
            ]
        );

        $this->add_responsive_control(
            'ovly_spac',
            [
                'label' =>   esc_html__( 'Overlay margin', 'thepack' ),
                'type' =>  Controls_Manager::DIMENSIONS,
                'size_units' => ['%','px'],
                'selectors' => [
                    '{{WRAPPER}} .tb-foliolnk' => 'top: {{TOP}}{{UNIT}};bottom: {{BOTTOM}}{{UNIT}};left: {{LEFT}}{{UNIT}};right: {{RIGHT}}{{UNIT}};',
                ],
                'condition' => [
                    'tmpl' => 'two',
                ],                
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_pre',
            [
                'label' =>   esc_html__('Pre Title', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'pre_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cat' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'pre_bg',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cat' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
          'pre_mar',
          [
             'label' =>   esc_html__( 'Margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             
             'selectors' => [
                    '{{WRAPPER}} .cat' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_control(
          'pre_pad',
          [
             'label' =>   esc_html__( 'Padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             
             'selectors' => [
                    '{{WRAPPER}} .cat' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'pre_typo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .cat',
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_title',
            [
                'label' =>   esc_html__('Title', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            't_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
          't_margin',
          [
             'label' =>   esc_html__( 'Margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             
             'selectors' => [
                    '{{WRAPPER}} .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 't_typo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .title',
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_caro',
            [
                'label' =>   esc_html__('Slider control', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'dot',
            [
                'label' =>   esc_html__('Display dot', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );

        $this->add_control(
            'nav',
            [
                'label' =>   esc_html__('Display navigation', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );

        $this->add_control(
            'center',
            [
                'label' =>   esc_html__('Center Mode', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );

        $this->add_control(
            'mouse',
            [
                'label' =>   esc_html__('Mouse control', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );

        $this->add_control(
            'lazy',
            [
                'label' =>   esc_html__('Lazyload images', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );

        $this->add_control(
            'space',
            [
                'label' =>   esc_html__( 'Item spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'default' => [
                    'size' => 2,
                ],                
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 50,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],               
            ]
        );

        $this->add_control(
            'item',
            [
                'label' =>   esc_html__( 'Item per slide', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'default' => [
                    'size' => 4,
                ],                
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 5,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],               
            ]
        );

        $this->add_control(
            'item_tab',
            [
                'label' =>   esc_html__( 'Item per slide tablets', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'default' => [
                    'size' => 2,
                ],                 
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 5,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],               
            ]
        );

        $this->add_control(
            'speed',
            [
                'label' =>   esc_html__( 'Slide speed', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'default' => [
                    'size' => 2500,
                ],                
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 8000,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],               
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_cmd',
            [
                'label' =>   esc_html__('Centermode Styles', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'center' => 'yes',
                ],                 
            ]
        );

        $this->add_control(
            'cmzm',
            [
                'label' =>   esc_html__( 'Zoom factor', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'default' => [
                    'size' => 1,
                ],                
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1,
                        'step' => .05,
                    ],
                ],
                'size_units' => [ 'px'],  
                'selectors' => [
                    '{{WRAPPER}} .swiper-slide.centermode:not(.swiper-slide-active) .tb-hovercarou1' => 'transform: scale({{SIZE}}) translateZ(0);-moz-transform: scale({{SIZE}}) translateZ(0);-webkit-transform: scale({{SIZE}}) translateZ(0);',
                ],                             
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_pagi',
            [
                'label' =>   esc_html__('Slider Pagination', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'nav' => 'yes',
                ],                 
            ]
        );

        $this->add_control(
            'picon', [
                'type' => Controls_Manager::ICON,
                'label' =>   esc_html__('Prev icon', 'thepack'),
                'label_block' => true,
                'default' => 'fa-chevron-left',               
            ]
        );

        $this->add_control(
            'nicon', [
                'type' => Controls_Manager::ICON,
                'label' =>   esc_html__('Next icon', 'thepack'),
                'label_block' => true,
                'default' => 'fa-chevron-right',               
            ]
        );

        $this->add_control(
            'pgi_bg',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .no-bg' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'pgi_c',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .no-bg' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'pgwd',
            [
                'label' =>   esc_html__( 'Width and height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .no-bg' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'lheight',
            [
                'label' =>   esc_html__( 'Line-height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .no-bg' => 'line-height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'pgbrad',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .no-bg' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_nav',
            [
                'label' =>   esc_html__('Slider Navigation', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'dot' => 'yes',
                ],                
            ]
        );

        $this->add_responsive_control(
            'navpos',
            [
                'label' =>   esc_html__( 'Postion', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 300,
                        'min' => -300,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination' => 'bottom: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'navcol',
            [
                'label' =>   esc_html__('Dot color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullet' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'navacol',
            [
                'label' =>   esc_html__('Dot active color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullet-active' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();
    } 

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/list.php';
    }

}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_carousel1());