<?php

/*
Widget Name: Webangon Imagelayer
Description: Create image layers
Author: Webangon
Author URI: https://www.webangon.com
*/

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;
use Elementor\Utils;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_split_sec extends Widget_Base {

    public function get_name() {
        return 'ae_split';
    }

    public function get_title() {
        return   esc_html__('SPLIT SECTION', 'thepack');
    }

    public function get_icon() {
        return 'eicon-insert-image';
    }
    
    public function get_categories() {
        return array('ashelement-addons');
    } 

    protected function _register_controls() {

        $this->start_controls_section(
            'section_leftcnt',
            [
                'label' =>   esc_html__('Left Content', 'thepack'),                
            ] 
        );

        $this->add_control(
            'tpl', [
                'type' => Controls_Manager::SELECT2,
                'options' =>  thepack_template_selectb(), 
                'multiple' => false,
                'label' =>   esc_html__('Content template', 'thepack'),
                'label_block' => true,
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'lbg',
                'label' =>   esc_html__( 'Background', 'elementor' ),
                'types' => [ 'none', 'classic','gradient' ],
                'selector' => '{{WRAPPER}} .lsec',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_rightc',
            [
                'label' =>   esc_html__('Right Content', 'thepack'),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'title', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Label', 'thepack'),
                'label_block' => true,
                'default' =>'Template 1',
            ]
        );

        $repeater->add_control(
            'template', [
                'type' => Controls_Manager::SELECT2,
                'options' =>  thepack_template_selectb(), 
                'multiple' => false,
                'label' =>   esc_html__('Template', 'thepack'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'itms',
            [
                'type' => Controls_Manager::REPEATER,
                'prevent_empty' => false,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'title' =>   esc_html__( 'Finance', 'thepack' ),
                    ]
                ],
                'title_field' => '{{{ title }}}',
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'section_gnrl',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'lwid',
            [
                'label' =>   esc_html__( 'Left width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 100,
                        'max' => 1000,
                        'step' => 1,
                    ]
                ],
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} .lsec' => 'width: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .rsec' => 'margin-left: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'lht',
            [
                'label' =>   esc_html__( 'Left height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 100,
                        'max' => 1000,
                        'step' => 1,
                    ]
                ],
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} .lsec' => 'height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'rwid',
            [
                'label' =>   esc_html__( 'Right width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 100,
                        'max' => 1000,
                        'step' => 1,
                    ]
                ],
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} .rsec' => 'width: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
          'l-pad',
          [
             'label' =>   esc_html__( 'Left section padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => ['em','px'],
             'selectors' => [
                    '{{WRAPPER}} .lsec' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_responsive_control(
          'r-pad',
          [
             'label' =>   esc_html__( 'Right section padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => ['em','px'],
             'selectors' => [
                    '{{WRAPPER}} .rsec' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->end_controls_section();


    } 

    protected function render() {

        $settings = $this->get_settings();
        $tpl = $settings['tpl'] ? do_shortcode('[THEPACK_INSERT_TPL id="'.$settings['tpl'].'"]') : '';
        foreach ($settings['itms'] as $a){
            $content .= $this->icon_image($a);
        }
    ?>    
        <div class="tb-split-wrap">
            <div class="lsec">
                <?php echo $tpl;?>
            </div>
            <div class="rsec">
                <?php echo $content;?>
            </div>    
        </div>    
<style type="text/css">

.lsec,.rsec {
    width: 50%;
    float: left;
}
.lsec {
    height: 100vh;
    position: fixed;
    left: 0;
    bottom: 0;
    top: 0;
}
.lsec >div {
    position: relative;
    top: 50%;
    transform: translateY(-50%);
}

.rsec {
    margin-left: 50%;
}
@media (max-width: 992px) {

 .lsec,.rsec {
    width: 100% !important;
    position:relative;
    margin-left: 0% !important;
}

}
    
</style>
    <?php }

    private function icon_image($icon) { 

        return do_shortcode('[THEPACK_INSERT_TPL id="'.$icon['template'].'"]');


    }

}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_split_sec());