<?php
namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Scheme_Typography;
use Elementor\utils;

if (!defined('ABSPATH'))
    exit;

class thepack_team2 extends Widget_Base {

    public function get_name() {
        return 'tb_team2';
    }

    public function get_title() {
        return   esc_html__('TEAM 2', 'thepack');
    }

    public function get_icon() {
        return 'eicon-sync';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_process_1',
            [
                'label' =>   esc_html__('Content', 'thepack'),
            ]
        );

        $repeater1 = new \Elementor\Repeater();

        $repeater1->add_control(
            'name', [
                'label' =>   esc_html__( 'Name', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Mr Wick',                               
            ]
        );

        $repeater1->add_control(
            'pos', [
                'label' =>   esc_html__( 'Position', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' =>'Google,Gamer',
            ]
        );

        $repeater1->add_control( 
            'avatar', [
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'label_block' => true,
                'label' =>   esc_html__('Avatar', 'thepack'),
            ]
        );       

        $repeater1->add_control(
            'fb', [
                'label' =>   esc_html__('Facebook url', 'thepack'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        ); 

        $repeater1->add_control(
            'tw', [
                'label' =>   esc_html__('Twitter url', 'thepack'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $repeater1->add_control(
            'lnk', [
                'label' =>   esc_html__('Linkedin url', 'thepack'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $repeater1->add_control(
            'ig', [
                'label' =>   esc_html__('Instagram url', 'thepack'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater1->add_control(
            'gp', [
                'label' =>   esc_html__('Google plus url', 'thepack'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'items',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater1->get_controls(), 
                'prevent_empty' => false,
                'default' => [
                    [
                        'name' =>   esc_html__( 'Mr Wick', 'thepack' ),
                    ]
                ],
                'title_field' => '{{{name}}}',
            ]
        );

        $this->add_control(
            'img_size',
            [
                'label' =>   esc_html__('Image size', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' =>  thepack_image_size_choose(), 
                'multiple' => false,                                              
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'styl',
            [
                'label' =>   esc_html__('Style', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'styl_1' => [
                        'title' =>   esc_html__('Style 1', 'thepack'),
                        'icon' => 'eicon-gallery-grid',
                    ],
                    'styl_2' => [
                        'title' =>   esc_html__('Style 2', 'thepack'),
                        'icon' => 'eicon-slider-album',
                    ]
                ], 
                'default' => 'styl_1',               
            ]
        );

        $this->add_control(
            'disp',
            [
                'label' =>   esc_html__('Display', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'grid' => [
                        'title' =>   esc_html__('Grid', 'thepack'),
                        'icon' => 'eicon-gallery-grid',
                    ],
                    'slider' => [
                        'title' =>   esc_html__('Slider', 'thepack'),
                        'icon' => 'eicon-slider-album',
                    ]
                ], 
                'default' => 'grid',               
            ]
        );

        $this->add_control(
            'animation',
            [
                'label' =>   esc_html__('Animation', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'options' =>  thepack_animations(), 
                'label_block' => true,
                'condition' => [
                    'disp' => 'grid',
                ],                
            ]
        );

        $this->add_responsive_control(
            'width',
            [
                'label' =>   esc_html__( 'Column width', 'thepack' ),
                'type' =>  Controls_Manager::NUMBER, 
                'default' => '33.33',
                 'selectors' => [
                        '{{WRAPPER}} .team2' => 'width: {{VALUE}}%;',
                 ],  
                'condition' => [
                    'disp' => 'grid',
                ],                                             
            ]
        );

        $this->add_control(
            'padding',
            [
                'label' =>   esc_html__('Item Padding', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .team2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .tbteam2' => 'margin-left: -{{LEFT}}{{UNIT}};margin-right:-{{RIGHT}}{{UNIT}};',
                ],
                'condition' => [
                    'disp' => 'grid',
                ],                
            ]
        );

        $this->end_controls_section(); 

        $this->start_controls_section(
            'section_img',
            [
                'label' =>   esc_html__('Social Item', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,                 
            ]
        );

        $this->add_responsive_control(
            'smwid',
            [
                'label' =>   esc_html__( 'Max width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 800,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} .team-link' => 'max-width: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            's1pad',
            [
                'label' =>   esc_html__( 'Padding', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .styl_1 .team-link > a' => 'padding: {{SIZE}}px;',
                ],
            ]
        ); 

        $this->add_responsive_control(
            's1fz',
            [
                'label' =>   esc_html__( 'Icon size', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .styl_1 .team-link > a' => 'font-size: {{SIZE}}px;',
                ],
            ]
        );


        $this->add_control(
            's1bgc',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .styl_1 .team-link > a' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            's1clr',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .styl_1 .team-link > a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_name',
            [
                'label' =>   esc_html__('Content', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,                 
            ]
        );

        $this->add_control(
            'gcntbg',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-content' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'q_clr',
            [
                'label' =>   esc_html__('Name Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .name' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'q_pad',
            [
                'label' =>   esc_html__( 'Margin', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .name' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'q_typo',
                'label' =>   esc_html__('Name Typography', 'thepack'),
                'selector' => '{{WRAPPER}} .name',
            ]
        );

        $this->add_control(
            'p_clr',
            [
                'label' =>   esc_html__('Position Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pos' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'p_pad',
            [
                'label' =>   esc_html__( 'Position Margin', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .pos' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'p_typo',
                'label' =>   esc_html__('Position Typography', 'thepack'),
                'selector' => '{{WRAPPER}} .pos',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_carousel',
            [
                'label' =>   esc_html__('Carousel', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE, 
                'condition' => [
                    'disp' => 'slider',
                ],                             
            ]
        );

        $this->add_control(
            'arrow',
            [
                'label' =>   esc_html__('Display arrow', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );

        $this->add_control(
            'dot',
            [
                'label' =>   esc_html__('Display dot', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );

        $this->add_control(
            'auto',
            [
                'label' =>   esc_html__('Autoplay', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );

        $this->add_control(
            'space',
            [
                'label' =>   esc_html__('Spacing', 'thepack'),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],   
                'default' => [
                    'size' => 30,
                ],                            
            ]
        );

        $this->add_control(
            'item',
            [
                'label' =>   esc_html__( 'Item per slide', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 10,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'size' => 3,
                ],                
                'size_units' => [ 'px'],              
            ]
        );

        $this->add_control(
            'item_tab',
            [
                'label' =>   esc_html__( 'Item per slide - Tablet', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 5,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'size' => 2,
                ],                
                'size_units' => [ 'px'],              
            ]
        );

        $this->add_control(
            'speed',
            [
                'label' =>   esc_html__( 'Slide speed', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 8000,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'size' => 3000,
                ],      
                'condition' => [
                    'auto' => 'yes',
                ],                            
                'size_units' => [ 'px'],               
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_pagi',
            [
                'label' =>   esc_html__('Slider Arrow', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'arrow' => 'yes',
                ],                 
            ]
        );

        $this->add_control(
            'picon', [
                'type' => Controls_Manager::ICON,
                'label' =>   esc_html__('Prev icon', 'thepack'),
                'label_block' => true,
                'default' => 'fa-chevron-left',               
            ]
        );

        $this->add_control(
            'nicon', [
                'type' => Controls_Manager::ICON,
                'label' =>   esc_html__('Next icon', 'thepack'),
                'label_block' => true,
                'default' => 'fa-chevron-right',               
            ]
        );

        $this->add_control(
            'pgi_bg',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .no-bg' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'pgi_c',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .no-bg' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'pgwd',
            [
                'label' =>   esc_html__( 'Width and height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .no-bg' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'lheight',
            [
                'label' =>   esc_html__( 'Line-height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .no-bg' => 'line-height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'pgbrad',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .no-bg' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'lrspace',
            [
                'label' =>   esc_html__( 'Left-Right arrow position', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 500,
                        'min' => 1,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .swiper-button-prev' => 'left: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .swiper-button-next' => 'right: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_nav',
            [
                'label' =>   esc_html__('Slider Dot', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'dot' => 'yes',
                ],                
            ]
        );

        $this->add_responsive_control(
            'navpos',
            [
                'label' =>   esc_html__( 'Postion', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 300,
                        'min' => -300,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination' => 'bottom: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'navcol',
            [
                'label' =>   esc_html__('Dot color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullet' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'navacol',
            [
                'label' =>   esc_html__('Dot active color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullet-active' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {
        $settings = $this->get_settings();      
        require dirname(__FILE__) .'/view.php';
    }


    private function content($content,$column,$type,$imgsize) {

        foreach ($content as $item){

            switch ($type) {
                case "slider":
                    $cls = 'swiper-slide';
                    break;

                case "grid":
                    $cls = $column;
                    break;

                default:
            }

            $desc = $item['desc'] ? '<p class="desc">'.thepack_html($item['desc']). '</p>' : '';
            $img = thepack_ft_images($item['avatar']['id'],$imgsize); 
            $name = $item['name'] ? '<p class="name">'.thepack_html($item['name']). '</p>' : '';
            $pos = $item['pos'] ? '<p class="pos">'.thepack_html($item['pos']). '</p>' : '';

            $fb = $item['fb'] ? '<a href="'.esc_url($item['fb']).'" target="_blank"><i class="fa fa-facebook"></i></a>' : '';
            $tw = $item['tw'] ? '<a href="'.esc_url($item['tw']).'" target="_blank"><i class="fa fa-twitter"></i></a>' : '';
            $lnk = $item['lnk'] ? '<a href="'.esc_url($item['lnk']).'" target="_blank"><i class="fa fa-linkedin"></i></a>' : '';
            $ig = $item['ig'] ? '<a href="'.esc_url($item['ig']).'" target="_blank"><i class="fa fa-instagram"></i></a>' : '';
            $gp = $item['gp'] ? '<a href="'.esc_url($item['gp']).'" target="_blank"><i class="fa fa-google-plus"></i></a>' : '';

            $out1 .= '
                <div class="team2 '.$cls.'">
                    <div class="team-container">
                    
                        <div class="teamthmb">
                        '.$img.'
                        <div class="team-link">
                        '.$fb.$tw.$lnk.$ig.$gp.'
                        </div> 

                        </div>
                        <div class="team-content tbtr">
                            '.$name.$pos.'
                        </div>                       
                    </div>
                </div>
            ';

        }

        return $out1;

        
    }
    

}

 $widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_team2());