<?php

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base; 
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Scheme_Typography; 
use Elementor\utils;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_team3 extends Widget_Base {

    public function get_name() {
        return 'tbteam3';
    }

    public function get_title() {
        return   esc_html__('TEAM 3', 'thepack');
    }

    public function get_icon() {
        return 'eicon-sync';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_process_1',
            [
                'label' =>   esc_html__('Content', 'thepack'),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'label', [
                'label' =>   esc_html__( 'Name', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Fitness Programs',               
            ]
        );

        $repeater->add_control(
            'pos', [
                'label' =>   esc_html__( 'Position', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,              
            ]
        );

        $repeater->add_control(
            'desc', [
                'label' =>   esc_html__( 'Description', 'thepack' ),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,             
            ]
        );

        $repeater->add_control(
            'fb', [
                'label' =>   esc_html__('Facebook url', 'thepack'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        ); 

        $repeater->add_control(
            'tw', [
                'label' =>   esc_html__('Twitter url', 'thepack'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'lnk', [
                'label' =>   esc_html__('Linkedin url', 'thepack'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'ig', [
                'label' =>   esc_html__('Instagram url', 'thepack'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'gp', [
                'label' =>   esc_html__('Google plus url', 'thepack'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        ); 

        $repeater->add_control(
            'img', [
                'type' => Controls_Manager::MEDIA,
                'label' =>   esc_html__('Image', 'thepack'),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $repeater->add_control(
            'btn', [
                'label' =>   esc_html__( 'Button label', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,              
            ]
        );

        $repeater->add_control(
            'url', [
                'label' =>   esc_html__('Link', 'thepack'),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'placeholder' =>   esc_html__('http://your-link.com', 'thepack'),
            ]
        ); 
        $this->add_control(
            'items',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(), 
                'prevent_empty' => false, 
                'default' => [
                    [
                        'label' =>   esc_html__( 'Fitness Programs', 'thepack' ),
                    ]
                ],
                'title_field' => '{{{label}}}',                
            ]
        );

        $this->add_control(
            'img_size',
            [
                'label' =>   esc_html__('Image size', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' =>  thepack_image_size_choose(), 
                'multiple' => false,                                              
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'gbgclr',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbwrpr' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'width',
            [
                'label' =>   esc_html__( 'Content width in %', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER, 
                 'selectors' => [
                        '{{WRAPPER}} .inrcntnt' => 'width: {{SIZE}}%;',
                 ],                              
            ]
        );

        $this->add_responsive_control(
          'c_pd',
          [
             'label' =>   esc_html__( 'Content padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             
             'selectors' => [
                    '{{WRAPPER}} .inrcntnt' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );
        
        $this->add_control(
            'anim',
            [
                'label' =>   esc_html__('Animation', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'options' =>  thepack_animations(), 
                'label_block' => true 
            ]
        );

        $this->add_responsive_control(
            'btm_mrgn',
            [
                'label' =>   esc_html__( 'Bottom margin', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .tbwrpr' => 'margin-bottom: {{SIZE}}px;',
                ],

            ]
        );


        $this->end_controls_section(); 

        $this->start_controls_section(
            'section_img',
            [
                'label' =>   esc_html__('Image', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        ); 

        $this->add_control(
            'imghvr',
            [
                'label' =>   esc_html__( 'Image shadow', 'thepack' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__( 'Yes', 'thepack' ),
                'label_off' =>   esc_html__( 'No', 'thepack' ),
                'selectors' => [
                    '{{WRAPPER}} .tbimglyst img' => 'box-shadow: 2px 34px 30px -30px rgba(0,0,0,0.5);',
                ],                
            ]
        );

        $this->add_responsive_control(
            'imgbdr',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER, 
                 'selectors' => [
                        '{{WRAPPER}} .tbimglyst img' => 'border-radius: {{SIZE}}%;',
                 ],                              
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_pre',
            [
                'label' =>   esc_html__('Position', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        ); 

        $this->add_control(
            'ps_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pos' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'ps_typo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .pos',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_t',
            [
                'label' =>   esc_html__('Title', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        ); 

        $this->add_control(
            't_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
          't_margin',
          [
             'label' =>   esc_html__( 'Margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             
             'selectors' => [
                    '{{WRAPPER}} .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 't_typo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .title',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_cnt',
            [
                'label' =>   esc_html__('Description', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        ); 

        $this->add_control(
            'desc_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .description' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'desc_ty',
                'label' =>   esc_html__('Typography', 'thepack'),
                'selector' => '{{WRAPPER}} .description',
            ]
        );

        $this->add_responsive_control(
          'dmr',
          [
             'label' =>   esc_html__( 'Margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             
             'selectors' => [
                    '{{WRAPPER}} .description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_scl',
            [
                'label' =>   esc_html__('Social', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        ); 

        $this->add_control(
            'st_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-link a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'sth_color',
            [
                'label' =>   esc_html__('Hover color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-link:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'st_fs',
            [
                'label' =>   esc_html__( 'Font size', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .team-link' => 'font-size: {{SIZE}}px;',
                ],

            ]
        );

        $this->add_responsive_control(
            'st_mrgn',
            [
                'label' =>   esc_html__( 'Spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .team-link a' => 'padding:0px {{SIZE}}px;',
                    '{{WRAPPER}} .team-link' => 'margin:0px -{{SIZE}}px;',
                ],

            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_btn',
            [
                'label' =>   esc_html__('Button', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        ); 

        $this->add_responsive_control(
            'btn_mw',
            [
                'label' =>   esc_html__( 'Maximum width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .tour-btn' => 'width: {{SIZE}}{{UNIT}};display: inline-block;',
                ],

            ]
        );

        $this->add_control(
          'btn_pad',
          [
             'label' =>   esc_html__( 'Padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             
             'selectors' => [
                    '{{WRAPPER}} .tour-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .tour-btn',
            ]
        );

        $this->add_control(
            'btn_bgl',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tour-btn'=> 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btn_bgh',
            [
                'label' =>   esc_html__('Hover Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tour-btn:hover'=> 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btn_clr',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tour-btn'=> 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btn_clrh',
            [
                'label' =>   esc_html__('Hover Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tour-btn:hover'=> 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btn_bw',
            [
                'label' =>   esc_html__( 'Border width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .tour-btn' => 'border-width: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'btn_br',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .tour-btn' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'btn_bclr',
            [
                'label' =>   esc_html__('Border color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tour-btn'=> 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btn_bclrh',
            [
                'label' =>   esc_html__('Hover Border Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tour-btn:hover'=> 'border-color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();

    }

    protected function render() {
        $settings = $this->get_settings();      
        require dirname(__FILE__) .'/view.php';
    }


    private function content($content,$anim,$size) {
    

        foreach ($content as $item){

            $url = $item['url']['url'];
            $ext = $item['url']['is_external'];
            $nofollow = $item['url']['nofollow'];
            $url = ( isset($url) && $url ) ? 'href='.esc_url($url). '' : '';
            $ext = ( isset($ext) && $ext ) ? 'target= _blank' : '';
            $nofollow = ( isset($url) && $url ) ? 'rel=nofollow' : '';
            $link = $url.' '.$ext.' '.$nofollow;

            $bg = thepack_ft_images($item['img']['id'],$size);

            $btn = $item['btn'] ? '<a '.$link.' class="purecntr tour-btn">'.thepack_html($item['btn']).'</a>' : '';
            $label = $item['label'] ? '<h3 class="title">'.thepack_html($item['label']).'</h3>' :'';
            $pos = $item['pos'] ? '<span class="pos">'.thepack_html($item['pos']). '</span>' : '';
            $desc = $item['desc'] ? '<p class="description">'.thepack_html($item['desc']).'</p>' :'';

            $fb = $item['fb'] ? '<a href="'.esc_url($item['fb']).'" target="_blank"><i class="fa fa-facebook"></i></a>' : '';
            $tw = $item['tw'] ? '<a href="'.esc_url($item['tw']).'" target="_blank"><i class="fa fa-twitter"></i></a>' : '';
            $lnk = $item['lnk'] ? '<a href="'.esc_url($item['lnk']).'" target="_blank"><i class="fa fa-linkedin"></i></a>' : '';
            $ig = $item['ig'] ? '<a href="'.esc_url($item['ig']).'" target="_blank"><i class="fa fa-instagram"></i></a>' : '';
            $gp = $item['gp'] ? '<a href="'.esc_url($item['gp']).'" target="_blank"><i class="fa fa-google-plus"></i></a>' : '';

            $out .= '
                <div class="tbwrpr '.esc_attr($anim).'">
                    <div class="table-display">
                        <div class="tbimglyst col">
                            '.$bg.$btn.'
                        </div>
                        <div class="inrcntnt col">
                            '.$pos.$label.$desc.'
                            <div class="team-link">
                            '.$fb.$tw.$lnk.$ig.$gp.'
                            </div>                            
                        </div>
                    </div>                                                                                  
                </div>
            '; 
        }

        return $out;
        
    }
     

}

 $widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_team3());