<?php

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Scheme_Typography;
use Elementor\utils;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_testim_2 extends Widget_Base {

    public function get_name() {
        return 'tb_testim_2';
    }

    public function get_title() {
        return   esc_html__('TESTIMONIAL 2', 'thepack');
    }

    public function get_icon() {
        return 'eicon-sync';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_process_1',
            [
                'label' =>   esc_html__('Content', 'thepack'),
            ]
        );


        $repeater1 = new \Elementor\Repeater();

        $repeater1->add_control(
            'heading', [
                'label' =>   esc_html__( 'Heading', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Super fast service',               
            ]
        );

        $repeater1->add_control(
            'name', [
                'label' =>   esc_html__( 'Name', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Mr Wick',                               
            ]
        );

        $repeater1->add_control(
            'pos', [
                'label' =>   esc_html__( 'Position', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' =>'Google,Gamer',
            ]
        );

        $repeater1->add_control(
            'avatar', [
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'label_block' => true,
                'label' =>   esc_html__('Background Image', 'thepack'),
            ]
        );       

        $repeater1->add_control(
            'desc', [
                'label' =>   esc_html__('Comment', 'thepack'),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        ); 

        $this->add_control(
            'items',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater1->get_controls(), 
                'prevent_empty' => false,
                'default' => [
                    [
                        'name' =>   esc_html__( 'Mr Wick', 'thepack' ),
                    ]
                ],
                'title_field' => '{{{name}}}',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__('Content', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'align',
            [
                'label' =>   esc_html__('Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ]
                ], 
                'selectors' => [
                    '{{WRAPPER}} .content' => 'text-align: {{VALUE}};',
                ],                 
            ]
        );


        $this->add_control(
            'g_bg',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .content' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
          'g_pad',
          [
             'label' =>   esc_html__( 'Padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             
             'selectors' => [
                    '{{WRAPPER}} .content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_responsive_control(
            'c-max',
            [
                'label' =>   esc_html__( 'Max width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => ['%','px'],
                'selectors' => [
                    '{{WRAPPER}} .content' => 'max-width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'l-space',
            [
                'label' =>   esc_html__( 'Left spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => ['%','px'],
                'selectors' => [
                    '{{WRAPPER}} .content' => 'left: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'r-space',
            [
                'label' =>   esc_html__( 'Right spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => ['%','px'],
                'selectors' => [
                    '{{WRAPPER}} .content' => 'right: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
                [
                    'label'         =>   esc_html__('Box shadow','premium-addons-for-elementor'),
                    'name'          => 'img_box_sha',
                    'selector'      => '{{WRAPPER}} .content',
                ]
        );

        $this->end_controls_section(); 

        $this->start_controls_section(
            'section_head',
            [
                'label' =>   esc_html__('Heading', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,                 
            ]
        );

        $this->add_control(
            'h_clr',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .heading' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'h_mr',
            [
                'label' =>   esc_html__( 'Margin', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .heading' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'h_typo',
                'label' =>   esc_html__('Typography', 'thepack'),
                'selector' => '{{WRAPPER}} .heading',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_quote',
            [
                'label' =>   esc_html__('Quote content', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,                 
            ]
        );

        $this->add_control(
            'q_clr',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .desc' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'q_pad',
            [
                'label' =>   esc_html__( 'Padding', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .desc' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'q_typo',
                'label' =>   esc_html__('Typography', 'thepack'),
                'selector' => '{{WRAPPER}} .desc',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_avtr',
            [
                'label' =>   esc_html__('Image', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'avtr_m',
            [
                'label' =>   esc_html__( 'Max width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1500,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => ['%','px'],
                'selectors' => [
                    '{{WRAPPER}} .xld-image' => 'max-width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_meta',
            [
                'label' =>   esc_html__('Meta', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,                
            ]
        );


        $this->add_control(
            'n_color',
            [
                'label' =>   esc_html__('Name Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .name' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'pos_color',
            [
                'label' =>   esc_html__('Position Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pos' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'pos_pad',
            [
                'label' =>   esc_html__( 'Position Padding', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .pos' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'n_typo',
                'label' =>   esc_html__('Name Typography', 'thepack'),
                'selector' => '{{WRAPPER}} .name',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'pos_typo',
                'label' =>   esc_html__('Position Typography', 'thepack'),
                'selector' => '{{WRAPPER}} .pos',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_carousel',
            [
                'label' =>   esc_html__('Carousel settings', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,                
            ]
        );

        $this->add_control(
            'auto',
            [
                'label' =>   esc_html__('Autoplay', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',               
            ]
        );

        $this->add_control(
            'dot',
            [
                'label' =>   esc_html__('Display dot', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',               
            ]
        );

        $this->add_control(
            'dot_pos',
            [
                'label' =>   esc_html__('Dot position', 'thepack'),
                'type' => Controls_Manager::NUMBER,
                'default' => 4,
                'px' => [
                    'min' => 0,
                    'max' => 50,
                    'step' => 1,
                ],                
                'selectors' => [
                    '{{WRAPPER}} .slick-dots' => 'bottom: {{SIZE}}px;',
                ],                
            ]
        );

        $this->add_control(
            'dot_pri',
            [
                'label' =>   esc_html__('Dot main color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-dots li button' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'dot_sec',
            [
                'label' =>   esc_html__('Dot secondary color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-dots li.slick-active button' => 'box-shadow:0 0 0 2px {{VALUE}}',
                ],
            ]
        );                
        $this->end_controls_section();

    }

    protected function render() {
        $settings = $this->get_settings();      
        require dirname(__FILE__) .'/view.php';
    }


    private function content($content,$template,$column) {

        foreach ($content as $item){

            $heading = $item['heading'] ? '<h3 class="heading">'.$item['heading']. '</h3>' : '';
            $desc = $item['desc'] ? '<p class="desc">'.$item['desc']. '</p>' : '';
            $img = wp_get_attachment_image($item['avatar']['id'], 'full', false, array('class' => 'xlteam'));
            $name = $item['name'] ? '<p class="name">'.$item['name']. '</p>' : '';
            $pos = $item['pos'] ? '<p class="pos">'.$item['pos']. '</p>' : '';

            $out1 .= '
                <div class="testi-wrap">
                    <div class="content">
                        '.$heading.$desc.$name.$pos.'
                    </div>
                    <div class="xld-image">'.$img.'</div>
                </div>
            '; 

        }

        return $out1;
        
    }
    

}

 $widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_testim_2());