<?php

/*
Widget Name: Webangon Imagelayer
Description: Create image layers
Author: Webangon
Author URI: https://www.webangon.com
*/

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Scheme_Typography;
use Elementor\Utils;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_txtart1 extends Widget_Base {

    public function get_name() {
        return 'tb_tart1';
    }

    public function get_title() {
        return   esc_html__('TEXT ART1', 'thepack');
    }

    public function get_icon() {
        return 'eicon-insert-image';
    }
    
    public function get_categories() {
        return array('ashelement-addons');
    } 

    protected function _register_controls() {

        $this->start_controls_section(
            'section_heading',
            [
                'label' =>   esc_html__('Content', 'thepack'),
            ]
        );

        $this->add_control(
            'tmpl',
            [
                'label' =>   esc_html__('Template', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'one' => [
                        'title' =>   esc_html__('One', 'thepack'),
                        'icon' => 'fa fa-folder',
                    ],
                    'two' => [
                        'title' =>   esc_html__('Two', 'thepack'),
                        'icon' => 'fa fa-folder-o',
                    ],
                ],
                'default' => 'one',               
            ]
        );

        $this->add_control(
            'label', [
                'label' =>   esc_html__( 'Label', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => '5',               
            ]
        );


        $this->add_control(
            'icon', [
                'label' =>   esc_html__( 'Icon', 'thepack' ),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,                              
            ]
        );
        $this->end_controls_section();


        $this->start_controls_section(
            'section_genrl',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'gpos',
            [
                'label' =>   esc_html__( 'Position - vertical positioning', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => -800,
                        'max' => 800,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                        'step' => 1,
                    ],                    
                ],
                'size_units' => [ 'px','%'],
                'selectors' => [
                    '{{WRAPPER}} .thepack_txtart1' => 'top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'lpos',
            [
                'label' =>   esc_html__( 'Position - horizontal positioning', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => -800,
                        'max' => 800,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                        'step' => 1,
                    ],                    
                ],
                'size_units' => [ 'px','%'],
                'selectors' => [
                    '{{WRAPPER}} .thepack_txtart1' => 'left: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_lbl',
            [
                'label' =>   esc_html__('Number', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'mrht',
            [
                'label' =>   esc_html__( 'Margin right', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ]                   
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .number' => 'margin-right: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
          'hlbl',
          [
             'type'    => Controls_Manager::RAW_HTML,
             'raw' =>   esc_html__( 'Background', 'thepack' ),
          ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'overlay_color',
                'label' =>   esc_html__( 'Text background', 'elementor' ),
                'types' => [ 'none', 'classic','gradient' ],
                'selector' => '{{WRAPPER}} .number',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'num_ty',
                'label' =>   esc_html__('Typography', 'thepack'),
                'selector' => '{{WRAPPER}} .number',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_icn',
            [
                'label' =>   esc_html__('Heading', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'icol',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .text' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'h_ty',
                'label' =>   esc_html__('Typography', 'thepack'),
                'selector' => '{{WRAPPER}} .text',
            ]
        );

        $this->add_responsive_control(
            'hvpos',
            [
                'label' =>   esc_html__( 'Vertical positioning', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'condition' => [
                    'tmpl' => 'two',
                ],                
                'range' => [
                    'px' => [
                        'min' => -800,
                        'max' => 800,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                        'step' => 1,
                    ],                    
                ],
                'size_units' => [ 'px','%'],
                'selectors' => [
                    '{{WRAPPER}} .thepack_txtart1.two .text' => 'top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'vvpos',
            [
                'label' =>   esc_html__( 'Horizontal positioning', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'condition' => [
                    'tmpl' => 'two',
                ],                
                'range' => [
                    'px' => [
                        'min' => -800,
                        'max' => 800,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                        'step' => 1,
                    ],                    
                ],
                'size_units' => [ 'px','%'],
                'selectors' => [
                    '{{WRAPPER}} .thepack_txtart1.two .text' => 'left: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_txtbg',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'xtbg',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .text' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
          't-pad',
          [
             'label' =>   esc_html__( 'Margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'em','px'],
             'selectors' => [
                    '{{WRAPPER}} .text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings();
        $num = $settings['label'] ? '<div class="number">'.thepack_html($settings['label']).'</div>' : '';
        $text = $settings['icon'] ? '<div class="text">'.thepack_html($settings['icon']). '</div>' : '';


        ?>

        <div class="thepack_txtart1 <?php echo esc_attr($settings['tmpl']);?>">
            <?php echo $num.$text ;?>
        </div>        

        <style type="text/css">
        .thepack_txtart1 {
            position: absolute;
            left: 10%;
            top: -90px;
        }
        .thepack_txtart1 .number {
            display: inline-block;
            font-weight: 600;
            font-size: 150px;
            margin-right: 20px;
            -webkit-background-clip: text;
            -webkit-text-fill-color: transparent;            
        }
        .thepack_txtart1 .text {
            display: inline-block;
            font-size: 18px;
        }
        .thepack_txtart1.two .text{
            top: 50%;
            transform: translateY(-50%);
            position: absolute;
            left: 27%;
        }   

        </style>

    <?php }

    protected function content_template() {
    }

}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_txtart1());