<?php

/*
Widget Name: Webangon Imagelayer
Description: Create image layers
Author: Webangon
Author URI: https://www.webangon.com
*/

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;
use Elementor\Scheme_Typography;
use Elementor\Utils;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_txtart3 extends Widget_Base {

    public function get_name() {
        return 'tb_tart3';
    }

    public function get_title() {
        return   esc_html__('TEXT ART3', 'thepack');
    }

    public function get_icon() {
        return 'eicon-insert-image';
    }
    
    public function get_categories() {
        return array('ashelement-addons');
    } 

    protected function _register_controls() {

        $this->start_controls_section(
            'section_heading',
            [
                'label' =>   esc_html__('Content', 'thepack'),
            ]
        );

        $this->add_control(
            'tmpl',
            [
                'label' =>   esc_html__('Template', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'one' => [
                        'title' =>   esc_html__('One', 'thepack'),
                        'icon' => 'fa fa-folder',
                    ],
                    'two' => [
                        'title' =>   esc_html__('Two', 'thepack'),
                        'icon' => 'fa fa-folder-o',
                    ],
                ],
                'default' => 'one',               
            ]
        );

        $this->add_control(
            'label', [
                'label' =>   esc_html__( 'Label', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => '5',               
            ]
        );


        $this->add_control(
            'icon', [
                'label' =>   esc_html__( 'Icon', 'thepack' ),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,                              
            ]
        );
        $this->end_controls_section();


        $this->start_controls_section(
            'section_genrl',
            [
                'label' =>   esc_html__('Box background', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'bwh',
            [
                'label' =>   esc_html__( 'Width and height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 800,
                        'step' => 1,
                    ],                  
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .number:after' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'bvp',
            [
                'label' =>   esc_html__( 'Vertical position', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => -800,
                        'max' => 800,
                        'step' => 1,
                    ],                  
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .number:after' => 'top:{{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'hvp',
            [
                'label' =>   esc_html__( 'Horizontal position', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => -800,
                        'max' => 800,
                        'step' => 1,
                    ],                  
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .number:after' => 'left:{{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'bclr',
            [
                'label' =>   esc_html__('Border color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .number:after' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'bth',
            [
                'label' =>   esc_html__( 'Border thickness', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 20,
                        'step' => 1,
                    ],                  
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .number:after' => 'border-width:{{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_lbl',
            [
                'label' =>   esc_html__('Number', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'nvp',
            [
                'label' =>   esc_html__( 'Vertical position', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ]                   
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .number span' => 'top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'nhp',
            [
                'label' =>   esc_html__( 'Horizontal position', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                        'step' => 1,
                    ]                   
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .number span' => 'left: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
          'hlbl',
          [
             'type'    => Controls_Manager::RAW_HTML,
             'raw' =>   esc_html__( 'Background', 'thepack' ),
          ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'overlay_color',
                'label' =>   esc_html__( 'Text color', 'elementor' ),
                'types' => [ 'none', 'classic','gradient' ],
                'selector' => '{{WRAPPER}} .number span',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'num_ty',
                'label' =>   esc_html__('Typography', 'thepack'),
                'selector' => '{{WRAPPER}} .number span',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_icn',
            [
                'label' =>   esc_html__('Heading', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'icol',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .text' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'h_ty',
                'label' =>   esc_html__('Typography', 'thepack'),
                'selector' => '{{WRAPPER}} .text',
            ]
        );

        $this->add_responsive_control(
            'hvpos',
            [
                'label' =>   esc_html__( 'Vertical positioning', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,              
                'range' => [
                    'px' => [
                        'min' => -800,
                        'max' => 800,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                        'step' => 1,
                    ],                    
                ],
                'size_units' => [ 'px','%'],
                'selectors' => [
                    '{{WRAPPER}} .thepack_txtart3 .text' => 'top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'vvpos',
            [
                'label' =>   esc_html__( 'Horizontal positioning', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,              
                'range' => [
                    'px' => [
                        'min' => -800,
                        'max' => 800,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                        'step' => 1,
                    ],                    
                ],
                'size_units' => [ 'px','%'],
                'selectors' => [
                    '{{WRAPPER}} .thepack_txtart3 .text' => 'left: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';
    }

}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_txtart3());