<?php

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Scheme_Typography; 
use Elementor\utils;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_tymlyn3 extends Widget_Base {

    public function get_name() {
        return 'tb_tymlyn3';
    }

    public function get_title() {
        return   esc_html__('TIMELINE 3', 'thepack');
    }

    public function get_icon() {
        return 'eicon-sync';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_process_1',
            [
                'label' =>   esc_html__('Content', 'thepack'),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'title', [
                'label' =>   esc_html__( 'Title', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Frontend Web Developer',               
            ]
        );

        $repeater->add_control(
            'sub', [
                'label' =>   esc_html__( 'Sub title', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,               
            ]
        );

        $repeater->add_control(
            'type', [
                'label' =>   esc_html__('Image/Icon', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'img' => [
                        'title' =>   esc_html__('Image', 'thepack'),
                        'icon' => ' eicon-document-file',
                    ],
                    'icon' => [
                        'title' =>   esc_html__('Icon', 'thepack'),
                        'icon' => 'eicon-image-rollover',
                    ]
                ],
                'default' => 'img',
                'label_block' => true,                
            ]
        );

        $repeater->add_control(
            'img', [
                'label' =>   esc_html__( 'Image', 'thepack' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'label_block' => true,
                'condition' => [
                    'type' => 'img',
                ],                
            ]
        );      

        $repeater->add_control(
            'icon',
            [
                'type' => Controls_Manager::ICON,
                'label' =>   esc_html__('Icon', 'thepack'),
                'label_block' => true,
                'condition' => [
                    'type' => 'icon',
                ],                 
            ]
        );

        $repeater->add_control(
            'desc', [
                'label' =>   esc_html__( 'Description', 'thepack' ),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default' =>'Full Time - London, United Kingdom - Published 4 months ago',
            ]
        );

        $repeater->add_control(
            'btn', [
                'label' =>   esc_html__( 'Button Label', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Apply',               
            ]
        );

        $repeater->add_control(
            'url', [
                'label' =>   esc_html__('Link', 'thepack'),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'placeholder' =>   esc_html__('http://your-link.com', 'thepack'),
            ]
        ); 
        $this->add_control(
            'items',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(), 
                'prevent_empty' => false,
                'default' => [
                    [
                        'title' =>   esc_html__( 'Frontend Web Developer', 'thepack' ),
                    ]
                ],
                'title_field' => '{{{ title }}}',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
          'g_margin',
          [
             'label' =>   esc_html__( 'Content padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             'selectors' => [
                    '{{WRAPPER}} .tb_tymlyn3-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .tb_tymlyn3-content.lastitm' => 'padding-bottom: 0px;',
             ],
          ]
        );

        $this->add_responsive_control(
            'vbrlp',
            [
                'label' =>   esc_html__( 'Vertical line left spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .tb_tymlyn3::before' => 'left: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'vbrbg',
            [
                'label' =>   esc_html__('Vertical bar background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tb_tymlyn3::before' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section(); 

        $this->start_controls_section(
            'section_img',
            [
                'label' =>   esc_html__('Image/Icon', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'img_wid',
            [
                'label' =>   esc_html__( 'Width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .tb_tymlyn3-picture' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'ikbg',
            [
                'label' =>   esc_html__('Icon background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .iknwrp' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'iknclr',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .iknwrp' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'ikbpd',
            [
                'label' =>   esc_html__( 'Icon content bottom spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .tb_tymlyn3-content.hasikn' => 'padding-bottom: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'ikvp',
            [
                'label' =>   esc_html__( 'Icon vertical position', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .iknwrp' => 'line-height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'ikfs',
            [
                'label' =>   esc_html__( 'Icon size', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .iknwrp' => 'font-size: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'img_br',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .tb_tymlyn3-picture img,{{WRAPPER}} .iknwrp' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_stitle',
            [
                'label' =>   esc_html__('Sub title', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'st_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sub' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'st_bcolor',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sub' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
          'st_pd',
          [
             'label' =>   esc_html__( 'Padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             'selectors' => [
                    '{{WRAPPER}} .sub' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};display:inline-block;',
             ],
          ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'st_typo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .sub',
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_title',
            [
                'label' =>   esc_html__('Title', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            't_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
          't_margin',
          [
             'label' =>   esc_html__( 'Margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             'selectors' => [
                    '{{WRAPPER}} .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 't_typo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .title',
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_desc',
            [
                'label' =>   esc_html__('Description', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'desc_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .description' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'desc_ty',
                'label' =>   esc_html__('Typography', 'thepack'),
                'selector' => '{{WRAPPER}} .description',
            ]
        );


        $this->add_control(
          'desc_margin',
          [
             'label' =>   esc_html__( 'Margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             'selectors' => [
                    '{{WRAPPER}} .description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_btn',
            [
                'label' =>   esc_html__('Button', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
          'btn_pad',
          [
             'label' =>   esc_html__( 'Padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             'selectors' => [
                    '{{WRAPPER}} .tbtn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .tbtn',
            ]
        );

        $this->add_control(
            'btn_bgl',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbtn'=> 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btn_bgh',
            [
                'label' =>   esc_html__('Hover Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbtn:hover'=> 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btn_clr',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbtn'=> 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btn_clrh',
            [
                'label' =>   esc_html__('Hover Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbtn:hover'=> 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btn_bw',
            [
                'label' =>   esc_html__( 'Border width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .tbtn' => 'border-width: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'btn_bclr',
            [
                'label' =>   esc_html__('Border color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbtn'=> 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btn_bclrh',
            [
                'label' =>   esc_html__('Hover Border Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbtn:hover'=> 'border-color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();

    }

    protected function render() {
        $settings = $this->get_settings();      
        require dirname(__FILE__) .'/view.php';
    }


    private function content($content) {
        
        foreach ($content as $item){

            $sub = $item['sub'] ? '<span class="sub">'.esc_attr($item['sub']). '</span>' : '';
            $title = $item['title'] ? '<h3 class="title">'.esc_attr($item['title']). '</h3>' : '';
            $desc = $item['desc'] ? '<p class="description">'.esc_attr($item['desc']). '</p>' : '';

            $url = $item['url']['url'];
            $ext = $item['url']['is_external'];
            $nofollow = $item['url']['nofollow'];
            $url = ( isset($url) && $url ) ? 'href='.esc_url($url). '' : '';
            $ext = ( isset($ext) && $ext ) ? 'target= _blank' : '';
            $nofollow = ( isset($url) && $url ) ? 'rel=nofollow' : '';
            $link = $url.' '.$ext.' '.$nofollow;

            $btn = $item['btn'] ? '<a '.$link.' class="tbtn">'.thepack_html($item['btn']).'</a>' : '';

            if ($item['type']=='img'){
                $imgik = $item['img']['id'] ? '<figure>'.thepack_ft_images($item['img']['id'], 'full'). '</figure>' : '';
                $bcls = '';
            } else {
                $imgik = $item['icon'] ? '<figure class="iknwrp"><i class="tbicon '.esc_attr($item['icon']).'"></i></figure>' : '';
                $bcls = 'hasikn';
            }

            if(!next($content)) {
                $last = 'lastitm';
            }

            $out .= '
                <div class="tb_tymlyn3-block">
                  <div class="tb_tymlyn3-picture">
                    '.$imgik.'
                  </div>

                  <div class="tb_tymlyn3-content '.$last.' '.$bcls.'">
                    '.$sub.$title.$desc.$btn.'
                  </div>
                </div>            
            '; 
        }

        return $out;
        
    }
     

}

 $widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_tymlyn3());