<?php
/*
Widget Name: Webangon Servicebox
Description: Servicebox in 4 items with center image
Author: Webangon
Author URI: https://www.webangon.com
*/

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;
use Elementor\Scheme_Typography;
use Elementor\Utils;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_tooltipfolio extends Widget_Base {

    public function get_name() {
        return 'ae-tipfolio';
    }

    public function get_title() {
        return   esc_html__('TOOLTIP FOLIO', 'thepack');
    }

    public function get_categories() {
        return array('ashelement-addons');
    } 
    
    public function get_icon() {
        return 'eicon-accordion';
    }


    protected function _register_controls() {

        $this->start_controls_section(
            'section_heading',
            [
                'label' =>   esc_html__('Content', 'thepack'),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'type', [
                'label' =>   esc_html__('Population', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'content' => [
                        'title' =>   esc_html__('No tooltip', 'thepack'),
                        'icon' => ' eicon-document-file',
                    ],
                    'template' => [
                        'title' =>   esc_html__('Tooltip', 'thepack'),
                        'icon' => 'eicon-image-rollover',
                    ]
                ],
                'default' => 'content',
                'label_block' => true,                
            ]
        );

        $repeater->add_control(
            'title', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Label', 'thepack'),
                'label_block' => true,
                'default' =>'Car Insurance',
            ]
        );

        $repeater->add_control(
            'url', [
                'label' =>   esc_html__('Label url', 'thepack'),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'placeholder' =>   esc_html__('http://your-link.com', 'thepack'),                                
            ]
        );

        $repeater->add_control(
            'img', [
                'type' => Controls_Manager::MEDIA,
                'label' =>   esc_html__('Image', 'thepack'),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'type' => 'template',
                ],                
            ]
        );

        $repeater->add_control(
            'desc', [
                'type' => Controls_Manager::TEXTAREA,
                'label' =>   esc_html__('Description', 'thepack'),
                'condition' => [
                    'type' => 'template',
                ],                
            ]
        );
                                
        $this->add_control(
            'tabs',
            [
                'type' => Controls_Manager::REPEATER,
                'prevent_empty' => false,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'title' =>   esc_html__( 'Finance', 'thepack' ),
                    ]
                ],
                'title_field' => '{{{ title }}}',
            ]
        );

        $this->add_control(
            'img_size',
            [
                'label' =>   esc_html__('Image size', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' =>  thepack_image_size_choose(), 
                'multiple' => false,                                
            ]
        );
        
        $this->end_controls_section();

        $this->start_controls_section(
            'section_gnrl',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
 
        $this->add_control(
            'it_bg',
            [
                'label' =>   esc_html__( 'Background', 'thepack' ),
                'type' => Controls_Manager::COLOR,               
            ]
        );

        $this->add_control(
            'n_color',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
            ]
        );

        $this->add_control(
          'anim',
          [
             'label'       =>   esc_html__( 'Animation', 'thepack' ),
             'type' => Controls_Manager::SELECT,
             'default' => 'bounce',
             'label_block' => true,
             'options' => [
                'bounce'  =>   esc_html__( 'Bounce', 'thepack' ),
                'fade' =>   esc_html__( 'Fade', 'thepack' ),
                'material' =>   esc_html__( 'Material', 'thepack' ),
                'float' =>   esc_html__( 'Float', 'thepack' ),

             ],
          ]
        );

        $this->add_control(
          'pos',
          [
             'label'       =>   esc_html__( 'Position', 'thepack' ),
             'type' => Controls_Manager::SELECT,
             'default' => 'top',
             'label_block' => true,
             'options' => [
                'top'  =>   esc_html__( 'Top', 'thepack' ),
                'bottom' =>   esc_html__( 'Bottom', 'thepack' ),
                'left' =>   esc_html__( 'Left', 'thepack' ),
                'right' =>   esc_html__( 'Right', 'thepack' ),
             ],
          ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_title',
            [
                'label' =>   esc_html__('Title', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'align',
            [
                'label' =>   esc_html__('Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .foliotips' => 'text-align: {{VALUE}};',
                ],                              
            ]
        ); 
        $this->add_control(
          't-pad',
          [
             'label' =>   esc_html__( 'Padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'em','px'],
             'selectors' => [
                    '{{WRAPPER}} .myTooltip.title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_control(
            'nv_color',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tipfoliolink' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'h_color',
            [
                'label' =>   esc_html__('Underline color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tipfoliolink:after' => 'border-top: 2px solid {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typo',
                'selector' => '{{WRAPPER}} .tipfoliolink',
                'label' =>   esc_html__( 'Underline typography', 'thepack' ),
            ]
        );

        $this->add_control(
            'nr_color',
            [
                'label' =>   esc_html__('No link color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .no-tip' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'nr_typo',
                'selector' => '{{WRAPPER}} .no-tip',
                'label' =>   esc_html__( 'No link typography', 'thepack' ),
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/accordion.php';
    }

    private function icon_image($icon,$size) { 

        $type = $icon['type'];
        if ($type == 'template'){

            $id = $icon['img']['id'];
            $img = $id ? wp_get_attachment_image($id, $size) : '';            
            $desc = $icon['desc'] ? ''.$icon['desc'].'' : '';
            return '<div class="tipdes">'.$img.$desc.'</div>';
        }
    }

}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_tooltipfolio());