<?php

/*
Widget Name: Webangon Servicebox
Description: Servicebox in 4 items with center image
Author: Webangon
Author URI: https://www.webangon.com
*/

namespace WebangonAddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Utils;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_video_popup extends Widget_Base {

    public function get_name() {
        return 'aevidpopup';
    }

    public function get_title() {
        return   esc_html__('VIDEO POPUP', 'thepack');
    }

    public function get_icon() {
        return ' eicon-youtube';
    }

    public function get_categories() {
        return array('ashelement-addons');
    } 

    protected function _register_controls() {

        $this->start_controls_section(
            'section_heading',
            [
                'label' =>   esc_html__('Video Popup', 'thepack'),
            ]
        );

        $this->add_control(
            'url',
            [
                'type' => 'textarea',
                'label' =>   esc_html__('Url', 'thepack'),
                'label_block' => true,
                'default' => 'https://www.youtube.com/embed/ABYoaAH6OlI',
                'description' =>   esc_html__('Video embed url', 'thepack'),
            ]
        );

        $this->add_control(
            'btn-text',
            [
                'type' => 'text',
                'label' =>   esc_html__('Button label', 'thepack'),
                'label_block' => true,
            ]
        ); 

        $this->add_control(
            'img',
            [
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'label_block' => true,
                'label' =>   esc_html__('Placeholder image', 'thepack'),
            ]
        );

        $this->add_control(
            'icon',
            [
                'type' => Controls_Manager::ICON,
                'label' =>   esc_html__('Play Icon', 'thepack'),
                'label_block' => true,
            ]
        );


        $this->end_controls_section();


        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        
        $this->add_control(
            'full_width',
            [
                'label' =>   esc_html__( 'Full width', 'elementor' ),
                'type' => Controls_Manager::SWITCHER,
                'selectors' => [
                    '{{WRAPPER}} .video-pop a' => 'display:block;',
                ],
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label' =>   esc_html__('Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' =>   esc_html__('Justified', 'thepack'),
                        'icon' => 'fa fa-align-justify',
                    ],
                ],
                'default' => 'center',
                'selectors' => [
                    '{{WRAPPER}} .video-pop' => 'text-align: {{VALUE}};',
                ], 
                'condition' => [
                    'full_width!' => 'yes',
                ],                               
            ]
        );

        $this->add_responsive_control(
            'width',
            [
                'label' =>   esc_html__( 'Max width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    'em' => [
                        'min' => 0,
                        'max' => 10,
                    ],
                ],
                'size_units' => [ 'px', 'em','%' ],
                'selectors' => [
                    '{{WRAPPER}} .video-pop a' => 'max-width: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'full_width!' => 'yes',
                ], 
            ]
        );  

        $this->add_control(
            'animation',
            [
                'label' =>   esc_html__('Animation', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'options' =>  thepack_animations(), 
                'multiple' => false,
                'label_block' => true                              
            ]
        ); 

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typo',
                'selector' => '{{WRAPPER}} .btn-label',
                'fields_options' => [
                    'typography' => [
                        'label' =>   esc_html__( 'Button label typo', 'thepack' ),
                    ],
                ],               
            ]
        );  

        $this->add_control(
            'btn_label_color',
            [
                'label' =>   esc_html__( 'Button label color', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .btn-label' => 'color: {{VALUE}};'
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_image',
            [
                'label' =>   esc_html__('Image', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
                [
                    'label'         =>   esc_html__('Shadow','premium-addons-for-elementor'),
                    'name'          => 'img_box_sha',
                    'selector'      => '{{WRAPPER}} .video-pop img',
                ]
        );

        $this->add_responsive_control(
            'img_brad',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .video-pop img' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_icon',
            [
                'label' =>   esc_html__('Icon', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'overlay_color',
                'label' =>   esc_html__( 'Background', 'elementor' ),
                'types' => [ 'none', 'classic','gradient' ],
                'selector' => '{{WRAPPER}} .video-pop i',
            ]
        );

        $this->add_control(
            'icon_c',
            [
                'label' =>   esc_html__( 'Icon color', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .video-pop i' => 'color: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'icon_width',
            [
                'label' =>   esc_html__( 'Play button width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .video-pop i' => 'width: {{SIZE}}px;height: {{SIZE}}px;',
                ],
            ]
        );

        $this->add_control(
            'icon_lheight',
            [
                'label' =>   esc_html__( 'Icon line-height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .video-pop i' => 'line-height: {{SIZE}}px;',
                ],
            ]
        );

        $this->add_control(
            'btn_size',
            [
                'label' =>   esc_html__( 'Icon font size', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .video-pop i'=>'font-size: {{SIZE}}px;',
                ],
            ]
        );

        $this->add_control(
            'btn_rad',
            [
                'label' =>   esc_html__( 'Button border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .video-pop i'=>'border-radius: {{SIZE}}px;',
                ],
            ]
        );

        $this->add_responsive_control(
            'captp',
            [
                'label' =>   esc_html__( 'Top spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 1000,
                        'min' => -1000,
                        'step' => 1,
                    ]
                ],
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} .video-pop.has-bg i' => 'top: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'capbt',
            [
                'label' =>   esc_html__( 'Bottom spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 1000,
                        'min' => -1000,
                        'step' => 1,
                    ]
                ],
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} .video-pop.has-bg i' => 'bottom: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'caplf',
            [
                'label' =>   esc_html__( 'Left spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 1000,
                        'min' => -1000,
                        'step' => 1,
                    ]
                ],
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} .video-pop.has-bg i' => 'left: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'caprt',
            [
                'label' =>   esc_html__( 'Right spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 1000,
                        'min' => -1000,
                        'step' => 1,
                    ]
                ],
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} .video-pop.has-bg i' => 'right: {{SIZE}}{{UNIT}};',
                ],

            ]
        );
        $this->end_controls_section();
    }

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';

    }
}

$widgets_manager->register_widget_type(new \WebangonAddon\Widgets\thepack_video_popup());