<?php
 
namespace WebangonAddon;
// Exit if accessed directly 

if (!defined('ABSPATH'))
    exit;

if (!class_exists('thepack_elementor_addon_widget')) :

    /**
     * Main thepack_elementor_addon_widget Class
     *
     */
    final class thepack_elementor_addon_widget {

        /** Singleton *************************************************************/

        private static $instance;

        /**
         * Main thepack_elementor_addon_widget Instance
         *
         * Insures that only one instance of thepack_elementor_addon_widget exists in memory at any one
         * time. Also prevents needing to define globals all over the place.
         */
        public static function instance() {

            if (!isset(self::$instance) && !(self::$instance instanceof thepack_elementor_addon_widget)) {

                self::$instance = new thepack_elementor_addon_widget;

                self::$instance->thepack_setup_constants();

                self::$instance->thepack_includes();

                self::$instance->thepack_hooks();

            }
            return self::$instance;
        }

        /**
         * Throw error on object clone
         *
         * The whole idea of the singleton design pattern is that there is a single
         * object therefore, we don't want the object to be cloned.
         */
        public function __clone() {
            // Cloning instances of the class is forbidden
            _doing_it_wrong(__FUNCTION__,   esc_html__('Cheatin&#8217; huh?', 'thepack'), '1.6');
        }

        /**
         * Disable unserializing of the class
         *
         */
        public function __wakeup() {
            // Unserializing instances of the class is forbidden
            _doing_it_wrong(__FUNCTION__,   esc_html__('Cheatin&#8217; huh?', 'thepack'), '1.6');
        }

        /**
         * Setup plugin constants
         *
         */
        private function thepack_setup_constants() {

            // Plugin version

            // Plugin Folder Path
            if (!defined('AE_PLUGIN_DIR')) {
                define('AE_PLUGIN_DIR', plugin_dir_path(__FILE__));
            }

            // Plugin Folder URL
            if (!defined('AE_PLUGIN_URL')) {
                define('AE_PLUGIN_URL', plugin_dir_url(__FILE__));
            }

            // Plugin Folder Path
            if (!defined('AE_ADDONS_DIR')) {
                define('AE_ADDONS_DIR', plugin_dir_path(__FILE__) . 'includes/widgets/');
            }

        }

        /**
         * Include required files
         *
         */
        private function thepack_includes() {


            require_once AE_PLUGIN_DIR . 'includes/helper-functions.php';
            require_once AE_PLUGIN_DIR . 'includes/query-functions.php';
            require_once AE_PLUGIN_DIR . 'includes/template-lib.php';
            require_once AE_PLUGIN_DIR . 'includes/element-hooks.php';

        }

        /**
         * Setup the default hooks and actions
         */ 
        private function thepack_hooks() {

            add_action('elementor/widgets/widgets_registered', array(self::$instance, 'thepack_include_widgets'));
            add_action('elementor/frontend/after_register_scripts', array($this, 'thepack_frontend_scripts'));
            add_action('elementor/frontend/after_enqueue_styles', array($this, 'thepack_frontend_styles'));
            add_action( 'elementor/element/section/section_advanced/after_section_end', array( $this, 'thepack_after_column_section' ), 10, 2 );

            add_action( 'elementor/frontend/section/before_render',  array( $this, 'thepack_before_column' ) );

            add_action('elementor/editor/after_enqueue_scripts', array($this, 'thepack_builder_styles'));

            add_action('elementor/init', array($this, 'thepack_add_elementor_category'));
            add_action( 'elementor/init', array( $this, 'thepack_controls_registered' ) );  

            add_action( 'elementor/element/before_section_end', function( $element, $section_id, $args ) {

                if ( 'icon-box' === $element->get_name() ) {

                    $element->add_control(
                        'icon-boxhm',
                        [
                            'label' =>   esc_html__( 'Heading margin', 'elementor' ),
                            'type' => \Elementor\Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px','%' ],                  
                            'selectors' => [
                                '{{WRAPPER}} .elementor-icon-box-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                        ]
                    );

                }


                if ( 'column' === $element->get_name() ) {

                        $element->add_control(
                            'xl_raisedh',
                            [
                                'label' =>   esc_html__( 'Raised on hover', 'thepack' ),
                                'type' => \Elementor\Controls_Manager::SWITCHER,
                                'default' => '',
                                'label_on' =>   esc_html__( 'Yes', 'thepack' ),
                                'label_off' =>   esc_html__( 'No', 'thepack' ),
                                'prefix_class' => 'xl-raisedhover-',
                            ]
                        );

                        $element->add_group_control(
                            \Elementor\Group_Control_Box_Shadow::get_type(),
                                [
                                    'label'         =>   esc_html__('Hover Shadow','premium-addons-for-elementor'),
                                    'name'          => 'box_sha',
                                    'selector'      => '{{WRAPPER}} .elementor-element-populated:hover',
                                    'condition' => [
                                        'xl_raisedh' => 'yes',
                                    ],                                    
                                ]
                        );

                }

                if ( 'heading' === $element->get_name() ) {

                        $element->add_group_control(
                            \Elementor\Group_Control_Typography::get_type(),
                            [
                                'name' => 'em_typo',
                                'selector' => '{{WRAPPER}} .elementor-heading-title em',
                                'label' =>   esc_html__( 'Em Typography', 'thepack' ),
                            ]
                        );

                        $element->add_group_control(
                            \Elementor\Group_Control_Background::get_type(),
                            [
                                'name' => 'bg_color',
                                'label' =>   esc_html__( 'Background', 'elementor' ),
                                'types' => [ 'none', 'classic','gradient' ],
                                'selector' => '{{WRAPPER}} .elementor-heading-title',
                            ]
                        );
                        $element->add_control(
                            'icon-boxhm',
                            [
                                'label' =>   esc_html__( 'Padding', 'elementor' ),
                                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                                'size_units' => [ 'px','%' ],                  
                                'selectors' => [
                                    '{{WRAPPER}} .elementor-heading-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                                ],
                            ]
                        );                        
                } 

            }, 10, 3 );
                            
        }

        /**
         * After column_layout callback
         *
         * @param  object $obj
         * @param  array $args
         * @return void
         */
        public function thepack_after_column_section( $obj, $args ) {

            $obj->start_controls_section(
                'section_xldextra',
                array(
                    'label' =>   esc_html__( 'XLD Section Extra', 'thepack' ),
                    'tab'   => \Elementor\Controls_Manager::TAB_ADVANCED,
                )
            );

            $obj->add_control(
                'xld_parallax_on',
                array(
                    'label'        =>   esc_html__( 'Parallax', 'jetsticky-for-elementor' ),
                    'type'         => \Elementor\Controls_Manager::SWITCHER,
                    'label_on'     =>   esc_html__( 'Yes', 'jetsticky-for-elementor' ),
                    'label_off'    =>   esc_html__( 'No', 'jetsticky-for-elementor' ),
                    'return_value' => 'true',
                    'default'      => 'false',                    
                )
            );

            $obj->add_control(
                'xld-speed',
                array(
                    'label'   =>   esc_html__( 'Speed', 'jetsticky-for-elementor' ),
                    'type'    => \Elementor\Controls_Manager::SLIDER,
                    'default' => [
                        'size' => .1,
                    ],                    
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 2,
                            'step' => .1,
                        ],
                        
                    ],
                    'size_units' => [ 'px'], 
                    'condition' => array(
                        'xld_parallax_on' => 'true',
                    ),
                )
            );

            $obj->add_control(
                'xld_blur',
                array(
                    'label'        =>   esc_html__( 'Blur content on scroll', 'jetsticky-for-elementor' ),
                    'type'         => \Elementor\Controls_Manager::SWITCHER,
                    'label_on'     =>   esc_html__( 'Yes', 'jetsticky-for-elementor' ),
                    'label_off'    =>   esc_html__( 'No', 'jetsticky-for-elementor' ),
                    'return_value' => 'true',
                    'default'      => 'false', 
                    'condition' => array(
                        'xld_parallax_on' => 'true',
                    ),                                       
                )
            );

            $obj->add_control(
                'xld_particles_on',
                array(
                    'label'        =>   esc_html__( 'Particles', 'jetsticky-for-elementor' ),
                    'type'         => \Elementor\Controls_Manager::SWITCHER,
                    'label_on'     =>   esc_html__( 'Yes', 'jetsticky-for-elementor' ),
                    'label_off'    =>   esc_html__( 'No', 'jetsticky-for-elementor' ),
                    'return_value' => 'true',
                    'default'      => 'false',                    
                )
            );

            $obj->add_control(
                'vseparator_on',
                array(
                    'label'        =>   esc_html__( 'Vertical separator', 'jetsticky-for-elementor' ),
                    'type'         => \Elementor\Controls_Manager::SWITCHER,
                    'label_on'     =>   esc_html__( 'Yes', 'jetsticky-for-elementor' ),
                    'label_off'    =>   esc_html__( 'No', 'jetsticky-for-elementor' ),
                    'return_value' => 'true',
                    'default'      => 'false',                    
                )
            );

            $obj->add_control(
                'mouse_sep',
                array(
                    'label'        =>   esc_html__( 'Mouse separator', 'jetsticky-for-elementor' ),
                    'type'         => \Elementor\Controls_Manager::SWITCHER,
                    'label_on'     =>   esc_html__( 'Yes', 'jetsticky-for-elementor' ),
                    'label_off'    =>   esc_html__( 'No', 'jetsticky-for-elementor' ),
                    'return_value' => 'true',
                    'default'      => 'false',                    
                )
            );

            $obj->add_control(
                'f_footer',
                array(
                    'label'        =>   esc_html__( 'Fixed footer', 'jetsticky-for-elementor' ),
                    'type'         => \Elementor\Controls_Manager::SWITCHER,
                    'label_on'     =>   esc_html__( 'Yes', 'jetsticky-for-elementor' ),
                    'label_off'    =>   esc_html__( 'No', 'jetsticky-for-elementor' ),
                    'return_value' => 'true',
                    'default'      => 'false',                    
                )
            );

            $obj->add_control(
                'clr_sep',
                array(
                    'label'        =>   esc_html__( 'Colored background', 'jetsticky-for-elementor' ),
                    'type'         => \Elementor\Controls_Manager::SWITCHER,
                    'label_on'     =>   esc_html__( 'Yes', 'jetsticky-for-elementor' ),
                    'label_off'    =>   esc_html__( 'No', 'jetsticky-for-elementor' ),
                    'return_value' => 'true',
                    'default'      => 'false',                    
                )
            );

            $obj->add_control(
                'sbg',
                array(
                    'label'        =>   esc_html__( 'Scrolling background image', 'jetsticky-for-elementor' ),
                    'type'         => \Elementor\Controls_Manager::SWITCHER,
                    'label_on'     =>   esc_html__( 'Yes', 'jetsticky-for-elementor' ),
                    'label_off'    =>   esc_html__( 'No', 'jetsticky-for-elementor' ),
                    'return_value' => 'true',
                    'default'      => 'false',                    
                )
            );

            $obj->add_control(
                'particle_style',
                array(
                    'label'        =>   esc_html__( 'Style', 'jetsticky-for-elementor' ),
                    'type'         => \Elementor\Controls_Manager::SELECT,
                    'options' => [
                        'default'  =>   esc_html__( 'Default', 'thepack' ),
                        'nasa' =>   esc_html__( 'NASA', 'thepack' ),
                        'bubble' =>   esc_html__( 'Bubble', 'thepack' ),
                        'snow' =>   esc_html__( 'Snow', 'thepack' ),
                    ],  
                    'condition' => array(
                        'xld_particles_on' => 'true',
                    ),                                     
                )
            );

            $obj->add_control(
                'pcolor',
                array(
                    'label'        =>   esc_html__( 'Particle color', 'jetsticky-for-elementor' ),
                    'type'         => \Elementor\Controls_Manager::COLOR, 
                    'condition' => array(
                        'xld_particles_on' => 'true',
                    ),                                      
                )
            );

            $obj->add_control(
                'link_color',
                array(
                    'label'        =>   esc_html__( 'Link color', 'jetsticky-for-elementor' ),
                    'type'         => \Elementor\Controls_Manager::COLOR, 
                    'condition' => array(
                        'xld_particles_on' => 'true',
                    ),                                      
                )
            );

            $obj->add_control(
                'clr_sep1',
                array(
                    'label'        =>   esc_html__( 'First color', 'jetsticky-for-elementor' ),
                    'type'         => \Elementor\Controls_Manager::COLOR, 
                    'condition' => array(
                        'clr_sep' => 'true',
                    ),
                    'selectors' => [
                        '{{WRAPPER}} .fbg' => 'background: {{VALUE}};',
                    ],                                                                                                                
                )
            );

            $obj->add_control(
                'fbgwid',
                [
                    'label' =>   esc_html__( 'First block width', 'thepack' ),
                    'type' =>  \Elementor\Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 1000,
                            'step' => 1,
                        ],
                    ],
                    'size_units' => ['px','%'],
                    'condition' => array(
                        'clr_sep' => 'true',
                    ),                     
                    'selectors' => [
                        '{{WRAPPER}} .fbg' => 'width: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );

            $obj->add_control(
                'clr_sep2',
                array(
                    'label'        =>   esc_html__( 'Second color', 'jetsticky-for-elementor' ),
                    'type'         => \Elementor\Controls_Manager::COLOR, 
                    'condition' => array(
                        'clr_sep' => 'true',
                    ), 
                    'selectors' => [
                        '{{WRAPPER}} .lbg' => 'background: {{VALUE}};',
                    ],                                                         
                )
            );

            $obj->add_control(
                'lbgwid',
                [
                    'label' =>   esc_html__( 'Last block width', 'thepack' ),
                    'type' =>  \Elementor\Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 1000,
                            'step' => 1,
                        ],
                    ],
                    'size_units' => ['px','%'],
                    'condition' => array(
                        'clr_sep' => 'true',
                    ),                     
                    'selectors' => [
                        '{{WRAPPER}} .lbg' => 'width: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );
            $obj->add_control(
                'vs_color',
                array(
                    'label'        =>   esc_html__( 'Vertical separator color', 'jetsticky-for-elementor' ),
                    'type'         => \Elementor\Controls_Manager::COLOR, 
                    'condition' => array(
                        'vseparator_on' => 'true',
                    ), 
                    'selectors' => [
                        '{{WRAPPER}} .vsecsep span::before' => 'background: {{VALUE}};',
                    ],                                                         
                )
            );

            $obj->add_control(
                'wmaxwid',
                [
                    'label' =>   esc_html__( 'Vertical separator height', 'thepack' ),
                    'type' =>  \Elementor\Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 500,
                            'step' => 1,
                        ],
                    ],
                    'size_units' => ['px'],
                    'condition' => array(
                        'vseparator_on' => 'true',
                    ),                     
                    'selectors' => [
                        '{{WRAPPER}} .vsecsep span::before' => 'height: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );

            $obj->add_control(
                'vseppos',
                [
                    'label' =>   esc_html__( 'Vertical bottom position', 'thepack' ),
                    'type' =>  \Elementor\Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'min' => -500,
                            'max' => 500,
                            'step' => 1,
                        ],
                    ],
                    'size_units' => ['px'],
                    'condition' => array(
                        'vseparator_on' => 'true',
                    ),                     
                    'selectors' => [
                        '{{WRAPPER}} .vsecsep' => 'bottom: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );

            $obj->add_control(
                'mus_bg',
                [
                    'label' =>   esc_html__('Mouse theme color', 'thepack'),
                    'type' => \Elementor\Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .mousey' => 'border-color: {{VALUE}};',
                        '{{WRAPPER}} .scroller' => 'background-color: {{VALUE}};',
                    ],
                ]
            );


            $obj->add_responsive_control(
                'muspgwd',
                [
                    'label' =>   esc_html__( 'Mouse bottom spacing', 'thepack' ),
                    'type' =>  \Elementor\Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'max' => 500,
                            'min' => 1,
                            'step' => 1,
                        ]
                    ],
                    'size_units' => ['px','%'],
                    'selectors' => [
                        '{{WRAPPER}} .scroll-downs' => 'bottom: {{SIZE}}{{UNIT}};',
                    ],

                ]
            );

            $obj->add_control(
              'mus_mr',
              [
                 'label' =>   esc_html__( 'Mouse size', 'thepack' ),
                 'type' => \Elementor\Controls_Manager::DIMENSIONS,
                 'size_units' => [ 'px','em'],
                 'allowed_dimensions' => array('top','left'),
                 'selectors' => [
                        '{{WRAPPER}} .mousey' => 'padding-top: {{TOP}}{{UNIT}};padding-bottom:{{TOP}}{{UNIT}}; padding-left:{{LEFT}}{{UNIT}};padding-right:{{LEFT}}{{UNIT}};',
                 ],
              ]
            );

            $obj->end_controls_section();
        }

        public function thepack_before_column( $element ) {
            $data     = $element->get_data();
            $type     = isset( $data['elType'] ) ? $data['elType'] : 'section';
            $settings = $data['settings'];

            if ( 'section' !== $type ) {
                return;
            }

            if ( isset( $settings['vseparator_on'] ) ) {

                if ( filter_var( $settings['vseparator_on'], FILTER_VALIDATE_BOOLEAN ) ) {

                    $element->add_render_attribute( '_wrapper', array(
                        'class' => 'tb-vsecsep',
                    ) );
                }
            }

            if ( isset( $settings['mouse_sep'] ) ) {

                if ( filter_var( $settings['mouse_sep'], FILTER_VALIDATE_BOOLEAN ) ) {

                    $element->add_render_attribute( '_wrapper', array(
                        'class' => 'tb-mousesep',
                    ) );
                }
            }

            if ( isset( $settings['sbg'] ) ) {

                if ( filter_var( $settings['sbg'], FILTER_VALIDATE_BOOLEAN ) ) {

                    $element->add_render_attribute( '_wrapper', array(
                        'class' => 'tb-sbg',
                    ) );
                }
            }

            if ( isset( $settings['f_footer'] ) ) {

                if ( filter_var( $settings['f_footer'], FILTER_VALIDATE_BOOLEAN ) ) {

                    $element->add_render_attribute( '_wrapper', array(
                        'class' => 'tb-fixedfooter',
                    ) );
                }
            }

            if ( isset( $settings['xld_parallax_on'] ) ) {
                $column_settings = array( 
                    'id'            => $data['id'],
                    'speed'    => $settings['xld-speed']['size'],
                    'blur'    => $settings['xld_blur'],
                );
                if ( filter_var( $settings['xld_parallax_on'], FILTER_VALIDATE_BOOLEAN ) ) {

                    $element->add_render_attribute( '_wrapper', array(
                        'class' => 'tb-parallaxbg',
                        'data-tb-parallaxbg-settings' => json_encode( $column_settings ),
                    ) );
                }

                $this->columns_data[ $data['id'] ] = $column_settings;

            }

            if ( isset( $settings['clr_sep'] ) ) {

                if ( filter_var( $settings['clr_sep'], FILTER_VALIDATE_BOOLEAN ) ) {

                    $element->add_render_attribute( '_wrapper', array(
                        'class' => 'tb-dualclrbg',
                    ) );
                }
            }

            if ( isset( $settings['xld_particles_on'] ) ) {
                $particle_settings = array(
                    'style'    => $settings['particle_style'],
                    'linecolor'    => $settings['link_color'],
                    'color'    => $settings['pcolor'],
                );
                if ( filter_var( $settings['xld_particles_on'], FILTER_VALIDATE_BOOLEAN ) ) {

                    $element->add_render_attribute( '_wrapper', array(
                        'class' => 'tb-particlebg',
                        'data-tb-particle-settings' => json_encode( $particle_settings ),
                    ) );
                }

                $this->columns_data[ $data['id'] ] = $particle_settings;
            }

        }


        /**
         * Load Frontend Scripts
         *
         */
        public function thepack_frontend_scripts() {
             
            $gmap = cs_get_option('gmapkey','',TBOPT);
            $translation_array = array( 'template_url' => plugin_dir_url( __FILE__ ) );
            wp_enqueue_script('jquery');
            $tb_scripts = cs_get_option('tb_scripts','',TBOPT);
            if (is_array($tb_scripts)){
                foreach ($tb_scripts as $name){
                    wp_enqueue_script( $name, AE_PLUGIN_URL . 'assets/js/'.$name.'.js');
                }

            }         

            wp_enqueue_script('lazysizes', AE_PLUGIN_URL . 'assets/js/lazysizes.min.js');  
            wp_enqueue_script('jquery.scrollbar', AE_PLUGIN_URL . 'assets/js/jquery.scrollbar.min.js');  
            wp_enqueue_script('thepack-js', AE_PLUGIN_URL . 'assets/js/custom.js', array('jquery','drooltip','masonry'), '', true);        
            wp_enqueue_script('my_loadmore', AE_PLUGIN_URL . 'assets/js/kc-engine.js', array('jquery'), '', true);

            wp_localize_script( 'my_loadmore', 'misha_loadmore_params', array(
                'ajaxurl' => admin_url( 'admin-ajax.php' ), 
                'current_page' => get_query_var( 'paged' ) ? get_query_var('paged') : 1,
            ) );    

            wp_enqueue_script('particles', AE_PLUGIN_URL . 'assets/js/particles.min.js', array('jquery'), '', true);
            wp_localize_script( 'particles', 'xld_particle', $translation_array );


        }

        public function thepack_frontend_styles() {

            wp_enqueue_style('thepack-shortcode', AE_PLUGIN_URL . 'assets/css/shortcode.css');
            $tb_fonts = cs_get_option('tb_fonts','',TBOPT);
            if (is_array($tb_fonts)){
                $new = array_diff($tb_fonts, ["font-awesome"]);
                foreach ($new as $name){
                    wp_enqueue_style( $name, AE_PLUGIN_URL . 'assets/css/'.$name.'/styles.css','',true );
                }

            }

            $tb_styles = cs_get_option('tb_styles','',TBOPT);
            if (is_array($tb_styles)){
                foreach ($tb_styles as $name){
                    wp_enqueue_style( $name, AE_PLUGIN_URL . 'assets/css/'.$name.'.css');
                }
            }
        }

        public function thepack_builder_styles() {

            $tb_fonts = cs_get_option('tb_fonts','',TBOPT);
            if (is_array($tb_fonts)){
                $new = array_diff($tb_fonts, ["font-awesome"]);
                foreach ($new as $name){
                    wp_enqueue_style( $name, AE_PLUGIN_URL . 'assets/css/'.$name.'/styles.css','',true );
                }

            }
        }


        public function thepack_add_elementor_category() {
            \Elementor\Plugin::instance()->elements_manager->add_category(
                'ashelement-addons',
                array(
                    'title' =>   esc_html__('The Pack', 'thepack'),
                    'icon' => 'fa fa-plug',
                ),
                1);
        } 


        public function thepack_controls_registered()
        {
            if ( ! defined( 'ELEMENTOR_PATH' ) || ! class_exists( 'Elementor\Widget_Base' ) || ! class_exists( 'Elementor\Plugin' ) ) {
                return false;
            }

            require_once AE_PLUGIN_DIR . 'admin/controls/icon.php';
        }

        /**
         * Include required files 
         *
         */
        public function thepack_include_widgets($widgets_manager) {

            /* Load Elementor Addon Elements */ 

            $tb_widgets = [];
            $tb_widgets[] = cs_get_option('awards','',TBOPT) ? 'awards' : '';
            $tb_widgets[] = cs_get_option('accordion_1','',TBOPT) ? 'accordion_1' : '';
            $tb_widgets[] = cs_get_option('process_1','',TBOPT) ? 'process_1' : '';
            $tb_widgets[] = cs_get_option('counter_1','',TBOPT) ? 'counter_1' : '';
            $tb_widgets[] = cs_get_option('counter_2','',TBOPT) ? 'counter_2' : '';
            $tb_widgets[] = cs_get_option('timeline_1','',TBOPT) ? 'timeline_1' : '';
            $tb_widgets[] = cs_get_option('timeline_2','',TBOPT) ? 'timeline_2' : '';
            $tb_widgets[] = cs_get_option('testimonial_1','',TBOPT) ? 'testimonial_1' : '';

            $tb_widgets[] = cs_get_option('testimonial_2','',TBOPT) ? 'testimonial_2' : '';
            $tb_widgets[] = cs_get_option('testimonial_3','',TBOPT) ? 'testimonial_3' : '';
            $tb_widgets[] = cs_get_option('testimonial_4','',TBOPT) ? 'testimonial_4' : '';
            $tb_widgets[] = cs_get_option('testimonial_5','',TBOPT) ? 'testimonial_5' : '';
            $tb_widgets[] = cs_get_option('social_1','',TBOPT) ? 'social_1' : '';
            $tb_widgets[] = cs_get_option('split_folio','',TBOPT) ? 'split_folio' : '';
            $tb_widgets[] = cs_get_option('social_2','',TBOPT) ? 'social_2' : '';
            $tb_widgets[] = cs_get_option('gallery_1','',TBOPT) ? 'gallery_1' : '';

            $tb_widgets[] = cs_get_option('gallery_2','',TBOPT) ? 'gallery_2' : '';
            $tb_widgets[] = cs_get_option('gallery_ticker','',TBOPT) ? 'gallery_ticker' : '';
            $tb_widgets[] = cs_get_option('video-pop','',TBOPT) ? 'video-pop' : '';
            $tb_widgets[] = cs_get_option('videobg-pop','',TBOPT) ? 'videobg-pop' : '';
            $tb_widgets[] = cs_get_option('pricing_list','',TBOPT) ? 'pricing_list' : '';
            $tb_widgets[] = cs_get_option('joblisting','',TBOPT) ? 'joblisting' : '';
            $tb_widgets[] = cs_get_option('tourlisting','',TBOPT) ? 'tourlisting' : '';
            $tb_widgets[] = cs_get_option('eventlisting','',TBOPT) ? 'eventlisting' : '';

            $tb_widgets[] = cs_get_option('slider_1','',TBOPT) ? 'slider_1' : '';
            $tb_widgets[] = cs_get_option('slider_thumb','',TBOPT) ? 'slider_thumb' : '';
            $tb_widgets[] = cs_get_option('slidervertical_2','',TBOPT) ? 'slidervertical_2' : '';
            $tb_widgets[] = cs_get_option('slidercarousel_1','',TBOPT) ? 'slidercarousel_1' : '';
            $tb_widgets[] = cs_get_option('sliderfullscrn','',TBOPT) ? 'sliderfullscrn' : '';
            $tb_widgets[] = cs_get_option('slider_hoversync','',TBOPT) ? 'slider_hoversync' : '';
            $tb_widgets[] = cs_get_option('slider_shop','',TBOPT) ? 'slider_shop' : '';
            $tb_widgets[] = cs_get_option('slider_slicksplit','',TBOPT) ? 'slider_slicksplit' : '';

            $tb_widgets[] = cs_get_option('slidercentswipr','',TBOPT) ? 'slidercentswipr' : '';
            $tb_widgets[] = cs_get_option('heading_1','',TBOPT) ? 'heading_1' : '';
            $tb_widgets[] = cs_get_option('iconbox_1','',TBOPT) ? 'iconbox_1' : '';
            $tb_widgets[] = cs_get_option('iconbox_2','',TBOPT) ? 'iconbox_2' : '';
            $tb_widgets[] = cs_get_option('iconbox_3','',TBOPT) ? 'iconbox_3' : '';
            $tb_widgets[] = cs_get_option('imgbox_1','',TBOPT) ? 'imgbox_1' : '';
            $tb_widgets[] = cs_get_option('imgbox_2','',TBOPT) ? 'imgbox_2' : '';
            $tb_widgets[] = cs_get_option('imgbox_3','',TBOPT) ? 'imgbox_3' : '';

            $tb_widgets[] = cs_get_option('imgbox_4','',TBOPT) ? 'imgbox_4' : '';
            $tb_widgets[] = cs_get_option('imgbox_5','',TBOPT) ? 'imgbox_5' : '';
            $tb_widgets[] = cs_get_option('imgbox_6','',TBOPT) ? 'imgbox_6' : '';
            $tb_widgets[] = cs_get_option('imgslickcarousel','',TBOPT) ? 'imgslickcarousel' : '';
            $tb_widgets[] = cs_get_option('slideshowify','',TBOPT) ? 'slideshowify' : '';
            $tb_widgets[] = cs_get_option('datecounter','',TBOPT) ? 'datecounter' : '';
            $tb_widgets[] = cs_get_option('foliomultiscroll','',TBOPT) ? 'foliomultiscroll' : '';
            $tb_widgets[] = cs_get_option('minibox','',TBOPT) ? 'minibox' : '';

            $tb_widgets[] = cs_get_option('multiscrollfullscreen','',TBOPT) ? 'multiscrollfullscreen' : '';
            $tb_widgets[] = cs_get_option('portfolio_parallax','',TBOPT) ? 'portfolio_parallax' : '';
            $tb_widgets[] = cs_get_option('portfolio_filter','',TBOPT) ? 'portfolio_filter' : '';
            $tb_widgets[] = cs_get_option('portfolio_hover','',TBOPT) ? 'portfolio_hover' : '';
            $tb_widgets[] = cs_get_option('tab','',TBOPT) ? 'tab' : '';
            $tb_widgets[] = cs_get_option('tab_2','',TBOPT) ? 'tab_2' : '';
            $tb_widgets[] = cs_get_option('tab_3','',TBOPT) ? 'tab_3' : '';
            $tb_widgets[] = cs_get_option('sticky_nav','',TBOPT) ? 'sticky_nav' : '';

            $tb_widgets[] = cs_get_option('slider_bgblur','',TBOPT) ? 'slider_bgblur' : '';
            $tb_widgets[] = cs_get_option('separator','',TBOPT) ? 'separator' : '';
            $tb_widgets[] = cs_get_option('separator_vertical','',TBOPT) ? 'separator_vertical' : '';
            $tb_widgets[] = cs_get_option('progressbar_1','',TBOPT) ? 'progressbar_1' : '';
            $tb_widgets[] = cs_get_option('progress_circle','',TBOPT) ? 'progress_circle' : '';
            $tb_widgets[] = cs_get_option('before_after','',TBOPT) ? 'before_after' : '';
            $tb_widgets[] = cs_get_option('typed_text_1','',TBOPT) ? 'typed_text_1' : '';
            $tb_widgets[] = cs_get_option('insta_feed','',TBOPT) ? 'insta_feed' : '';

            $tb_widgets[] = cs_get_option('altimagegrid','',TBOPT) ? 'altimagegrid' : '';
            $tb_widgets[] = cs_get_option('iconbox','',TBOPT) ? 'iconbox' : '';
            $tb_widgets[] = cs_get_option('list_1','',TBOPT) ? 'list_1' : '';
            $tb_widgets[] = cs_get_option('tooltipfolio','',TBOPT) ? 'tooltipfolio' : '';
            $tb_widgets[] = cs_get_option('circular-phone','',TBOPT) ? 'circular-phone' : '';
            $tb_widgets[] = cs_get_option('split_section','',TBOPT) ? 'split_section' : '';
            $tb_widgets[] = cs_get_option('imagecaption','',TBOPT) ? 'imagecaption' : '';
            $tb_widgets[] = cs_get_option('image-layer2','',TBOPT) ? 'image-layer2' : '';

            $tb_widgets[] = cs_get_option('tab_history','',TBOPT) ? 'tab_history' : '';
            $tb_widgets[] = cs_get_option('cf7','',TBOPT) ? 'cf7' : '';
            $tb_widgets[] = cs_get_option('image-layer','',TBOPT) ? 'image-layer' : '';
            $tb_widgets[] = cs_get_option('team_1','',TBOPT) ? 'team_1' : '';
            $tb_widgets[] = cs_get_option('team_2','',TBOPT) ? 'team_2' : '';
            $tb_widgets[] = cs_get_option('button_1','',TBOPT) ? 'button_1' : '';
            $tb_widgets[] = cs_get_option('button_2','',TBOPT) ? 'button_2' : '';
            $tb_widgets[] = cs_get_option('button_3','',TBOPT) ? 'button_3' : '';

            $tb_widgets[] = cs_get_option('button_4','',TBOPT) ? 'button_4' : '';
            $tb_widgets[] = cs_get_option('button_dbl','',TBOPT) ? 'button_dbl' : '';
            $tb_widgets[] = cs_get_option('flipcard','',TBOPT) ? 'flipcard' : '';
            $tb_widgets[] = cs_get_option('text_art1','',TBOPT) ? 'text_art1' : '';
            $tb_widgets[] = cs_get_option('text_art2','',TBOPT) ? 'text_art2' : '';
            $tb_widgets[] = cs_get_option('text_art3','',TBOPT) ? 'text_art3' : '';
            $tb_widgets[] = cs_get_option('links_1','',TBOPT) ? 'links_1' : '';
            $tb_widgets[] = cs_get_option('image_hotspot1','',TBOPT) ? 'image_hotspot1' : '';

            $tb_widgets[] = cs_get_option('cliendgrid1','',TBOPT) ? 'cliendgrid1' : '';
            $tb_widgets[] = cs_get_option('imgart1','',TBOPT) ? 'imgart1' : '';
            $tb_widgets[] = cs_get_option('imgrid','',TBOPT) ? 'imgrid' : '';
            $tb_widgets[] = cs_get_option('pricing_1','',TBOPT) ? 'pricing_1' : '';
            $tb_widgets[] = cs_get_option('imgbgbox_1','',TBOPT) ? 'imgbgbox_1' : '';
 
            $tb_widgets[] = 'cta1'; 
            $tb_widgets[] = 'card_slider';
            $tb_widgets[] = 'heading_2';
            $tb_widgets[] = 'tab_4'; 
            $tb_widgets[] = 'imgrid_1';
            $tb_widgets[] = 'datecounter1';
            $tb_widgets[] = 'heading_3';
            $tb_widgets[] = 'gallery_sync';
            $tb_widgets[] = 'titmeline_3';
            $tb_widgets[] = 'imgbgbox_2'; 
            $tb_widgets[] = 'fullscrnslksync';
            $tb_widgets[] = 'portfolio_hover2';
            $tb_widgets[] = 'image_accordion';
            $tb_widgets[] = 'process_2';
            $tb_widgets[] = 'gmap';
            $tb_widgets[] = 'list_2';
            $tb_widgets[] = 'timeline_fullscrn';
            $tb_widgets[] = 'audioplayer';
            $tb_widgets[] = 'team_3';
            $tb_widgets[] = 'imgmix';
            $tb_widgets[] = 'imgbgbox_3';
            $tb_widgets[] = 'cookie_consent';
            $tb_widgets[] = 'tourlisting_mini';
            $tb_widgets[] = 'page_loader';
            $tb_widgets[] = 'timeline_alt';
            $tb_widgets[] = 'imgzigzag';
            $tb_widgets[] = 'portfolio_hover3';
            $tb_widgets[] = 'pricing_2';
            $tb_widgets[] = 'imgbgbox_4';
            $tb_widgets[] = 'changelog';
            $tb_widgets[] = 'hover_reveal';
                                                                                    
            if (is_array($tb_widgets)){
                $tb_widgets = array_filter($tb_widgets);
                foreach ($tb_widgets as $name){
                    require_once AE_ADDONS_DIR . ''.$name.'/index.php';
                }

            }
                                                                    
        }

    }

endif;


function thepack_run() {
    return thepack_elementor_addon_widget::instance();
}

thepack_run();
