<?php

namespace thepack_themebuilderr;

use Elementor;
use Elementor\Plugin;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Utils;

class thepack_author_meta extends Widget_Base{
    public function get_name() {
        return 'tb-authrbx';
    }

    public function get_title() {
        return    esc_html__( 'AUTHOR BOX', 'thepack' );
    }

    public function get_icon() {
        return 'fa fa-user-circle';
    }

    public function get_categories() {
        return [ 'xl-theme-builder' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_info',
            [
                'label' =>   esc_html__('Info', 'thepack'),
            ]
        );

        $this->add_control(
            'aulabel',
            [
                'type' => 'text',
                'label' =>   esc_html__('Title for block', 'thepack'),
                'label_block' => true,
                'default' => 'About Author',
            ]
        );

        $this->add_control(
            'img',
            [
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'label_block' => true,
                'label' =>   esc_html__('Avatar', 'thepack'),
            ]
        );

        $this->add_control(
            'pre',
            [
                'type' => 'text',
                'label' =>   esc_html__('Pre title', 'thepack'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'name',
            [
                'type' => 'text',
                'label' =>   esc_html__('Name', 'thepack'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'desc',
            [
                'type' => 'textarea',
                'label' =>   esc_html__('Description', 'thepack'),
                'label_block' => true,
            ]
        );
        
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'icon', [
                'label' =>   esc_html__( 'Icon', 'thepack' ),
                'type' => Controls_Manager::ICON,
                'label_block' => true,               
            ]
        );

        $repeater->add_control(
            'url', [
                'label' =>   esc_html__('Link', 'thepack'),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'placeholder' =>   esc_html__('http://your-link.com', 'thepack'),
            ]
        ); 
        $this->add_control(
            'lists',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(), 
                'prevent_empty' => false, 
                'default' => [
                    [
                        'label' =>   esc_html__( '<i class="fa fa-facebook"></i>', 'thepack' ),
                    ]
                ],
                'title_field' => '<i class="{{{icon}}}"></i>',                
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_gnrl',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'tmpl',
            [
                'label' =>   esc_html__('Template', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'style_one' => [
                        'title' =>   esc_html__('Style One', 'thepack'),
                        'icon' => 'fa fa-folder',
                    ],
                    'style_two' => [
                        'title' =>   esc_html__('Style Two', 'thepack'),
                        'icon' => 'fa fa-folder-o',
                    ]

                ],
                'default' => 'style_one',               
            ]
        );

        $this->add_control(
            'align',
            [
                'label' =>   esc_html__('Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .tb-post-author' => 'text-align: {{VALUE}};',
                ],                 
            ]
        );

        $this->add_responsive_control(
            'cntwed',
            [
                'label' =>   esc_html__( 'Content width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'size_units' => [ '%'],
                'selectors' => [
                    '{{WRAPPER}} .author-details' => 'width: {{SIZE}}%;',
                ],
                'condition' => [
                    'tmpl' => 'style_two',
                ],
            ]
        );

        $this->add_responsive_control(
            'cnt_pad',
            [
                'label' =>   esc_html__('Content padding', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px','em'],
                'selectors' => [
                    '{{WRAPPER}} .author-details' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'tmpl' => 'style_two',
                ],                  
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_avatar',
            [
                'label' =>   esc_html__('Avatar', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'width',
            [
                'label' =>   esc_html__( 'Avatar width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],

                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .featured-img' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'ava_border',
                'label' =>   esc_html__( 'Border', 'elementor' ),
                'selector' => '{{WRAPPER}} .featured-img',
            ]
            );    
        $this->add_responsive_control(
            'border-radius',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'size_units' => [ '%'],
                'selectors' => [
                    '{{WRAPPER}} .featured-img' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->end_controls_section();   

        $this->start_controls_section(
            'section_pre',
            [
                'label' =>   esc_html__('Desination', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'pre_typography',
                'label' =>   esc_html__('Prehead typo', 'thepack'),
                'selector' => '{{WRAPPER}} .prename',
            ]
        );

        $this->add_control(
            'pre_color',
            [
                'label' =>   esc_html__('Preheading color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .prename' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'pre_mar',
            [
                'label' =>   esc_html__('Preheading margin', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px','em'],
                'selectors' => [
                    '{{WRAPPER}} .prename' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );

        $this->end_controls_section(); 

        $this->start_controls_section(
            'section_authnam',
            [
                'label' =>   esc_html__('Name', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'cont_typography',
                'label' =>   esc_html__('Content typo', 'thepack'),
                'selector' => '{{WRAPPER}} .author-job',
            ]
        );

        $this->add_control(
            'h_color',
            [
                'label' =>   esc_html__('Heading color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .author-job' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section(); 

        $this->start_controls_section(
            'section_content',
            [
                'label' =>   esc_html__('Content', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'dsc_typ',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .desc',
            ]
        );

        $this->add_control(
            'c_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .desc' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'cont_mar',
            [
                'label' =>   esc_html__('Margin', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px','em'],
                'selectors' => [
                    '{{WRAPPER}} .desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );

        $this->end_controls_section();    

        $this->start_controls_section(
            'section_social',
            [
                'label' =>   esc_html__( 'Social', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        ); 

        $this->add_responsive_control(
            'itmsp',
            [
                'label' =>   esc_html__( 'Item spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .author-details li' => 'margin:0px {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .author-details ul' => 'margin-left:-{{SIZE}}{{UNIT}};margin-right:-{{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'list_bordercol',
            [
                'label' =>   esc_html__( 'color', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .social a' =>'color:{{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'list_colorhov',
            [
                'label' =>   esc_html__( 'Hover Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,             
                'selectors' => [
                    '{{WRAPPER}} .social a:hover' => 'color: {{VALUE}};',
                ],
            ]
        ); 


        $this->end_controls_section();

    }

    protected function render( ) {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';
    }
}

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new thepack_author_meta() );