<?php

/*
Widget Name: Webangon carousel
Description: Display blog posts or custom post types as a carousel.
Author: LiveMesh
Author URI: https://www.webangon.com
*/

namespace thepack_themebuilderr;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly

class thepack_blog_carousel extends Widget_Base {

    public function get_name() {
        return 'ae_blgcro';
    }

    public function get_title() {
        return   esc_html__('Blog Carousel', 'thepack');
    }

    public function get_icon() {
        return 'eicon-posts-group';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_posts_carousel',
            [
                'label' =>   esc_html__('Query', 'thepack'),
            ]
        );

        $this->add_control(

            'style', [
                'type' => Controls_Manager::SELECT,
                'label' =>   esc_html__('Style', 'thepack'),
                'default' => 'style_one',
                'options' => [
                    'style_one' =>   esc_html__('Style 1', 'thepack'),
                    'style_two' =>   esc_html__('Style 2', 'thepack'),
                    'style_three' =>   esc_html__('Style 3', 'thepack'),
                ],
            ]
        );

        $this->add_control(
            'query_type',
            [
                'label' =>   esc_html__('Query type', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'default' => 'icon',
                'options' => [
                    'category' =>   esc_html__('Category', 'thepack'),
                    'individual' =>   esc_html__('Individual', 'thepack'),
                ],
            ] 
        );

        $this->add_control(
            'cat_query',
            [
                'label' =>   esc_html__('Category', 'thepack'),
                'type' => Controls_Manager::SELECT2,
                'options' => thepack_drop_cat('category'),
                'multiple' => true,
                'label_block' => true,
                'condition' => [
                    'query_type' => 'category',
                ],                
            ]           
        );

        $this->add_control(
            'id_query',
            [
                'label' =>   esc_html__('Posts', 'thepack'),
                'type' => Controls_Manager::SELECT2,
                'options' => thepack_drop_posts('post'),
                'multiple' => true,
                'label_block' => true,
                'condition' => [
                    'query_type' => 'individual',
                ],                
            ]           
        );

        $this->add_control(
            'f_m',
            [
                'label' =>   esc_html__( 'Post meta', 'thepack' ),
                'type' => Controls_Manager::RAW_HTML,
            ]
        );

        $this->add_control(
            'metas',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name' => 'meta',
                        'type' => Controls_Manager::SELECT2,
                        'label' =>   esc_html__('Post meta', 'thepack'),
                        'default' => '',
                        'options' =>  thepack_metaa_fields(), 
                        'multiple' => false,
                        'label_block' => true                                   
                    ],

                ],
                'title_field' => '{{{ meta }}}',
            ]
        );

        $this->add_control(
            'excerpt',
            [
                'label' =>   esc_html__( 'Excerpt length', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                        'step' => 1,
                    ],
                ],

            ]
        );

        $this->add_control(
            'posts_per_page',
            [
                'label' =>   esc_html__('Posts Per Page', 'thepack'),
                'type' => Controls_Manager::NUMBER,
                'default' => 6,
            ]
        );

        $this->add_control(
            'img_size',
            [
                'label' =>   esc_html__('Image size', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' =>  thepack_image_size_choose(), 
                'multiple' => false,                                              
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_style',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );



        $this->add_responsive_control(
            'height',
            [
                'label' =>   esc_html__('Slider height', 'thepack'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'default' => [
                    'size' => 400,
                ],
                'range' => [
                    'px' => [
                        'max' => 1200,
                        'min' => 1,
                        'step' => 1,
                    ],                   
                ],
                'condition' => [
                    'style!' => array('style_two'),
                ],                
                'selectors' => [
                    '{{WRAPPER}} .grid-item' => 'height: {{SIZE}}{{UNIT}};',
                ]                
            ]
        );

        $this->add_control(
            'overlay',
            [
                'label' =>   esc_html__( 'Overlay Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,               
                'selectors' => [
                    '{{WRAPPER}} .thumb-content' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'max-over-wid',
            [
                'label' =>   esc_html__('Max overlay width', 'thepack'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'default' => [
                    'size' => 400,
                ],
                'range' => [
                    'px' => [
                        'max' => 1200,
                        'min' => 1,
                        'step' => 1,
                    ],                   
                ],
               
                'selectors' => [
                    '{{WRAPPER}} .thumb-overlay3' => 'max-width: {{SIZE}}{{UNIT}};',
                ]                
            ]
        );

        $this->add_control(
            'overlay-hov',
            [
                'label' =>   esc_html__( 'Hover Overlay Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,                 
                'selectors' => [
                    '{{WRAPPER}} .grid-item:hover .thumb-content' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'overlay_pad',
            [
                'label' =>   esc_html__('Overlay content padding', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .thumb-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'txt_align',
            [
                'label' =>   esc_html__('Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ]
                ],
                'default' => 'center',
                'selectors' => [
                    '{{WRAPPER}} .thumb-content' => 'text-align: {{VALUE}};',
                ],                 
            ]
        );

        $this->end_controls_section();

         $this->start_controls_section(
            'section_style3',
            [
                'label' =>   esc_html__('Post meta', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'm_typography',
                'selector' => '{{WRAPPER}} .post-cat',
                'label' =>   esc_html__( 'Category Typo', 'thepack' ),
            ]
        );

        $this->add_control(
            'meta_margins',
            [
                'label' =>   esc_html__('Category margin', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .post-cat' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'm_color',
            [
                'label' =>   esc_html__( 'Category Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .post-cat,{{WRAPPER}} .post-cat a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'meta_typography',
                'selector' => '{{WRAPPER}} .leffect-1',
                'label' =>   esc_html__( 'Meta Typo', 'thepack' ),
            ]
        );

        $this->add_control(
            'meta_color',
            [
                'label' =>   esc_html__( 'Meta Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .leffect-1,{{WRAPPER}} .leffect-1 a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

         $this->start_controls_section(
            'section_style2',
            [
                'label' =>   esc_html__('Title', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .post-title-builder',
                'label' =>   esc_html__( 'Title typo', 'thepack' ),
            ]
        );

        $this->add_control(
            'title_margins',
            [
                'label' =>   esc_html__('Title margin', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .post-title-builder' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .post-title-builder a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

         $this->start_controls_section(
            'section_style4',
            [
                'label' =>   esc_html__('Excerpt', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'e_typography',
                'selector' => '{{WRAPPER}} .entry_excerpt',
                'label' =>   esc_html__( 'Excerpt Typo', 'thepack' ),
            ]
        );

        $this->add_control(
            'e_margins',
            [
                'label' =>   esc_html__('Excerpt margin', 'elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .entry_excerpt' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'e_color',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .entry_excerpt' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_readmore',
            [
                'label' =>   esc_html__('Read more', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,             
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typography',
                'selector' => '{{WRAPPER}} .btn-more',
            ]
        );

        $this->add_control(
            'btn_color',
            [
                'label' =>   esc_html__( 'Button color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn-more' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btn_colorbg',
            [
                'label' =>   esc_html__( 'Button background', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn-more' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btn_color-h',
            [
                'label' =>   esc_html__( 'Button color hover', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn-more:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btn_colorbgh',
            [
                'label' =>   esc_html__( 'Button background hover', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn-more:hover' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btn_bcol',
            [
                'label' =>   esc_html__( 'Button border color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn-more' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btn_bcolh',
            [
                'label' =>   esc_html__( 'Button border hover', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn-more:hover' => 'border-color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'bbtnwidth',
            [
                'label' =>   esc_html__( 'Border width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .btn-more' => 'border-width: {{SIZE}}{{UNIT}};border-style:solid',
                ],

            ]
        );

        $this->add_control(
            'bbtnradius',
            [
                'label' =>   esc_html__( 'Border radisu', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .btn-more' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'btn-pad',
            [
                'label' =>   esc_html__('Button padding', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .btn-more' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );


        $this->end_controls_section();     
        
        $this->start_controls_section(
            'section_carousel',
            [
                'label' =>   esc_html__('Carousel', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,                
            ]
        );

        $this->add_control(
            'arrow',
            [
                'label' =>   esc_html__('Display arrow', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                 
            ]
        );

        $this->add_control(
            'center',
            [
                'label' =>   esc_html__('Center mode', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                 
            ]
        );

        $this->add_control(
            'auto',
            [
                'label' =>   esc_html__('Autoplay', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );

        $this->add_control(
            'dot',
            [
                'label' =>   esc_html__('Display dot', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',               
            ]
        );

        $this->add_control(
            'transition',
            [
                'label' =>   esc_html__('Transition', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Fade', 'thepack'),
                'label_off' =>   esc_html__('Slide', 'thepack'),              
            ]
        );

        $this->add_control(
            'item',
            [
                'label' =>   esc_html__( 'Item per slide', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'default' => [
                    'size' => 4,
                ],                
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 5,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],              
            ]
        );

        $this->add_control(
            'item_tab',
            [
                'label' =>   esc_html__( 'Item per slide tablet', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'default' => [
                    'size' => 2,
                ],                
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 5,
                        'step' => 1,
                    ],
                ],            
            ]
        );

        $this->add_control(
            'speed',
            [
                'label' =>   esc_html__( 'Autoplay Speed', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'default' => [
                    'size' => 3500,
                ],                  
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 8000,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],              
            ]
        );

        $this->add_responsive_control(
            'sldsp',
            [
                'label' =>   esc_html__('Item spacing', 'thepack'),
                'type' => Controls_Manager::SLIDER,                
                'selectors' => [
                    '{{WRAPPER}} .slick-list' => 'margin-left: -{{SIZE}}px;margin-right:-{{SIZE}}px;',
                    '{{WRAPPER}} .slick-slide' => 'margin-left: {{SIZE}}px;margin-right:{{SIZE}}px;',
                ]                
            ]
        );

        $this->end_controls_section(); 

        $this->start_controls_section(
            'section_arrow',
            [
                'label' =>   esc_html__('Carousel Arrow', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,  
                'condition' => [
                    'arrow' => 'yes',
                ],                             
            ]
        );

        $this->add_control(
            'pri',
            [
                'label' =>   esc_html__('Arrow color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-arrow' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'sec',
            [
                'label' =>   esc_html__('Arrow background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-arrow' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'prih',
            [
                'label' =>   esc_html__('Arrow hover color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-arrow:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'sech',
            [
                'label' =>   esc_html__('Arrow hover background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-arrow:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'arrow_border_co_r',
            [
                'label' =>   esc_html__( 'Arrow Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .slick-arrow' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],

            ]
        );
        
        $this->end_controls_section();

        $this->start_controls_section(
            'section_dot',
            [
                'label' =>   esc_html__('Carousel Dot', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS, 
                'condition' => [
                    'dot' => 'yes',
                ],                              
            ]
        );

        $this->add_control(
            'dot-pos',
            [
                'label' =>   esc_html__('Dot position', 'thepack'),
                'type' => Controls_Manager::NUMBER,    
                'selectors' => [
                    '{{WRAPPER}} .slick-dots' => 'bottom: {{VALUE}}px;',
                ],                            
            ]
        );

        $this->add_control(
            'dotsec',
            [
                'label' =>   esc_html__('Dot main color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-dots li button' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'dotprih',
            [
                'label' =>   esc_html__('Active border color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-dots li.slick-active button' => 'box-shadow:0 0 0 2px {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'dotprihacti',
            [
                'label' =>   esc_html__('Active background color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-dots li.slick-active button' => 'background:{{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';
    }

    protected function content_template() {
    }

}

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new thepack_blog_carousel() );
