<?php

namespace thepack_themebuilderr;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Plugin;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly

class thepack_blog_masonry extends Widget_Base {

    public function get_name() {
        return 'ae_blogmason';
    }

    public function get_title() {
        return   esc_html__('BLOG MASON', 'thepack');
    }

    public function get_icon() {
        return ' eicon-posts-group';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_posts_carousel',
            [
                'label' =>   esc_html__('Query', 'thepack'),
            ]
        );
        $this->add_control(
            'arc_query',
            [
                'label' =>   esc_html__( 'Enable archive query', 'thepack' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__( 'Yes', 'thepack' ),
                'label_off' =>   esc_html__( 'No', 'thepack' ),
            ]
        );

        $this->add_control(
            'query_type',
            [
                'label' =>   esc_html__('Query type', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'default' => 'icon',
                'options' => [
                    'category' =>   esc_html__('Category', 'thepack'),
                    'individual' =>   esc_html__('Individual', 'thepack'),
                ],
                'condition' => [
                    'arc_query!' => 'yes',
                ],                 
            ]
        );

        $this->add_control(
            'cat_query',
            [
                'label' =>   esc_html__('Category', 'thepack'),
                'type' => Controls_Manager::SELECT2,
                'options' => thepack_drop_cat('category'),
                'multiple' => true,
                'label_block' => true,
                'condition' => [
                    'query_type' => 'category',
                    'arc_query!' => 'yes',
                ],                
            ]           
        );

        $this->add_control(
            'id_query',
            [
                'label' =>   esc_html__('Posts', 'thepack'),
                'type' => Controls_Manager::SELECT2,
                'options' => thepack_drop_posts('post'),
                'multiple' => true,
                'label_block' => true,
                'condition' => [
                    'query_type' => 'individual',
                ],                
            ]           
        );

        $this->add_control(
            'posts_per_page',
            [
                'label' =>   esc_html__('Posts Per Page', 'thepack'),
                'type' => Controls_Manager::NUMBER,
                'default' => 6,
            ]
        );

        $this->add_control(
            'show_pagi',
            [
                'label' =>   esc_html__( 'Show pagination', 'thepack' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__( 'Yes', 'thepack' ),
                'label_off' =>   esc_html__( 'No', 'thepack' ),                
            ]
        );
        $this->add_control(
            'metas',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name' => 'meta',
                        'type' => Controls_Manager::SELECT2,
                        'label' =>   esc_html__('Post meta', 'thepack'),
                        'default' => '',
                        'options' =>  thepack_metaa_fields(), 
                        'multiple' => false,
                        'label_block' => true                                   
                    ],

                ],
                'title_field' => '{{{ meta }}}',
            ]
        );

        $this->add_control(
            'excerpt',
            [
                'label' =>   esc_html__( 'Excerpt length', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                        'step' => 1,
                    ],
                ],

            ]
        );

        $this->add_control(
            'img_size',
            [
                'label' =>   esc_html__('Image size', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' =>  thepack_image_size_choose(), 
                'multiple' => false,                                                
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_style',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );
 
        $this->add_control(
            'style',
            [
                'label' =>   esc_html__('Show as', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'grid' => [
                        'title' =>   esc_html__('Grid', 'thepack'),
                        'icon' => 'fa fa-th',
                    ],
                    'list' => [
                        'title' =>   esc_html__('List', 'thepack'),
                        'icon' => 'fa fa-picture-o',
                    ],
                    'masonry' => [
                        'title' =>   esc_html__('Masonry', 'thepack'),
                        'icon' => 'fa fa-th',
                    ],                    
                ],
                'default' => 'grid',               
            ]
        );

        $this->add_control(
            'animation',
            [
                'label' =>   esc_html__('Animation', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'options' =>  thepack_animations(), 
                'multiple' => false,
                'label_block' => true,
                'condition' => [
                    'style' => 'grid',
                ],                
            ]
        );


        $this->add_responsive_control(
            'imgcwid',
            [
                'label' =>   esc_html__( 'Image container width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 800,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px','%'],
                'condition' => [
                    'style' => 'list',
                ],                 
                'selectors' => [
                    '{{WRAPPER}} .gallery-box' => 'width: {{SIZE}}{{UNIT}}',
                ],

            ]
        );

        $this->add_responsive_control(
            'imgcrp',
            [
                'label' =>   esc_html__( 'Image right spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 800,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px','%'],
                'condition' => [
                    'style' => 'list',
                ],                 
                'selectors' => [
                    '{{WRAPPER}} .gallery-box' => 'margin-right: {{SIZE}}{{UNIT}}',
                ],

            ]
        );

 
         $this->add_responsive_control(
            'xdwid',
            [
                'label' =>   esc_html__( 'Column width', 'thepack' ),
                'type' =>  Controls_Manager::NUMBER, 
                'default' => '33.33',
                 'selectors' => [
                        '{{WRAPPER}} .grid-item' => 'width: {{VALUE}}%;',
                 ],   
                'condition' => [
                    'style!' => 'list',
                ],                                             
            ]
        );

        $this->add_control(
            'lrpad',
            [
                'label' =>   esc_html__( 'Left right padding', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 30,
                        'step' => 1,
                    ],
                ],
                'condition' => [
                    'style!' => 'list',
                ],                 
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .grid-item' => 'padding-left: {{SIZE}}{{UNIT}};padding-right: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .ashelement-grid' => 'margin-left: -{{SIZE}}{{UNIT}};margin-right: -{{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'botmargin',
            [
                'label' =>   esc_html__( 'Margin-bottom', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .grid-item' => 'margin-bottom: {{SIZE}}{{UNIT}}',
                ],

            ]
        );

        $this->add_responsive_control(
          'ginpad',
          [
             'label' =>   esc_html__( 'Inner padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px', '%', 'em' ],
             'selectors' => [
                    '{{WRAPPER}} .mason-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_control(
            'gbclr',
            [
                'label' =>   esc_html__( 'Border Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mason-content' => 'border:1px solid {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'gbclr',
            [
                'label' =>   esc_html__( 'Border Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mason-content' => 'border:1px solid {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'gbrad',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .mason-content' => 'border-radius: {{SIZE}}px',
                ],

            ]
        );

        $this->add_control(
            'gbgclr',
            [
                'label' =>   esc_html__( 'Background', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mason-content' => 'background:{{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'raizhv',
            [
                'label' =>   esc_html__('Hover raised', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),  
                'selectors' => [
                    '{{WRAPPER}} .mason-content:hover' => 'top: -10px;',
                ],                               
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_title',
            [
                'label' =>   esc_html__('Post title', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $this->add_control(
          'hmargin',
          [
             'label' =>   esc_html__( 'Title margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px', '%', 'em' ],
             'allowed_dimensions' => array('top','bottom'),
             'selectors' => [
                    '{{WRAPPER}} .post-title-builder' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'heading_typography',
                'selector' => '{{WRAPPER}} .post-title-builder',
                'label' =>   esc_html__( 'Typo', 'thepack' ),
            ]
        );

        $this->add_control(
            'tcol',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .post-title-builder a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'tcolh',
            [
                'label' =>   esc_html__( 'Hover color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .post-title-builder:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_excerpt',
            [
                'label' =>   esc_html__('Excerpt', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $this->add_control(
            'ecol',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .post-entry' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
          'exmargin',
          [
             'label' =>   esc_html__( 'Margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px', '%', 'em' ],
             'allowed_dimensions' => array('top','bottom'),
             'selectors' => [
                    '{{WRAPPER}} .post-entry' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'selector' => '{{WRAPPER}} .post-entry',
                'label' =>   esc_html__( 'Typo', 'thepack' ),
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_meta',
            [
                'label' =>   esc_html__('Post meta', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'meta_typography',
                'selector' => '{{WRAPPER}} .leffect-1',
                'label' =>   esc_html__( 'Typo', 'thepack' ),
            ]
        );

        $this->add_control(
            'gcol',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .leffect-1' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'mcol',
            [
                'label' =>   esc_html__( 'Link Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .leffect-1 a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'mcolh',
            [
                'label' =>   esc_html__( 'Link Hover color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .leffect-1:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_pagination',
            [
                'label' =>   esc_html__('Pagination', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'pagi_typography',
                'selector' => '{{WRAPPER}} .pagination-theme li',
                'label' =>   esc_html__( 'Pagination', 'thepack' ),
            ]
        );

        $this->add_control(
            'pagi-align',
            [
                'label' =>   esc_html__('Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' =>   esc_html__('Justified', 'thepack'),
                        'icon' => 'fa fa-align-justify',
                    ],
                ],
                'default' => 'center',
                'selectors' => [
                    '{{WRAPPER}} .pagination-theme ul' => 'text-align: {{VALUE}};',
                ],                 
            ]
        );

        $this->add_control(
          'pagi-margin',
          [
             'label' =>   esc_html__( 'Margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             'selectors' => [
                    '{{WRAPPER}} .pagination-theme ul' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_control(
            'pcol',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pagination-theme a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'pcolh',
            [
                'label' =>   esc_html__( 'Hover color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pagination-theme a:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/'. $settings['style'] .'.php';

    }

}

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new thepack_blog_masonry() );