<?php
namespace thepack_themebuilderr;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly

class thepack_blog_list_intro extends Widget_Base {

    public function get_name() {
        return 'tb_blog_slide';
    }

    public function get_title() {
        return   esc_html__('BLOG SLIDER', 'thepack');
    }

    public function get_icon() {
        return ' eicon-posts-group';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_posts_carousel',
            [
                'label' =>   esc_html__('Query', 'thepack'),
            ]
        ); 

        $this->add_control(
            'query_type',
            [
                'label' =>   esc_html__('Query type', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'default' => 'icon',
                'options' => [
                    'category' =>   esc_html__('Category', 'thepack'),
                    'individual' =>   esc_html__('Individual', 'thepack'),
                ],
            ]
        );

        $this->add_control(
            'cat_query',
            [
                'label' =>   esc_html__('Category', 'thepack'),
                'type' => Controls_Manager::SELECT2,
                'options' => thepack_drop_cat('category'),
                'multiple' => true,
                'label_block' => true,
                'condition' => [
                    'query_type' => 'category',
                ],                
            ]           
        );

        $this->add_control(
            'id_query',
            [
                'label' =>   esc_html__('Posts', 'thepack'),
                'type' => Controls_Manager::SELECT2,
                'options' => thepack_drop_posts('post'),
                'multiple' => true,
                'label_block' => true,
                'condition' => [
                    'query_type' => 'individual',
                ],                
            ]           
        ); 

        $this->add_control(
            'posts_per_page',
            [
                'label' =>   esc_html__('Posts Per Page', 'thepack'),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 30,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],                                
            ]
        );

        $this->add_control(
            'metas',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name' => 'meta',
                        'type' => Controls_Manager::SELECT2,
                        'label' =>   esc_html__('Post meta', 'thepack'),
                        'default' => '',
                        'options' =>  thepack_metaa_fields(), 
                        'multiple' => false,
                        'label_block' => true                                   
                    ],

                ],
                'title_field' => '{{{ meta }}}',
            ]
        );

        $this->add_control(
            'excerpt',
            [
                'label' =>   esc_html__( 'Excerpt length', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                        'step' => 1,
                    ],
                ],

            ]
        );

        $this->add_control(
            'img_size',
            [
                'label' =>   esc_html__('Image size', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' =>  thepack_image_size_choose(), 
                'multiple' => false,                                                
            ]
        );
 
        $this->end_controls_section();

        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $this->add_control(
            'lrpad',
            [
                'label' =>   esc_html__( 'Left right padding', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 30,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .grid-item' => 'padding-left: {{SIZE}}{{UNIT}};padding-right: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .simpost-carousel' => 'margin-left: -{{SIZE}}{{UNIT}};margin-right: -{{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'botmargin',
            [
                'label' =>   esc_html__( 'Margin-bottom', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => -500,
                        'max' => 500,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .grid-item' => 'margin-bottom: {{SIZE}}{{UNIT}}',
                ],

            ]
        );

        $this->add_control(
            'background_color',
            [
                'label' =>   esc_html__( 'Background', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mason-content' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'border_col',
            [
                'label' =>   esc_html__( 'Border Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .post-entry' => 'border-bottom:1px solid {{VALUE}};',
                    '{{WRAPPER}} .mason-content' => 'border:1px solid {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
          'item_padding',
          [
             'label' =>   esc_html__( 'Padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => ['px', '%', 'em'],
             'selectors' => [
                    '{{WRAPPER}} .grid-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_title',
            [
                'label' =>   esc_html__('Title', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'heading_typography',
                'selector' => '{{WRAPPER}} .post-title-builder',
                'label' =>   esc_html__( 'Post title', 'thepack' ),
            ]
        );

        $this->add_control(
            'title_col',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .post-title-builder a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'title_colh',
            [
                'label' =>   esc_html__( 'Hover Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .post-title-builder:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
          'title_margin',
          [
             'label' =>   esc_html__( 'Margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px', '%', 'em' ],
             'selectors' => [
                    '{{WRAPPER}} .post-title-builder' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_excerpt',
            [
                'label' =>   esc_html__('Excerpt', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'excerpt_typography',
                'selector' => '{{WRAPPER}} .post-entry',
                'label' =>   esc_html__( 'Post title', 'thepack' ),
            ]
        );

        $this->add_control(
            'excerpt_col',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .post-entry' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
          'excerpt_margin',
          [
             'label' =>   esc_html__( 'Margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px', '%', 'em' ],
             'selectors' => [
                    '{{WRAPPER}} .post-entry' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_control(
            'excerpt_bot_pad',
            [
                'label' =>   esc_html__( 'Padding-bottom', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .post-entry' => 'padding-bottom: {{SIZE}}{{UNIT}}',
                ],

            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_meta',
            [
                'label' =>   esc_html__('Post Meta', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'meta_typography',
                'selector' => '{{WRAPPER}} .leffect-1',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
            ]
        );

        $this->add_control(
            'pmata_color',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .leffect-1' => 'color: {{VALUE}};',
                ],
            ]
        );


        $this->add_control(
            'pmata_collink',
            [
                'label' =>   esc_html__( 'Link Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .leffect-1 a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'pmata_collinkh',
            [
                'label' =>   esc_html__( 'Link Hover Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .leffect-1 a:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_btn',
            [
                'label' =>   esc_html__('Read More Button', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'more_typography',
                'selector' => '{{WRAPPER}} .btn-more',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
            ]
        );

        $this->add_control(
            'more_color',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn-more' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'more_collinkh',
            [
                'label' =>   esc_html__( 'Hover Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn-more:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_carousel',
            [
                'label' =>   esc_html__('Carousel', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,                  
            ]
        );

        $this->add_control(
            'arrow',
            [
                'label' =>   esc_html__('Display arrow', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                 
            ]
        );

        $this->add_control(
            'auto',
            [
                'label' =>   esc_html__('Autoplay', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',                
            ]
        );

        $this->add_control(
            'dot',
            [
                'label' =>   esc_html__('Display dot', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'yes',
                'default' => 'no',               
            ]
        );

        $this->add_control(
            'item',
            [
                'label' =>   esc_html__( 'Item per slide', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'default' => [
                    'size' => 4,
                ],                
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 5,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],              
            ]
        );

        $this->add_control(
            'item_tab',
            [
                'label' =>   esc_html__( 'Item per slide tablet', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'default' => [
                    'size' => 2,
                ],                
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 5,
                        'step' => 1,
                    ],
                ],            
            ]
        );

        $this->add_control(
            'speed',
            [
                'label' =>   esc_html__( 'Slide speed', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 8000,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],              
            ]
        );


        $this->end_controls_section(); 

        $this->start_controls_section(
            'section_carousel_cust',
            [
                'label' =>   esc_html__('Carousel Customiser', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,              
            ]
        );

        $this->add_control(
            'pri',
            [
                'label' =>   esc_html__('Arrow color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-arrow' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'sec',
            [
                'label' =>   esc_html__('Arrow background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-arrow' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'dot-pos',
            [
                'label' =>   esc_html__('Dot position', 'thepack'),
                'type' => Controls_Manager::NUMBER,    
                'selectors' => [
                    '{{WRAPPER}} .slick-dots' => 'bottom: {{VALUE}}px;',
                ],                            
            ]
        );

        $this->add_control(
            'prih',
            [
                'label' =>   esc_html__('Arrow hover color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-arrow:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'sech',
            [
                'label' =>   esc_html__('Arrow hover background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-arrow:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'arrow_border_co',
            [
                'label' =>   esc_html__('Arrow border color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-arrow' => 'border:1px solid {{VALUE}};border-style:solid;',
                ],
            ]
        );
        $this->add_control(
            'arrow_border_co_r',
            [
                'label' =>   esc_html__( 'Arrow Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .slick-arrow' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'dotsec',
            [
                'label' =>   esc_html__('Dot main color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-dots li button' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'dotprih',
            [
                'label' =>   esc_html__('Active border color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-dots li.slick-active button' => 'box-shadow:0 0 0 2px {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'dotprihacti',
            [
                'label' =>   esc_html__('Active background color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-dots li.slick-active button' => 'background:{{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';

    }

    protected function content_template() {
    }

}

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new thepack_blog_list_intro() );
