<?php

namespace thepack_themebuilderr;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;

class thepack_folionavv extends Widget_Base{
    public function get_name() {
        return 'ae-post-navigation';
    }

    public function get_title() {
        return   esc_html__( 'FOLIO NAV', 'thepack' );
    }

    public function get_icon() {
        return 'eicon-navigation-horizontal';
    }

    public function get_categories() {
        return [ 'ae-template-elements' ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__( 'General', 'thepack' ),
            ]
        );

        $this->add_control(
            'tmpl',
            [
                'label' =>   esc_html__('Template', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'one' => [
                        'title' =>   esc_html__('One', 'thepack'),
                        'icon' => 'fa fa-folder',
                    ],
                    'two' => [
                        'title' =>   esc_html__('Two', 'thepack'),
                        'icon' => 'fa fa-folder-o',
                    ],
                ],
                'default' => 'one',               
            ]
        );

        $this->add_control(
            'show_label',
            [
                'label' =>   esc_html__( 'Show label', 'thepack' ),
                'type' => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'post_title',
            [
                'label' =>   esc_html__( 'Post title', 'thepack' ),
                'type' => Controls_Manager::SWITCHER,
            ]
        );
        $this->add_control(

            'arclink', [
                'type' => Controls_Manager::SELECT,
                'label' =>   esc_html__('Archive link', 'thepack'),
                'options' => [
                    'post' =>   esc_html__('Post', 'thepack'),
                    'portfolio' =>   esc_html__('Portfolio', 'thepack'),
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_previous',
            [
                'label' =>   esc_html__( 'Previous', 'thepack' ),
            ]
        );


        $this->add_control(
            'prev_label',
            [
                'label' =>   esc_html__( 'Previous Label', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'placeholder' =>   esc_html__( 'Enter Label', 'thepack' ),
                'default' =>   esc_html__( 'Previous', 'thepack' ),
            ]
        );

        $this->add_control(
            'next_label',
            [
                'label' =>   esc_html__( 'Next Label', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'placeholder' =>   esc_html__( 'Enter Label', 'thepack' ),
                'default' =>   esc_html__( 'Next', 'thepack' ),
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_previous',
            [
                'label' =>   esc_html__( 'Icons', 'thepack' ),
            ]
        );

        $this->add_control(
            'picon',
            [
                'type' => Controls_Manager::ICON,
                'label' =>   esc_html__('Previous Icon', 'thepack'),
                'label_block' => true,
            ]
        );        

        $this->add_control(
            'cicon',
            [
                'type' => Controls_Manager::ICON,
                'label' =>   esc_html__('Center Icon', 'thepack'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'nicon',
            [
                'type' => Controls_Manager::ICON,
                'label' =>   esc_html__('Next Icon', 'thepack'),
                'label_block' => true,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_label',
            [
                'label' =>   esc_html__( 'Label', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'icnspace',
            [
                'label' =>   esc_html__( 'Content spacing from icon', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .prev-post .innerpg' => 'padding-left: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .next-post .innerpg' => 'padding-right: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'show_label',
            [
                'label' =>   esc_html__( 'Show label', 'thepack' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__( 'Yes', 'thepack' ),
                'label_off' =>   esc_html__( 'No', 'thepack' ),
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'label',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
                'selector' => '{{WRAPPER}} .tblabel',
            ]
        );
        $this->add_control(
            'label_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .tblabel' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'botpad-label',
            [
                'label' =>   esc_html__( 'Bottom margin', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => -50,
                        'max' => 100,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .tblabel' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section-link',
            [
                'label' =>   esc_html__( 'Link', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_control(
            'link_length',
            [
                'label' =>   esc_html__( 'Link length', 'thepack' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                    ],
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'link',
                'label' =>   esc_html__( 'Link', 'thepack' ),
                'selector' => '{{WRAPPER}} .link',
            ]
        );

        $this->add_control(
            'link_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .link' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'link_colorh',
            [
                'label' =>   esc_html__('Hover Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .link:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();
        $this->start_controls_section(
            'section-icon',
            [
                'label' =>   esc_html__( 'Icon', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE
            ]
        );        

        $this->add_control(
            'icon-color',
            [
                'label' =>   esc_html__('Prev-Next Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .prvnxticon' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'icon-size',
            [
                'label' =>   esc_html__( 'Prev-Next Size', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .prvnxticon' => 'font-size: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'ci-color',
            [
                'label' =>   esc_html__('Center icon Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .middleticon' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'ci-bgcolor',
            [
                'label' =>   esc_html__('Center icon background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .middleticon' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'ci-size',
            [
                'label' =>   esc_html__( 'Center icon Size', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .middleticon' => 'font-size: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'ci-lsize',
            [
                'label' =>   esc_html__( 'Center icon position', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .middleticon' => 'line-height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'ci-wh',
            [
                'label' =>   esc_html__( 'Center icon width and height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .middleticon' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};display: inline-block;',
                ],

            ]
        );

        $this->end_controls_section();
    }

    protected function render( ) {
        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';
    }
}

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new thepack_folionavv() );