<?php

namespace thepack_themebuilderr;
use Elementor\Plugin;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

class thepack_header1 extends Widget_Base{
    
    public function get_name() {
        return 'tb-header1';
    }
 
    public function get_title() {
        return   esc_html__( 'HEADER 1', 'thepack' );
    }

    public function get_icon() {
        return 'eicon-image-box';
    }

    public function get_categories() {
        return [ 'ae-template-elements' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_cntnt',
            [
                'label' =>   esc_html__( 'Content', 'thepack' )
            ]
        );

        $this->add_control(
            'logo',
            [
                'label' =>   esc_html__('Logo', 'thepack'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'menu',
            [
                'label' =>   esc_html__('Menu', 'thepack'),
                'type' => Controls_Manager::SELECT2,
                'options' =>  thepack_drop_menu_select(), 
                'multiple' => false,
                'label_block' => true 
            ]
        );

        $repeater1 = new \Elementor\Repeater();

        $repeater1->add_control(
            'icon', [
                'label' =>   esc_html__( 'Icon', 'thepack' ),
                'type' => Controls_Manager::ICON,
                'label_block' => true,
                'default' => 'fa fa-facebook',                               
            ]
        );

        $repeater1->add_control(
            'url', [
                'label' =>   esc_html__('Social link url', 'thepack'),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'placeholder' =>   esc_html__('http://your-link.com', 'thepack'),
            ]
        );        

        $this->add_control(
            'items',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater1->get_controls(),  
                'prevent_empty' => false,
                'default' => [
                    [
                        'icon' =>   esc_html__( 'fa fa-facebook', 'thepack' ),
                    ]
                ],
                'title_field' => '<i class="{{{icon}}}"></i>',
            ]
        );

        $this->add_control(
            'tickn', [
                'label' =>   esc_html__( 'Tap icon', 'thepack' ),
                'type' => Controls_Manager::ICON,
                'label_block' => true,
                'default' => 'fa fa-bar',                               
            ]
        );

        $this->add_control(
            'xikn', [
                'label' =>   esc_html__( 'Close icon', 'thepack' ),
                'type' => Controls_Manager::ICON,
                'label_block' => true,
                'default' => 'fa fa-bar',                               
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_gnrl',
            [
                'label' =>   esc_html__( 'General', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'wid',
            [
                'label' =>   esc_html__( 'Width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .tbheader-aside' => 'width: {{SIZE}}px;',
                ],

            ]
        );

        $this->add_responsive_control(
            'tbspc',
            [
                'label' =>   esc_html__( 'Top bottom spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .social-icons' => 'bottom: {{SIZE}}px;',
                    '{{WRAPPER}} .logotb' => 'top: {{SIZE}}px;',
                ],

            ]
        );

        $this->add_control(
            'bbg',
            [
                'label' =>   esc_html__( 'Background', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbheader-aside' => 'background: {{VALUE}};',
                ],               
            ]
        );

        $this->add_control(
            'btxt',
            [
                'label' =>   esc_html__( 'Text color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .open-nav i' => 'color: {{VALUE}};',
                ],               
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_lgos',
            [
                'label' =>   esc_html__('Logo & Icon','thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'ico-sze',
            [
                'label' =>   esc_html__( 'Icon size', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .tbicon' => 'font-size: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'lgo-wid',
            [
                'label' =>   esc_html__( 'Logo width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .logotb' => 'width: {{SIZE}}px;',
                ],

            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_offscreen',
            [
                'label' =>   esc_html__('Offscreen', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'overlay_bg',
            [
                'label' =>   esc_html__('Overlay background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .click-capture' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'offnav_typo',
                'label' =>   esc_html__('Parent nav typo', 'thepack'),
                'selector' => '{{WRAPPER}} .menu-list > li',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'off_sub_typo',
                'label' =>   esc_html__('Child nav typo', 'thepack'),
                'selector' => '{{WRAPPER}} .menu-list ul li',
            ]
        );

        $this->add_control(
            'offmenucolor',
            [
                'label' =>   esc_html__('Menu color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .menu-list a,{{WRAPPER}} .tb_off_nav .social-icons a,{{WRAPPER}} .close-nav i' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'offmenucolor_h',
            [
                'label' =>   esc_html__('Menu color hover', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .menu-list a:hover,{{WRAPPER}} .offsocial-list a:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
          'm1',
          [
             'type'    => Controls_Manager::RAW_HTML,
             'raw' =>   esc_html__( '<b>Background</b>', 'thepack' ),
          ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'popbg',
                'label' =>   esc_html__( 'Background', 'elementor' ),
                'types' => [ 'none', 'classic','gradient' ],
                'selector' => '{{WRAPPER}} .tb_off_nav',
            ]
        );

        $this->end_controls_section();

    }

    protected function render( ) {
        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';


    }
}

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new thepack_header1() );