<?php
  
namespace thepack_themebuilderr;
use Elementor\Plugin;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;

class thepack_header4 extends Widget_Base{
    public function get_name() {
        return 'tb-header4';
    }

    public function get_title() {
        return   esc_html__( 'HEADER 4', 'thepack' );
    }

    public function get_icon() {
        return 'eicon-image-box';
    }

    public function get_categories() {
        return [ 'ae-template-elements' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_lgo',
            [
                'label' =>   esc_html__( 'Logo', 'thepack' )
            ]
        );

        $this->add_control(
            'logo_light',
            [
                'label' =>   esc_html__('Logo', 'thepack'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        ); 

        $this->add_control(
            'tapicon', [
                'label' =>   esc_html__( 'Tap icon', 'thepack' ),
                'type' => Controls_Manager::ICON,
                'label_block' => true,
                'default' => 'fa fa-plus',                               
            ]
        );

        $this->add_control(
            'klicon', [
                'label' =>   esc_html__( 'Close offsidebar icon', 'thepack' ),
                'type' => Controls_Manager::ICON,
                'label_block' => true,
                'default' => 'fa fa-plus',                               
            ]
        );

        $this->add_control(
            'picon', [
                'label' =>   esc_html__( 'Menu expand icon', 'thepack' ),
                'type' => Controls_Manager::ICON,
                'label_block' => true,
                'default' => 'fa fa-plus',                               
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_bc',
            [
                'label' =>   esc_html__( 'Content', 'thepack' )
            ]
        );

        $this->add_control(
            'menu_main',
            [
                'label' =>   esc_html__('Menu', 'thepack'),
                'type' => Controls_Manager::SELECT2,
                'options' =>  thepack_drop_menu_select(), 
                'multiple' => false,
                'label_block' => true 
            ]
        );

        $repeater1 = new \Elementor\Repeater();

        $repeater1->add_control(
            'icon', [
                'label' =>   esc_html__( 'Icon', 'thepack' ),
                'type' => Controls_Manager::ICON,
                'label_block' => true,
                'default' => 'fa fa-facebook',                               
            ]
        );

        $repeater1->add_control(
            'url', [
                'label' =>   esc_html__('Social link url', 'thepack'),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'placeholder' =>   esc_html__('http://your-link.com', 'thepack'),
            ]
        );       

        $this->add_control(
            'items',
            [
                'type' => Controls_Manager::REPEATER,
                'label' =>   esc_html__('Social icons', 'thepack'),
                'fields' => $repeater1->get_controls(), 
                'prevent_empty' => false,
                'default' => [
                    [
                        'icon' =>   esc_html__( 'fa fa-facebook', 'thepack' ),
                    ]
                ],
                'title_field' => '<i class="{{{icon}}}"></i>',
            ]
        );

        $this->add_control(
            'copy', [
                'label' =>   esc_html__( 'Copyright text', 'thepack' ),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,                             
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_gnrl',
            [
                'label' =>   esc_html__( 'General', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'tpos',
            [
                'label' =>   esc_html__( 'Header top spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,               
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 800,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],   
                'selectors' => [
                    '{{WRAPPER}} #header-4' => 'top: {{SIZE}}{{UNIT}};',
                ],                            
            ]
        );

        $this->add_responsive_control(
            'lpos',
            [
                'label' =>   esc_html__( 'Header left spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,               
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 800,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],   
                'selectors' => [
                    '{{WRAPPER}} #header-4' => 'left: {{SIZE}}{{UNIT}};',
                ],                            
            ]
        );

        $this->add_responsive_control(
            'ofwid',
            [
                'label' =>   esc_html__( 'Off canvas width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,               
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 800,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],   
                'selectors' => [
                    '{{WRAPPER}} .offsidebar' => 'width: {{SIZE}}{{UNIT}};',
                ],                            
            ]
        );

        $this->add_control(
            'bd_overlay',
            [
                'label' =>   esc_html__('Body overlay color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .click-capture' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_responsive_control(
          'of_pad',
          [
             'label' =>   esc_html__( 'Offcanvas padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px', '%', 'em' ],
             'selectors' => [
                    '{{WRAPPER}} .offsidebar' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'overlay_color',
                'label' =>   esc_html__( 'Background', 'elementor' ),
                'types' => [ 'none', 'classic','gradient' ],
                'selector' => '{{WRAPPER}} .offsidebar',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_lgos',
            [
                'label' =>   esc_html__( 'Logo & Icon', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'ico-sze',
            [
                'label' =>   esc_html__( 'Icon size', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .tapicon' => 'font-size: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'icn-col',
            [
                'label' =>   esc_html__( 'Icon color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tapicon' => 'color: {{VALUE}};',
                ],               
            ]
        );

        $this->add_responsive_control(
            'iposv',
            [
                'label' =>   esc_html__( 'Icon vertical position', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,               
                'range' => [
                    'px' => [
                        'min' => -50,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],   
                'selectors' => [
                    '{{WRAPPER}} .tapicon' => 'top: {{SIZE}}{{UNIT}};',
                ],                            
            ]
        );

        $this->add_responsive_control(
            'iposl',
            [
                'label' =>   esc_html__( 'Icon left space', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,               
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 800,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],   
                'selectors' => [
                    '{{WRAPPER}} .tapicon' => 'padding-right: {{SIZE}}{{UNIT}};',
                ],                            
            ]
        );

        $this->add_responsive_control(
            'lgo-wid',
            [
                'label' =>   esc_html__( 'Logo width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 50,
                        'max' => 500,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .logo-image' => 'width: {{SIZE}}{{UNIT}};',
                ],

            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_xicn',
            [
                'label' =>   esc_html__( 'Close icon', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'xfz',
            [
                'label' =>   esc_html__( 'Font size', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,               
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 80,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],   
                'selectors' => [
                    '{{WRAPPER}} .close-menu' => 'font-size: {{SIZE}}{{UNIT}};',
                ],                            
            ]
        );

        $this->add_control(
            'xfc',
            [
                'label' =>   esc_html__( 'Icon color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .close-menu' => 'color: {{VALUE}};',
                ],               
            ]
        );

        $this->end_controls_section();  

        $this->start_controls_section(
            'section_exicn',
            [
                'label' =>   esc_html__( 'Expand menu icon', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'exic',
            [
                'label' =>   esc_html__( 'Expand icon color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .menu-icon' => 'color: {{VALUE}};',
                ],               
            ]
        );

        $this->add_responsive_control(
            'exfz',
            [
                'label' =>   esc_html__( 'Expand icon size', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,               
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 80,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],   
                'selectors' => [
                    '{{WRAPPER}} .menu-icon' => 'font-size: {{SIZE}}{{UNIT}};',
                ],                            
            ]
        );

        $this->add_responsive_control(
            'exftp',
            [
                'label' =>   esc_html__( 'Expand icon vertical position', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,               
                'range' => [
                    'px' => [
                        'min' => -20,
                        'max' => 80,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],   
                'selectors' => [
                    '{{WRAPPER}} .menu-icon' => 'top: {{SIZE}}{{UNIT}};',
                ],                            
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_navmenu',
            [
                'label' =>   esc_html__( 'Navigation menu', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'mxscrollh',
            [
                'label' =>   esc_html__( 'Scrollheight', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,               
                'range' => [
                    'px' => [
                        'min' => 50,
                        'max' => 800,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'size' => 200,
                ],                
                'size_units' => [ 'px'],                             
            ]
        );

        $this->add_responsive_control(
          'om-pad',
          [
             'label' =>   esc_html__( 'Wrapper margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px', '%', 'em' ],
             'selectors' => [
                    '{{WRAPPER}} .scrollbar-macosxwrp' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_responsive_control(
          'parlipad',
          [
             'label' =>   esc_html__( 'Parent item padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px', '%', 'em' ],
             'selectors' => [
                    '{{WRAPPER}} .menu-list > li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_responsive_control(
          'chilipad',
          [
             'label' =>   esc_html__( 'Child wrapper item padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px', '%', 'em' ],
             'selectors' => [
                    '{{WRAPPER}} .menu-list ul' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_responsive_control(
          'chiliipad',
          [
             'label' =>   esc_html__( 'Child item padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px', '%', 'em' ],
             'selectors' => [
                    '{{WRAPPER}} .menu-list ul li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'offnav_typo',
                'label' =>   esc_html__('Parent nav typo', 'thepack'),
                'selector' => '{{WRAPPER}} .menu-list > li',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'off_sub_typo',
                'label' =>   esc_html__('Child nav typo', 'thepack'),
                'selector' => '{{WRAPPER}} .menu-list ul li',
            ]
        );

        $this->add_control(
            'offmenucolor',
            [
                'label' =>   esc_html__('Menu color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .menu-list a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'offmenucolor_h',
            [
                'label' =>   esc_html__('Menu color hover', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .menu-list a:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_osocial',
            [
                'label' =>   esc_html__( 'Social links', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
          'socipad',
          [
             'label' =>   esc_html__( 'Wrapper margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px', '%', 'em' ],
             'selectors' => [
                    '{{WRAPPER}} .socialitm' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_responsive_control(
            'sofz',
            [
                'label' =>   esc_html__( 'Font size', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,               
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 80,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],   
                'selectors' => [
                    '{{WRAPPER}} .socialitm a' => 'font-size: {{SIZE}}{{UNIT}};',
                ],                            
            ]
        );

        $this->add_responsive_control(
            'sorm',
            [
                'label' =>   esc_html__( 'Right spacing', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,               
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 80,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],   
                'selectors' => [
                    '{{WRAPPER}} .socialitm li' => 'margin-right: {{SIZE}}{{UNIT}};',
                ],                            
            ]
        );

        $this->add_control(
            'sofc',
            [
                'label' =>   esc_html__( 'Icon color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .socialitm a' => 'color: {{VALUE}};',
                ],               
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_ocpy',
            [
                'label' =>   esc_html__( 'Copyright text', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'cpyc',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .copy' => 'color: {{VALUE}};',
                ],               
            ]
        );

        $this->add_responsive_control(
          'cpymr',
          [
             'label' =>   esc_html__( 'Margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px', '%', 'em' ],
             'selectors' => [
                    '{{WRAPPER}} .copy' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'cpy_ty',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .copy',
            ]
        );

        $this->end_controls_section();


    }

    protected function render( ) {
        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';
    }

    private function content($content) {

        foreach ($content as $item){

            $out .= '
                <li><a  href="'.esc_attr($item['url']['url']).'" target="_blank">
                    <span class="icon '.esc_attr($item['icon']).'"></span>
                </a></li>
            '; 

        }

        return '<ul class="socialitm">'.$out.'</ul>';

    }
}

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new thepack_header4() );