<?php
  
namespace thepack_themebuilderr;
use Elementor\Plugin;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;

class thepack_tb_op1 extends Widget_Base{
    public function get_name() {
        return 'tb-headerop1';
    }

    public function get_title() {
        return   esc_html__( 'HEADER OP', 'thepack' );
    }

    public function get_icon() {
        return 'eicon-image-box';
    }

    public function get_categories() {
        return [ 'ae-template-elements' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_lgo',
            [
                'label' =>   esc_html__( 'Logo', 'thepack' )
            ]
        );

        $this->add_control(
            'logo_light',
            [
                'label' =>   esc_html__('Logo', 'thepack'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        ); 

        $this->add_control(
            'logo_dark',
            [
                'label' =>   esc_html__('Logo fixed', 'thepack'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        ); 

        $this->add_control(
            'menu_main',
            [
                'label' =>   esc_html__('Menu', 'thepack'),
                'type' => Controls_Manager::SELECT2,
                'options' =>  thepack_drop_menu_select(), 
                'multiple' => false,
                'label_block' => true 
            ]
        );

        $this->add_control(
            'icon', [
                'label' =>   esc_html__( 'Tap icon', 'thepack' ),
                'type' => Controls_Manager::ICON,
                'label_block' => true,
                'default' => 'fa fa-bar',                               
            ]
        );
        $repeater1 = new \Elementor\Repeater();

        $repeater1->add_control(
            'label', [
                'label' =>   esc_html__( 'Menu label', 'thepack' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Home',                               
            ]
        );

        $repeater1->add_control(
            'type', [
                'label' =>   esc_html__('Type', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'link' => [
                        'title' =>   esc_html__('Link', 'thepack'),
                        'icon' => ' eicon-document-file',
                    ],
                    'template' => [
                        'title' =>   esc_html__('Template', 'thepack'),
                        'icon' => 'eicon-image-rollover',
                    ]
                ],
                'default' => 'content',
                'label_block' => true,                
            ]
        );

        $repeater1->add_control(
            'url', [
                'label' =>   esc_html__('Custom link', 'thepack'),
                'condition' => [
                    'type' => 'link',
                ],                
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'placeholder' =>   esc_html__('http://your-link.com', 'thepack'),
            ]
        );       

        $repeater1->add_control(
            'template', [
                'type' => Controls_Manager::TEXT, 
                'multiple' => false,
                'label' =>   esc_html__('Section Id', 'thepack'),
                'label_block' => true,
                'condition' => [
                    'type' => 'template',
                ],
            ]
        );

        $this->add_control(
            'items',
            [
                'type' => Controls_Manager::REPEATER,
                'label' =>   esc_html__('Blocks', 'thepack'),
                'fields' => $repeater1->get_controls(), 
                'prevent_empty' => false,
                'default' => [
                    [
                        'label' =>   esc_html__( 'Home', 'thepack' ),
                    ]
                ],
                'title_field' => '{{{label}}}',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_gnrl',
            [
                'label' =>   esc_html__( 'General', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'disp',
            [
                'label' =>   esc_html__('Display', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [

                    'absolute' => [
                        'title' =>   esc_html__('Absolute', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'relative' => [
                        'title' =>   esc_html__('Relative', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ]
                ], 
                'selectors' => [
                    '{{WRAPPER}} #opnav1' => 'position: {{VALUE}};',
                ],                 
            ]
        );

        $this->add_control(
            'sticky',
            [
                'label' =>   esc_html__('Enable sticky', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),             
            ]
        );

        $this->add_responsive_control(
            'mwid',
            [
                'label' =>   esc_html__( 'Max width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,               
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1500,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],   
                'selectors' => [
                    '{{WRAPPER}} nav' => 'max-width: {{SIZE}}{{UNIT}};',
                ],                            
            ]
        );

        $this->add_responsive_control(
            'bhi',
            [
                'label' =>   esc_html__( 'Navbar height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,               
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 800,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],   
                'selectors' => [
                    '{{WRAPPER}} #opnav1' => 'line-height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} #opnav1.scrollUp' => 'transform:translateY(-{{SIZE}}{{UNIT}});',
                ],                            
            ]
        );

        $this->add_control(
            'nvbgc',
            [
                'label' =>   esc_html__('Navbar backgroundcolor', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #opnav1' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'bhis',
            [
                'label' =>   esc_html__( 'Sticky navbar height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,               
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 800,
                        'step' => 1,
                    ],
                ],
                'size_units' => [ 'px'],   
                'selectors' => [
                    '{{WRAPPER}} #opnav1.stickyon.fixed' => 'line-height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} #opnav1.stickyon.fixed.scrollUp' => 'transform:translateY(-{{SIZE}}{{UNIT}});',
                ],                            
            ]
        );

        $this->add_control(
            'nvbgcs',
            [
                'label' =>   esc_html__('Sticky navbar backgroundcolor', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #opnav1.stickyon.fixed' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_lgos',
            [
                'label' =>   esc_html__( 'Logo', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'lgo-wid',
            [
                'label' =>   esc_html__( 'Logo width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 50,
                        'max' => 500,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .logo-image' => 'width: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'lgo-wids',
            [
                'label' =>   esc_html__( 'Sticky Logo width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 50,
                        'max' => 500,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .fixed .logo-image' => 'width: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_navmenu',
            [
                'label' =>   esc_html__( 'Navigation menu', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );


        $this->add_responsive_control(
          'om-pad',
          [
             'label' =>   esc_html__( 'Padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px', '%', 'em' ],
             'selectors' => [
                    '{{WRAPPER}} .tbnav a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'm_typo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .tbnav a',
            ]
        );

        $this->add_responsive_control(
            'offmenucolor',
            [
                'label' =>   esc_html__('Menu color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbnav a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'offmenucolors',
            [
                'label' =>   esc_html__('Menu sticky color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .fixed .tbnav a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'offmenucolor_h',
            [
                'label' =>   esc_html__('Menu color hover', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbnav a:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_tpikn',
            [
                'label' =>   esc_html__( 'Tap icon', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'tpclr',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #menu-icon i' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'tpsz',
            [
                'label' =>   esc_html__( 'Size', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} #menu-icon i' => 'font-size: {{SIZE}}{{UNIT}};',
                ],

            ]
        );
        $this->end_controls_section();

    }

    protected function render( ) {
        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';
    }

    private function navcontent($content) {

        foreach ($content as $item){

            $lbl = $item['label'] ? ''.$item['label'].'' : '';

            if ($item['type'] == 'template'){
                $out .= '
                    <li><a  href="#'.str_replace(' ', '', $item['template']).'">
                    '.$lbl.'</a></li>
                ';
            } else {

                $url = $item['url']['url'];
                $ext = $item['url']['is_external'];
                $nofollow = $item['url']['nofollow'];

                $url = ( isset($url) && $url ) ? 'href='.esc_url($url). '' : '';
                $ext = ( isset($ext) && $ext ) ? 'target= _blank' : '';
                $nofollow = ( isset($url) && $url ) ? 'rel=nofollow' : '';
                $link = $url.' '.$ext.' '.$nofollow;

                $out .= '
                    <li><a '.$link.'>
                    '.$lbl.'</a></li>
                ';                
            }

        }

        return '<ul class="tbnav">'.$out.'</ul>';
    }

}

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new thepack_tb_op1() );