<?php
 
/*
Widget Name: Webangon full social
Description: Full width social.
Author: Ashraf
Author URI: https://www.webangon.com
*/

namespace thepack_themebuilderr;
use Elementor\Plugin;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
 
if (!defined('ABSPATH'))
    exit; // Exit if accessed directly


class thepack_header_topinfo extends Widget_Base {

    public function get_name() {
        return 'tb-hdrtpinfo';
    }

    public function get_title() {
        return   esc_html__('HEADER TOPINFO', 'thepack');
    }

    public function get_icon() {
        return 'eicon-form-horizontal';
    }

    public function get_categories() {
        return array('ashelement-addons');
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_pricing_table',
            [
                'label' =>   esc_html__('Logo', 'thepack'),
            ]
        );

        $this->add_control(

            'style', [
                'type' => Controls_Manager::SELECT,
                'label' =>   esc_html__('Style', 'thepack'),
                'default' => 'style-one',
                'options' => [
                    'style_one' =>   esc_html__('Style 1', 'thepack'),
                    'style_two' =>   esc_html__('Style 2', 'thepack'),
                    'style_three' =>   esc_html__('Style 3', 'thepack'),
                ],
            ]
        );

        $this->add_control(
            'logo',
            [
                'label' =>   esc_html__('Logo', 'thepack'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'light-logo',
            [
                'label' =>   esc_html__('Logo light', 'thepack'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        ); 
        $this->end_controls_section();
        $this->start_controls_section(
            'section_menuof',
            [
                'label' =>   esc_html__('Socials & extra ', 'thepack'),
            ]
        );

        $this->add_control(
            'show_toggle',
            [
                'label' =>   esc_html__( 'Show toggle menu', 'thepack' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__( 'Yes', 'thepack' ),
                'label_off' =>   esc_html__( 'No', 'thepack' ),
            ]
        );

        $this->add_control(
            'tikn', [
                'label' =>   esc_html__( 'Tap Icon', 'thepack' ),
                'type' => Controls_Manager::ICON,
                'label_block' => true,
                'condition' => [
                    'show_toggle' => 'yes',
                ],                                               
            ]
        );

        $repeater1 = new \Elementor\Repeater();

        $repeater1->add_control(
            'icon', [
                'label' =>   esc_html__( 'Icon', 'thepack' ),
                'type' => Controls_Manager::ICON,
                'label_block' => true,
                'default' => 'fa fa-facebook',                               
            ]
        );

        $repeater1->add_control(
            'url', [
                'label' =>   esc_html__('Social link url', 'thepack'),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'placeholder' =>   esc_html__('http://your-link.com', 'thepack'),
            ]
        );        

        $this->add_control(
            'items',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater1->get_controls(),  
                'prevent_empty' => false,
                'default' => [
                    [
                        'icon' =>   esc_html__( 'fa fa-facebook', 'thepack' ),
                    ]
                ],
                'title_field' => '<i class="{{{icon}}}"></i>',
            ]
        );

        $this->add_control(
            'btn',
            [
                'label' =>   esc_html__('Button label', 'thepack'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true 
            ]
        );

        $this->add_control(
            'link',
            [
                'label' =>   esc_html__( 'Link', 'elementor' ),
                'type' => Controls_Manager::URL,
                'placeholder' => 'http://your-link.com',
                'default' => [
                    'url' => '#',
                ],
            ]
        );


        $this->add_control(
            'copyright',
            [
                'label' =>   esc_html__('Copyright text', 'thepack'),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true 
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_menugen',
            [
                'label' =>   esc_html__('Menu', 'thepack'),                
            ]
        );

        $this->add_control(
            'menu_main',
            [
                'label' =>   esc_html__('Main navmenu', 'thepack'),
                'type' => Controls_Manager::SELECT2,
                'options' =>  thepack_drop_menu_select(), 
                'multiple' => false,
                'label_block' => true 
            ]
        );
        $this->add_control(
            'menu-off',
            [
                'label' =>   esc_html__('Offscreen menu', 'thepack'),
                'type' => Controls_Manager::SELECT2,
                'options' =>  thepack_drop_menu_select(), 
                'multiple' => false,
                'label_block' => true 
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_general_s',
            [
                'label' =>   esc_html__( 'General settings', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'nav_h',
            [
                'label' =>   esc_html__( 'Navbar Height', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .header-one' => 'line-height: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_responsive_control(
            'nav_w',
            [
                'label' =>   esc_html__( 'Navbar width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1500,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .headerwrp' => 'max-width: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'bar-bg',
            [
                'label' =>   esc_html__( 'Background color', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .header-one' => 'background: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'stikybar-bg',
            [
                'label' =>   esc_html__( 'Sticky background color', 'thepack' ),
                'type' => Controls_Manager::COLOR,                
                'selectors' => [
                    '{{WRAPPER}} .header-one.is-fixed' => 'background: {{VALUE}};'
                ],
            ]
        );


        $this->add_control(
            'abs_header',
            [
                'label' =>   esc_html__( 'Overlay header absolute position', 'thepack' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__( 'Yes', 'thepack' ),
                'label_off' =>   esc_html__( 'No', 'thepack' ),
                'return_value' => 'abs-header',
            ]
        );

        $this->add_control(
            'sticky_header',
            [
                'label' =>   esc_html__( 'Sticky header', 'thepack' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__( 'Yes', 'thepack' ),
                'label_off' =>   esc_html__( 'No', 'thepack' ),
                'return_value' => 'tbsticky-header',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_logo_s',
            [
                'label' =>   esc_html__( 'Logo', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'logo_w',
            [
                'label' =>   esc_html__( 'Logo width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .tbsite-logo img' => 'width: {{SIZE}}{{UNIT}};',
                ],

            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_navmnu',
            [
                'label' =>   esc_html__( 'Navmenu', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
          'navmenuwrap',
          [
             'label' =>   esc_html__( 'Menu wrapper padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px'],
             'allowed_dimensions' => array('left','right'),
             'selectors' => [
                    '{{WRAPPER}} ul.topnav' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_control(
            'nav_item_pad',
            [
                'label' =>   esc_html__( 'Menu item Padding (left & right)', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .topnav >li >a' => 'padding: 0px {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'memualign',
            [
                'label' =>   esc_html__('Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ]
                ],
                'default' => 'center',
                'selectors' => [
                    '{{WRAPPER}} ul.topnav' => 'text-align: {{VALUE}};',
                ],                 
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'nav_typo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .topnav >li >a',
            ]
        );

        $this->add_control(
            'nav_color',
            [
                'label' =>   esc_html__('Menu color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .topnav >li >a,{{WRAPPER}} .navbar-toggle' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'nav_colorfixed',
            [
                'label' =>   esc_html__('Menu color sticky', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .is-fixed .topnav >li >a,{{WRAPPER}} .is-fixed .navbar-toggle'=> 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'nav_colorfixed',
            [
                'label' =>   esc_html__('Menu color sticky', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .is-fixed .topnav >li >a,{{WRAPPER}} .is-fixed .search_menu'=> 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'subtopmarginst',
            [
                'label' =>   esc_html__( 'Top margin sticky', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .is-fixed .topnav li:hover .sub-menu' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_childnav',
            [
                'label' =>   esc_html__( 'Submenu', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'subtopmargin',
            [
                'label' =>   esc_html__( 'Top margin', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .topnav li:hover .sub-menu' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'subg',
            [
                'label' =>   esc_html__('Wrapper background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .topnav .sub-menu'=> 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'sub_typo',
                'label' =>   esc_html__('Typo', 'thepack'),
                'selector' => '{{WRAPPER}} .topnav .sub-menu a',
            ]
        );

        $this->add_control(
            'fixedntxt',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .topnav .sub-menu a'=> 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'submenu_hover_color',
            [
                'label' =>   esc_html__('Hover Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .topnav .sub-menu a:hover'=> 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
          'submenu_pad',
          [
             'label' =>   esc_html__( 'Item padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px'],
             //'allowed_dimensions' => array('left','right'),
             'selectors' => [
                    '{{WRAPPER}} .topnav .sub-menu a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'section_ctabtn',
            [
                'label' =>   esc_html__('Button', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,               
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'ctbtnty',
                'label' =>   esc_html__('Button typo', 'thepack'),
                'selector' => '{{WRAPPER}} .tbar-btn span',
            ]
        );

        $this->add_control(
            'tbar_btn_pad',
            [
                'label' =>   esc_html__('Button padding', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%','em' ],
                'selectors' => [
                    '{{WRAPPER}} .tbar-btn span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'tabar_btnbg',
            [
                'label' =>   esc_html__('Button background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbar-btn span' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'tabar_btncol',
            [
                'label' =>   esc_html__('Button color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbar-btn span' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'tabar_btnbgh',
            [
                'label' =>   esc_html__('Button hover background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbar-btn:hover span' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'tabar_btncolh',
            [
                'label' =>   esc_html__('Button hover color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbar-btn:hover span' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'tabar_btnbordercol0r',
            [
                'label' =>   esc_html__('Button border color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbar-btn span' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'tbar_btn_borderwid',
            [
                'label' =>   esc_html__( 'Button border width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .tbar-btn span' => 'border-width: {{SIZE}}{{UNIT}};border-style:solid;',
                ],

            ]
        );

        $this->add_control(
            'tbar_btn_borderadius',
            [
                'label' =>   esc_html__( 'Button border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .tbar-btn span' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],

            ]
        );        
        $this->end_controls_section();

        $this->start_controls_section(
            'section_offscreen',
            [
                'label' =>   esc_html__('Offscreen', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'overlay_bg',
            [
                'label' =>   esc_html__('Overlay background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .click-capture' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'offnav_typo',
                'label' =>   esc_html__('Parent nav typo', 'thepack'),
                'selector' => '{{WRAPPER}} .menu-list > li',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'off_sub_typo',
                'label' =>   esc_html__('Child nav typo', 'thepack'),
                'selector' => '{{WRAPPER}} .menu-list ul li',
            ]
        );

        $this->add_control(
            'offmenucolor',
            [
                'label' =>   esc_html__('Menu color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .menu-list a,{{WRAPPER}} .offsocial-list a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'offmenucolor_h',
            [
                'label' =>   esc_html__('Menu color hover', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .menu-list a:hover,{{WRAPPER}} .offsocial-list a:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'copy_typo',
                'label' =>   esc_html__('Copyright typo', 'thepack'),
                'selector' => '{{WRAPPER}} .copy',
            ]
        );

        $this->add_control(
            'copy_color',
            [
                'label' =>   esc_html__('Copyright color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .copy' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

    }
        

    protected function render() {

        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';
    }


    private function header_button($label,$link){
        $url = $link['url'];
        $ext = $link['is_external'];
        $nofollow = $link['nofollow'];

        $url = ( isset($url) && $url ) ? 'href='.esc_url($url). '' : '';
        $ext = ( isset($ext) && $ext ) ? 'target= _blank' : '';
        $nofollow = ( isset($url) && $url ) ? 'rel=nofollow' : '';

        $link = ( isset($url) && $url ) ? '<a class="tbar-btn hidden-sm hidden-xs" '.$url.' '.$ext.' '.$nofollow.'><span>'.$label.'</span></a>' : '';
        echo $link;        

    }

    private function builder_header_socials($array){
        if(is_array($array)){
            foreach ($array as $a){
                $icon = $a['icon'];
                $url = (empty($a['url']['url'])) ? ' ' : esc_url($a['url']['url']);
                $target = $a['url']['is_external'] ? 'target="_blank"' : '';
                $markup.= '<li><a href="'.esc_url($url).'" target="_blank"><i class="'.$icon. '"></i></a></li>';
            }
            return $markup;
        }
    }

    private function show_navtoggle($label,$icon){
        if ($label){
            echo '<span class="navbar-toggle"><i class="tbicon '.$icon.'"></i></span>';
        } else {
            echo '<span class="navbar-toggle hidden-dsktp"><i class="tbicon '.$icon.'"></i></span>';
        }
    }


} 

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new thepack_header_topinfo() );