<?php

namespace thepack_themebuilderr;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Scheme_Typography;
use Elementor\Plugin;

class thepack_post_comment extends Widget_Base{
    public function get_name() {
        return 'ae-post-comments';
    }

    public function get_title() {
        return   esc_html__( 'COMMENTS', 'thepack' );
    }

    public function get_icon() {
        return 'eicon-testimonial';
    }

    public function get_categories() {
        return [ 'ae-template-elements' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_heading',
            [
                'label' =>   esc_html__( 'General', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'heading_color',
            [
                'label' =>   esc_html__( 'Heading Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .comment-wrap .title h3,{{WRAPPER}} #reply-title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'heading_typ',
                'label' =>   esc_html__( 'Heading Typography', 'thepack' ),
                'selector' => '{{WRAPPER}} .comment-wrap .title h3,{{WRAPPER}} #reply-title',
            ]
        );

        $this->end_controls_section();   

        $this->start_controls_section(
            'section_meta',
            [
                'label' =>   esc_html__( 'Comment', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'auth_color',
            [
                'label' =>   esc_html__( 'Author name color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .comment-wrap .name h4' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'auth_typ',
                'label' =>   esc_html__( 'Author name typography', 'thepack' ),
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .comment-wrap .name h4',
            ]
        );


        $this->add_control(
            'date_color',
            [
                'label' =>   esc_html__( 'Date label color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .comarticle .date' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'date_typ',
                'label' =>   esc_html__( 'Date label typography', 'thepack' ),
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .comarticle .date',
            ]
        );


        $this->add_control(
            'body_color',
            [
                'label' =>   esc_html__( 'Comment body color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .comment-content >p' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'body_typ',
                'label' =>   esc_html__( 'Comment body typography', 'thepack' ),
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .comment-content >p',
            ]
        );


        $this->add_control(
            'rply_color',
            [
                'label' =>   esc_html__( 'Reply color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .comment-reply-link' => 'color: {{VALUE}};',
                ],
            ]
        );
 
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'rply_typ',
                'label' =>   esc_html__( 'Reply typography', 'thepack' ),
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .comment-reply-link',
            ]
        );
        $this->end_controls_section();   

        $this->start_controls_section(
            'section_form',
            [
                'label' =>   esc_html__( 'Form', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'form-paddings',
            [
                'label' =>   esc_html__('Padding', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} #comment,{{WRAPPER}} #author,{{WRAPPER}} #email,{{WRAPPER}} #url' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'form_border',
                'label' =>   esc_html__( 'Form input border', 'thepack' ),
                'selector' => '{{WRAPPER}} #comment,{{WRAPPER}} #author,{{WRAPPER}} #email,{{WRAPPER}} #url',
            ]
        );
        $this->add_control(
            'formbg_color',
            [
                'label' =>   esc_html__( 'Background', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #comment,{{WRAPPER}} #author,{{WRAPPER}} #email,{{WRAPPER}} #url' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'form_color',
            [
                'label' =>   esc_html__( 'Input text color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #comment,{{WRAPPER}} #author,{{WRAPPER}} #email,{{WRAPPER}} #url' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'input_typo',
                'label' =>   esc_html__( 'Input Typography', 'thepack' ),
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} #comment,{{WRAPPER}} #author,{{WRAPPER}} #email,{{WRAPPER}} #url',
            ]
        );

        $this->end_controls_section();  

        $this->start_controls_section(
            'section_button',
            [
                'label' =>   esc_html__( 'Button', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'btn-paddings',
            [
                'label' =>   esc_html__('Padding', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} #commentform input.submit' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'btn-width',
            [
                'label' =>   esc_html__( 'Button width max', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} #commentform input.submit' => 'max-width: {{SIZE}}{{UNIT}};width: 100%;',
                ],

            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'btn_border',
                'label' =>   esc_html__( 'Border','thepack' ),
                'selector' => '{{WRAPPER}} #commentform input.submit',
            ]
        );

        $this->add_control(
            'btnbg_color',
            [
                'label' =>   esc_html__( 'Background', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #commentform input.submit' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btn_color',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #commentform input.submit' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btnbg_colorh',
            [
                'label' =>   esc_html__( 'Hover Background', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #commentform input.submit:hover' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'btn_colorh',
            [
                'label' =>   esc_html__( 'Hover Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #commentform input.submit:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typ',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
                'selector' => '{{WRAPPER}} #commentform input.submit',
            ]
        );

        $this->end_controls_section(); 
    }

    protected function render( ) {
        $settings = $this->get_settings();

        if(Plugin::instance()->editor->is_edit_mode()){ ?>

<div class="tbcustomcomnr">

<div class="comments">

          <div class="comment-wrap">
        <div class="title">
            <h3>1 comment               
            </h3>
        </div> 

        <ol class="comment-list">
                <li class="comment byuser comment-author-a bypostauthor even thread-even depth-1" id="comment-2">
            <div id="div-comment-2" class="comarticle">
      
        <div class="author-pic"><img alt="" src="http://0.gravatar.com/avatar/3f503ef5b51cdcf45106cf229882f68d?s=64&amp;d=mm&amp;r=g" srcset="http://0.gravatar.com/avatar/3f503ef5b51cdcf45106cf229882f68d?s=128&amp;d=mm&amp;r=g 2x" class="avatar avatar-64 photo" height="64" width="64"></div>
        <div class="details">
        <div class="author-meta">
            <div class="name"><h4 style="
    margin-top: 0px;
">Admin</h4></div>          <div class="date"><span>September 24, 2018</span></div>
        </div>
                
            
            <p>There are many variations of passages of Lorem Ipsum available, but the majority have suffered alteration in some form, by injected humour, or randomised words which don’t look even slightly believable.</p>
            
            <a rel="nofollow" class="comment-reply-link" href=""aria-label="Reply to Admin">Reply</a> 

       
    </div>

     
       
        </div>
        </li><!-- #comment-## -->
        </ol><!-- .comment-list -->

         
      </div>
    
    
            <div id="respond" class="comment-respond">
        <h3 id="reply-title" class="comment-reply-title">Leave a Comment <small><a rel="nofollow" id="cancel-comment-reply-link" href="/elementor/raptor/2018/09/13/tutorial-easy-10-steps-to-configure-server/#respond" style="display:none;">Cancel reply</a></small></h3>            <form action="http://localhost/elementor/raptor/wp-comments-post.php" method="post" id="commentform" class="comment-form" novalidate="">
                <p class="comment-notes col col-xs-12">Your email address will not be published. Required fields are marked  <span class="required">*</span></p><div class="comment-form-comment col col-xs-12"><textarea id="comment" class="form-control" name="comment" rows="8" aria-required="true" placeholder="Comment *"></textarea></div><div class="comment-form-author col col-md-4"><input id="author" class="form-control" name="author" type="text" value="" aria-required="true" placeholder="Name *"></div>
<div class="comment-form-email col col-md-4"><input id="email" name="email" class="form-control" type="text" value="" aria-required="true" placeholder="Email *"></div>
<div class="comment-form-url col col-md-4"><input id="url" name="url" class="form-control" type="text" value="" placeholder="Website"></div>
<p class="form-submit"></p><div class="col col-xs-12 submit-btn-comment"><input name="submit" type="submit" id="submit" class="submit" value="Submit"></div> <input type="hidden" name="comment_post_ID" value="104" id="comment_post_ID">
<input type="hidden" name="comment_parent" id="comment_parent" value="0">
<p></p>         </form>
            </div><!-- #respond -->
        

</div><!-- #comments -->
</div>

        <?php } else {

            $helper = new thepack_helper_theme();
            $post_data = $helper->thepack_get_demo_post_data();
            global $post;
            $post = $post_data;
            setup_postdata($post);
            comments_template();
            wp_reset_postdata();

        }        


    }
}

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new thepack_post_comment() );