<?php

namespace thepack_themebuilderr;

use Elementor;
use Elementor\Plugin;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use WP_Query;

class thepack_post_content extends Widget_Base{
    public function get_name() {
        return 'th-post-content';
    }

    public function get_title() {
        return   esc_html__( 'CONTENT', 'thepack' );
    }

    public function get_icon() {
        return 'eicon-align-left';
    }

    public function get_categories() {
        return [ 'ae-template-elements' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_general_style',
            [
                'label' =>   esc_html__( 'General', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'preview',
            [
                'label' =>   esc_html__('Preview Post', 'thepack'),
                'type' => Controls_Manager::SELECT2,
                'options' =>  thepack_footer_select('post','10'), 
                'multiple' => false,
                'label_block' => true 
            ]
        );

        $this->add_control(
            'color',
            [
                'label' =>   esc_html__( 'Content Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .content-builder' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'content_align',
            [
                'label' =>   esc_html__( 'Content Align', 'thepack' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__( 'Left', 'thepack' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__( 'Center', 'thepack' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__( 'Right', 'thepack' ),
                        'icon' => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' =>   esc_html__('Justified', 'thepack'),
                        'icon' => 'fa fa-align-justify',
                    ],                    
                ],
                'default' => 'left',
                'selectors' => [
                    '{{WRAPPER}} .content-builder' => 'text-align: {{VALUE}};',
                ],
            ]
        );
 
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
                'selector' => '{{WRAPPER}} .content-builder',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_heading',
            [
                'label' =>   esc_html__( 'Heading', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'h1',
            [
                'label' =>   esc_html__( 'H1', 'thepack' ),
                'type' => Controls_Manager::RAW_HTML,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'h1ty',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
                'selector' => '{{WRAPPER}} h1',
            ]
        );

        $this->add_responsive_control(
            'h1-m',
            [
                'label' =>   esc_html__('Margin', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors' => [
                    '{{WRAPPER}} h1' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );


        $this->add_control(
            'h2',
            [
                'label' =>   esc_html__( 'H2', 'thepack' ),
                'type' => Controls_Manager::RAW_HTML,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'h2ty',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
                'selector' => '{{WRAPPER}} h2',
            ]
        );

        $this->add_responsive_control(
            'h2-m',
            [
                'label' =>   esc_html__('Margin', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors' => [
                    '{{WRAPPER}} h2' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );


        $this->add_control(
            'h3',
            [
                'label' =>   esc_html__( 'H3', 'thepack' ),
                'type' => Controls_Manager::RAW_HTML,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'h3ty',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
                'selector' => '{{WRAPPER}} h3',
            ]
        );

        $this->add_responsive_control(
            'h3-m',
            [
                'label' =>   esc_html__('Margin', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors' => [
                    '{{WRAPPER}} h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );


        $this->add_control(
            'h4',
            [
                'label' =>   esc_html__( 'H4', 'thepack' ),
                'type' => Controls_Manager::RAW_HTML,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'h4ty',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
                'selector' => '{{WRAPPER}} h4',
            ]
        );

        $this->add_responsive_control(
            'h4-m',
            [
                'label' =>   esc_html__('Margin', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors' => [
                    '{{WRAPPER}} h4' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );


        $this->add_control(
            'h5',
            [
                'label' =>   esc_html__( 'H5', 'thepack' ),
                'type' => Controls_Manager::RAW_HTML,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'h5ty',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
                'selector' => '{{WRAPPER}} h5',
            ]
        );

        $this->add_responsive_control(
            'h5-m',
            [
                'label' =>   esc_html__('Margin', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors' => [
                    '{{WRAPPER}} h5' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );

        $this->add_control(
            'h6',
            [
                'label' =>   esc_html__( 'H6', 'thepack' ),
                'type' => Controls_Manager::RAW_HTML,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'h6ty',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
                'selector' => '{{WRAPPER}} h6',
            ]
        );

        $this->add_responsive_control(
            'h6-m',
            [
                'label' =>   esc_html__('Margin', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors' => [
                    '{{WRAPPER}} h6' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );

        $this->end_controls_section();

    }

    protected function render( ) {
        $settings = $this->get_settings();
        $helper = new thepack_helper_theme();
        $post_data = $helper->thepack_get_demo_post_data();
        $post_content = wpautop($post_data->post_content);
        
        echo '<div class="content-builder">';
        if (Plugin::instance()->editor->is_edit_mode()){

            $args = array(
              'p'         => $settings['preview'], // ID of a page, post, or custom type
              'post_type' => 'post',
              'posts_per_page' => 1,
            );
            $loop = new WP_Query($args);     

            if ($loop->have_posts()) : ?>
                    <?php while ($loop->have_posts()) : $loop->the_post(); ?>
                    <?php the_content();?>
                    <?php endwhile; ?>

                    <?php wp_reset_postdata(); ?>
                    
            <?php endif;

        } else {
            echo do_shortcode($post_content);
        }
        echo '</div>';
    }
}

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new thepack_post_content() );