<?php

namespace thepack_themebuilderr;
use Elementor;
use Elementor\Plugin;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Scheme_Typography;



class thepack_themebuilder_postmeta extends Widget_Base{
    public function get_name() {
        return 'th-postmeta';
    }

    public function get_title() {
        return   esc_html__( 'POSTMETA', 'thepack' );
    }

    public function get_icon() {
        return 'eicon-type-tool';
    }

    public function get_categories() {
        return [ 'ae-template-elements' ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_title',
            [
                'label' =>   esc_html__( 'Post Meta', 'thepack' ),
            ]
        );
        $helper = new thepack_helper_theme();
        $this->add_control(
            'metas',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name' => 'meta',
                        'type' => Controls_Manager::SELECT2,
                        'label' =>   esc_html__('Post meta', 'thepack'),
                        'default' => '',
                        'options' =>  thepack_metaa_fields(),
                        'multiple' => false,
                        'label_block' => true                                   
                    ],

                ],
                'title_field' => '{{{ meta }}}',                
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label' =>   esc_html__('Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ],
                ],                
                'selectors' => [
                    '{{WRAPPER}} .meta-wrap' => 'text-align: {{VALUE}};',
                ], 
                                
            ]
        ); 

        $this->end_controls_section();

        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__('Title', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typ',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
                'selector' => '{{WRAPPER}} .post-title-builder',
            ]
        );

        $this->add_control(
            'titlemargins',
            [
                'label' =>   esc_html__('Margin', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .post-title-builder' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'titlecolor',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .post-title-builder' => 'color: {{VALUE}};'
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_links',
            [
                'label' =>   esc_html__('Linked meta', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'link_typo',
                'selector' => '{{WRAPPER}} .leffect-1 a',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
            ]
        );


        $this->add_control(
            'link-color',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .leffect-1 a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'link-color-h',
            [
                'label' =>   esc_html__( 'Hover Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .leffect-1 a:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_nlinks',
            [
                'label' =>   esc_html__('Other meta', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'nlink_typo',
                'selector' => '{{WRAPPER}} .leffect-1',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
            ]
        );


        $this->add_control(
            'nlink-color',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .leffect-1' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_catbg',
            [
                'label' =>   esc_html__('Category background', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $this->add_control(
            'catbgbg',
            [
                'label' =>   esc_html__( 'Background', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cat-bg' => 'background: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'catbgcol',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cat-bg' => 'color: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'catbgpaddings',
            [
                'label' =>   esc_html__('Padding', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .cat-bg' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'catbgmargins',
            [
                'label' =>   esc_html__('Margin', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .cat-bg' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'catbg_typ',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
                'selector' => '{{WRAPPER}} .cat-bg',
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'section_tag',
            [
                'label' =>   esc_html__('Tag', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $this->add_control(
            'tblock',
            [
                'label' =>   esc_html__( 'Display block', 'thepack' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__( 'Yes', 'thepack' ),
                'label_off' =>   esc_html__( 'No', 'thepack' ),
                'selectors' => [
                    '{{WRAPPER}} .tags-links' => 'display:block;',
                ],                
            ]
        );


        $this->add_control(
            'tagpaddings',
            [
                'label' =>   esc_html__('Padding', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .tags-links span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'tagmargins',
            [
                'label' =>   esc_html__('Margin', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .tags-links span' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'tag_typ',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
                'selector' => '{{WRAPPER}} .tags-links span',
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'tag_border',
                'label' =>   esc_html__( 'Border', 'thepack' ),
                'selector' => '{{WRAPPER}} .tags-links span',
            ]
        );
        $this->add_control(
            'tag-bradius',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .tags-links span' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );                      
        $this->add_control(
            'tagbg',
            [
                'label' =>   esc_html__( 'Tag background', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tags-links span' => 'background: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'tagtxt',
            [
                'label' =>   esc_html__( 'Tag color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tags-links a' => 'color: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'tagbgh',
            [
                'label' =>   esc_html__( 'Tag background hover', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tags-links span:hover' => 'background: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'tagtxth',
            [
                'label' =>   esc_html__( 'Tag color hover', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tags-links span:hover a' => 'color: {{VALUE}};'
                ],
            ]
        );


        $this->end_controls_section();
    }

    protected function render( ) {
        $helper = new thepack_helper_theme();
        $preview = new thepack_backend_meta_preview();
        $settings = $this->get_settings();
        $post_data = $helper->thepack_get_demo_post_data();
        $meta = $helper->thepack_buildermeta_to_string($settings['metas']);

        if (Plugin::instance()->editor->is_edit_mode()){ 
            echo $preview->thepack_backendmetapreview($meta,$excerpt);
        } else {
            thepack_build_postmeta($meta,$excerpt);
        }
        


    }
}

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new thepack_themebuilder_postmeta() );