<?php

namespace thepack_themebuilderr;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Scheme_Typography;

class thepack_pst_nav extends Widget_Base{
    public function get_name() {
        return 'tb-postnav';
    }

    public function get_title() {
        return   esc_html__('POST NAV', 'thepack' );
    }

    public function get_icon() {
        return 'eicon-navigation-horizontal';
    }

    public function get_categories() {
        return [ 'ae-template-elements' ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__( 'General', 'thepack' ),
            ]
        );

        $this->add_control(
            'tmpl',
            [
                'label' =>   esc_html__( 'Template', 'thepack' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'one' => [
                        'title' =>   esc_html__( 'One', 'thepack' ),
                        'icon' => 'fa fa-folder',
                    ],
                    'two' => [
                        'title' =>   esc_html__( 'Two', 'thepack' ),
                        'icon' => 'fa fa-folder-o',
                    ]
                ],
                'default' => 'one'
            ]
        );

        $this->add_control(
            'ptxt',
            [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Previous Text', 'thepack'),
                'label_block' => true,
                'condition' => [
                    'tmpl' => 'two',
                ],                
            ]
        );

        $this->add_control(
            'ntxt',
            [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Next Text', 'thepack'),
                'label_block' => true,
                'condition' => [
                    'tmpl' => 'two',
                ],                
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section-st1',
            [
                'label' =>   esc_html__( 'Settings', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'tmpl' => 'one',
                ],                 
            ]
        );

        $this->add_control(
            'border_color',
            [
                'label' =>   esc_html__('Border color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .postnav-wrap.one' => 'border-top:1px solid {{VALUE}};border-bottom:1px solid {{VALUE}};',
                    '{{WRAPPER}} .postnav-wrap.one .fw-col-sm-6:first-child' => 'border-right:1px solid {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'link',
                'label' =>   esc_html__( 'Typo', 'thepack' ),
                'selector' => '{{WRAPPER}} .link',
            ]
        );

        $this->add_control(
            'link_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .link' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'link_colorh',
            [
                'label' =>   esc_html__('Hover Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .link:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section-st2',
            [
                'label' =>   esc_html__( 'Settings', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'tmpl' => 'two',
                ],                 
            ]
        );

        $this->add_responsive_control(
            '2mwid',
            [
                'label' =>   esc_html__( 'Width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px','%' ],
                'selectors' => [
                    '{{WRAPPER}} .xl-flex-col' => 'max-width: {{SIZE}}{{UNIT}};',
                ], 
            ]
        );

        $this->add_responsive_control(
            '2itpad',
            [
                'label' =>   esc_html__( 'Item padding', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px','%' ],
                'selectors' => [
                    '{{WRAPPER}} .xl-flex-col' => 'padding: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .xl-flex-row' => 'margin:0px -{{SIZE}}{{UNIT}};',
                ], 
            ]
        );

        $this->add_control(
          '2padi',
          [
             'label' =>   esc_html__( 'Padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             //'allowed_dimensions' => array('top','bottom'),
             'selectors' => [
                    '{{WRAPPER}} .prev-post,{{WRAPPER}} .next-post' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => '2typo',
                'label' =>   esc_html__( 'Typo', 'thepack' ),
                'selector' => '{{WRAPPER}} .postnav-wrap',
            ]
        );

        $this->add_control(
            '2clr',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .prev-post,{{WRAPPER}} .next-post' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
          'm1',
          [
             'type'    => Controls_Manager::RAW_HTML,
             'raw' =>   esc_html__( '<b>Background</b>', 'thepack' ),
          ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => '2bgs',
                'label' =>   esc_html__( 'Background', 'thepack' ),
                'types' => [ 'none', 'classic','gradient' ],
                'selector' => '{{WRAPPER}} .prev-post,{{WRAPPER}} .next-post',
            ]
        );

        $this->end_controls_section();
    }

    protected function render( ) {
        $settings = $this->get_settings();
        require dirname(__FILE__) .'/'. $settings['tmpl'] .'.php';
    }
}

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new thepack_pst_nav() );