<?php

namespace thepack_themebuilderr;
use Elementor\Plugin; 
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;

class thepack_builder_post_thumb extends Widget_Base{
    public function get_name() {
        return 'th-thumbnail';
    }

    public function get_title() {
        return   esc_html__( 'THUMBNAIL', 'thepack' );
    }

    public function get_icon() {
        return 'eicon-image-box';
    }

    public function get_categories() {
        return [ 'ae-template-elements' ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_layout_settings',
            [
                'label' =>   esc_html__( 'Layout Settings', 'thepack' )
            ]
        );
        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'image',
                'exclude' => [ 'custom' ],
            ]
        );

        $this->add_responsive_control(
            'image_align',
            [
                'label' =>   esc_html__( 'Image Alignment', 'thepack' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__( 'Left', 'thepack' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__( 'Center', 'thepack' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__( 'Right', 'thepack' ),
                        'icon' => 'fa fa-align-right',
                    ]
                ],
                'default' => 'left',
                'selectors' => [
                    '{{WRAPPER}}' => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'links_to',
            [
                'type' => Controls_Manager::SELECT,
                'label' =>   esc_html__('Link to', 'thepack'),
                'options' => [
                    ''  =>   esc_html__('None', 'thepack'),
                    'post' =>   esc_html__('Post', 'thepack'),
                    'media' =>   esc_html__('Full Image', 'thepack')
                ],
                'default' => 'post'
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section-general-style',
            [
                'label' =>   esc_html__( 'General', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_control(
            'img_w',
            [
                'label' =>   esc_html__( 'Image Width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ]
                ],
                'size_units' => ['px','%'],
                'selectors' => [
                    '{{WRAPPER}} .ae_thumb_wrapper img' => 'width: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->end_controls_section();
    }

    protected function render( ) {
        $settings = $this->get_settings();
        $helper = new thepack_helper_theme();
        $post_data = $helper->thepack_get_demo_post_data();
        $post_id = $post_data->ID;

        $post_image_size = $settings['image_size'];
        $post_image = get_the_post_thumbnail( $post_id, $post_image_size );
        $post_title = $post_data->post_title;

        if(!isset($settings['links_to']) || $settings['links_to'] == 'post'){
            $post_link = get_permalink($post_id );
        }elseif($settings['links_to'] == 'media'){
            $media_link = wp_get_attachment_image_src(get_post_thumbnail_id($post_id),'full');
            $post_link = $media_link[0];

        }

        if (Plugin::instance()->editor->is_edit_mode()){
            echo '<div class="ae_thumb_wrapper">';
            $thumb = THEPACK_TH_URL . 'includes/admin/demoimg.jpg';
            echo '</div>';
            ?>
            <img src="<?php echo esc_attr($thumb);?>">
        <?php } else {?>

            <div class="ae_thumb_wrapper">
                <?php if(!isset($settings['links_to']) || $settings['links_to'] != ''){ ?>
                    <a href="<?php echo esc_attr($post_link); ?>" title="<?php echo esc_attr($post_title);?>">
                <?php } ?>
                        <?php echo $post_image;?>

                <?php if(!isset($settings['links_to']) || $settings['links_to'] != ''){ ?>
                    </a>
                <?php } ?>
            </div>


        <?php }

    }
}

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new thepack_builder_post_thumb() );