<?php

namespace thepack_themebuilderr;

use Elementor;
use Elementor\Plugin;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;


class thepack_pst_share extends Widget_Base{
    public function get_name() {
        return 'tb_pshar';
    }

    public function get_title() {
        return   esc_html__( 'POST SHARE', 'thepack' );
    }

    public function get_icon() {
        return 'eicon-align-left';
    }

    public function get_categories() {
        return [ 'ae-template-elements' ];
    }

    protected function _register_controls() {



        $this->start_controls_section(
            'section_cntnt',
            [
                'label' =>   esc_html__('Content', 'thepack'),
            ]
        );

        $this->add_control(
            'tmpl',
            [
                'label' =>   esc_html__('Template', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'style_1' => [
                        'title' =>   esc_html__('One', 'thepack'),
                        'icon' => 'fa fa-folder',
                    ],
                    'style_2' => [
                        'title' =>   esc_html__('Two', 'thepack'),
                        'icon' => 'fa fa-folder-o',
                    ]

                ], 
                'default' => 'style_1',               
            ]
        );
        
         $this->add_control(
            'fbt', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Facebook share text', 'thepack'),
                'label_block' => true,
                'default' => 'Share on facebook',               
            ]
        );

         $this->add_control(
            'twt', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Twitter share text', 'thepack'),
                'label_block' => true,
                'default' => 'Share on twitter',               
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_gnrl',
            [
                'label' =>   esc_html__( 'General', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'flthm',
            [
                'label' =>   esc_html__('Use flat theme', 'thepack'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' =>   esc_html__('Yes', 'thepack'),
                'label_off' =>   esc_html__('No', 'thepack'),
                'return_value' => 'flathym',
                'default' => 'no',                
            ]
        );

        $this->add_control(
            'tclr',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xld_share_post a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
                'selector' => '{{WRAPPER}} .xld_share_post span',
            ]
        );

        $this->add_control(
            'bor-rad',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 150,
                        'step' => 1,
                    ]
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .xld_share_post a' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->add_control(
            'tbgclr',
            [
                'label' =>   esc_html__( 'Background color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xld_share_post a' => 'background: {{VALUE}};',
                ],
                'condition' => [
                    'flthm!' => 'flathym',
                ],                
            ]
        );

        $this->add_control(
            'tbghclr',
            [
                'label' =>   esc_html__( 'Hover background color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xld_share_post a:hover' => 'background: {{VALUE}};',
                ],
                'condition' => [
                    'flthm!' => 'flathym',
                ],                
            ]
        );

        $this->add_control(
            'thclr',
            [
                'label' =>   esc_html__( 'Hover color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xld_share_post a:hover' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'flthm!' => 'flathym',
                ],                
            ]
        );

        $this->add_control(
            'bdrclr',
            [
                'label' =>   esc_html__( 'Border color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xld_share_post a' => 'border-color: {{VALUE}};',
                ],
                'condition' => [
                    'flthm!' => 'flathym',
                ],                
            ]
        );

        $this->add_control(
            'bdrwd',
            [
                'label' =>   esc_html__( 'Border width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .xld_share_post a' => 'border-width: {{SIZE}}px;border-style:solid;',
                ],
                'condition' => [
                    'flthm!' => 'flathym',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render( ) { 
        $settings = $this->get_settings();
        require dirname(__FILE__) .'/'. $settings['tmpl'] .'.php';

    }
}

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new thepack_pst_share() );