<?php

namespace thepack_themebuilderr;
use Elementor\Plugin;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

class thepack_recent_post extends Widget_Base{
    public function get_name() {
        return 'aerecentpost';
    }

    public function get_title() {
        return   esc_html__( 'RECENT POST', 'thepack' );
    }

    public function get_icon() {
        return 'eicon-image-box';
    }

    public function get_categories() {
        return [ 'ae-template-elements' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_posts_carousel',
            [
                'label' =>   esc_html__('Query', 'thepack'),
            ]
        );

        $this->add_control(
            'query_type',
            [
                'label' =>   esc_html__('Query type', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'default' => 'icon',
                'options' => [
                    'category' =>   esc_html__('Category', 'thepack'),
                    'individual' =>   esc_html__('Individual', 'thepack'),
                ],                
            ]
        );

        $this->add_control(
            'cat_query',
            [
                'label' =>   esc_html__('Category', 'thepack'),
                'type' => Controls_Manager::SELECT2,
                'options' => thepack_drop_cat('category'),
                'multiple' => true,
                'label_block' => true,
                'condition' => [
                    'query_type' => 'category',
                ],                
            ]           
        );

        $this->add_control(
            'id_query',
            [
                'label' =>   esc_html__('Posts', 'thepack'),
                'type' => Controls_Manager::SELECT2,
                'options' => thepack_drop_posts('post'),
                'multiple' => true,
                'label_block' => true,
                'condition' => [
                    'query_type' => 'individual',
                ],                
            ]           
        );

        $this->add_control(
            'posts',
            [
                'label' =>   esc_html__('Posts Per Page', 'thepack'),
                'type' => Controls_Manager::SLIDER,
            ]
        );

        $this->add_control(
            'show_img',
            [
                'label' =>   esc_html__( 'Featured image', 'thepack' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => '',
                'label_on' =>   esc_html__( 'Show', 'thepack' ),
                'label_off' =>   esc_html__( 'Hide', 'thepack' ),
                'return_value' => 'yes',
            ]
        );

        $this->add_control(
            'img_size',
            [
                'label' =>   esc_html__('Image size', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' =>  thepack_image_size_choose(), 
                'multiple' => false,  
                'condition' => [
                    'show_img' => 'yes',
                ],                                              
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'section-general-style',
            [
                'label' =>   esc_html__( 'General', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_control(
            'botmargin',
            [
                'label' =>   esc_html__( 'Margin-top', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .tbrcntwid > .item + .item' => 'margin-top: {{SIZE}}{{UNIT}};padding-top: {{SIZE}}{{UNIT}}',
                ],

            ]
        );

        $this->add_control(
            'bor_col',
            [
                'label' =>   esc_html__( 'Border color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbrcntwid > .item + .item' => 'border-top: 1px solid {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_title',
            [
                'label' =>   esc_html__('Post title', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
          'hmargin',
          [
             'label' =>   esc_html__( 'Title margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px', '%', 'em' ],
             'allowed_dimensions' => array('top','bottom'),
             'selectors' => [
                    '{{WRAPPER}} .post-title-builder' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'heading_typography',
                'selector' => '{{WRAPPER}} .post-title-builder',
                'label' =>   esc_html__( 'Typo', 'thepack' ),
            ]
        );

        $this->add_control(
            'tcol',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .post-title-builder a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'tcolh',
            [
                'label' =>   esc_html__( 'Hover color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .post-title-builder:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );


        $this->end_controls_section();


        $this->start_controls_section(
            'section_meta',
            [
                'label' =>   esc_html__('Meta', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'meta_typo',
                'selector' => '{{WRAPPER}} .leffect-1',
                'label' =>   esc_html__( 'Typo', 'thepack' ),
            ]
        );

        $this->add_control(
            'metacolor',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .leffect-1' => 'color: {{VALUE}};',
                ],
            ]
        );


        $this->end_controls_section();

    }

    protected function render( ) {
        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';
    }
}

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new thepack_recent_post() );