<?php

namespace thepack_themebuilderr;

use Elementor;
use Elementor\Plugin;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use WP_Query;

class thepack_theme_related_post  extends Widget_Base{
    public function get_name() {
        return 'th-related';
    } 

    public function get_title() {
        return   esc_html__( 'RELATED POSTS', 'thepack' );
    }

    public function get_icon() {
        return 'fa fa-snowflake-o';
    }

    public function get_categories() {
        return [ 'xl-theme-builder' ];
    } 

    protected function _register_controls() {

        $this->start_controls_section(
            'section_heading',
            [
                'label' =>   esc_html__('Query', 'thepack'),
            ]
        );

        $this->add_control(
            'label',
            [
                'label' =>   esc_html__('Heading title', 'thepack'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Related Post',                                              
            ]
        );

        $this->add_control(
            'f_m',
            [
                'label' =>   esc_html__( 'Post meta', 'thepack' ),
                'type' => Controls_Manager::RAW_HTML,
            ]
        );

        $this->add_control(
            'metas',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name' => 'meta',
                        'type' => Controls_Manager::SELECT2,
                        'label' =>   esc_html__('Post meta', 'thepack'),
                        'default' => '',
                        'options' =>  thepack_metaa_fields(),  
                        'multiple' => false,
                        'label_block' => true                                   
                    ],

                ],
                'title_field' => '{{{ meta }}}',
            ]
        );
        
        $this->add_control(
            'post_perpage',
            [
                'label' =>   esc_html__('Post per page', 'thepack'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 20,
                    ],
                ],                
            ]
        );

        $this->add_control(
            'column',
            [
                'label' =>   esc_html__('Column', 'thepack'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 5,
                    ],
                ],                
            ]
        );

        $this->add_control(
            'img_size',
            [
                'label' =>   esc_html__('Image size', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' =>  thepack_image_size_choose(), 
                'multiple' => false,                                              
            ]
        );

        $this->add_control(
            'excerpt_l',
            [
                'label' =>   esc_html__( 'Excerpt length', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                        'step' => 1,
                    ],
                ],
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'section_general',
            [
                'label' =>   esc_html__('General', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'lr_pad',
            [
                'label' =>   esc_html__( 'Item padding- left and right', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .grid' => 'padding:0px {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .blog-grids' => 'margin:0px -{{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_title',
            [
                'label' =>   esc_html__('Post title', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .entry_title a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'title_colorh',
            [
                'label' =>   esc_html__( 'Hover Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .entry_title:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'title_margin',
            [
                'label' =>   esc_html__('Margin', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .entry_title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .entry_title',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_excerpt',
            [
                'label' =>   esc_html__('Excerpt', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'excerpt_pad',
            [
                'label' =>   esc_html__('Padding', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .entry_excerpt' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );

        $this->add_control(
            'excerpt_color',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .entry_excerpt' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'excerpt_typography',
                'selector' => '{{WRAPPER}} .entry_excerpt',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_bgcat',
            [
                'label' =>   esc_html__('Background Category', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'catbg_typo',
                'selector' => '{{WRAPPER}} .cat-bg',
                'label' =>   esc_html__( 'Typo', 'thepack' ),
            ]
        );
        
        $this->add_control(
            'catbg-col',
            [
                'label' =>   esc_html__( 'Background', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cat-bg' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'catbg-colo',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cat-bg' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
          'catbg-pad',
          [
             'label' =>   esc_html__( 'Padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px', '%', 'em' ],
             'selectors' => [
                    '{{WRAPPER}} .cat-bg' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_meta',
            [
                'label' =>   esc_html__('Post meta', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,                 
            ]
        );

        $this->add_control(
            'metaf_color',
            [
                'label' =>   esc_html__( 'Meta color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .leffect-1' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'metaf_colorl',
            [
                'label' =>   esc_html__( 'Meta link color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .leffect-1 a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'metaf_colorlh',
            [
                'label' =>   esc_html__( 'Meta link hover color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .leffect-1 a:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'metaf_typography',
                'label' =>   esc_html__('Meta typography', 'thepack'),
                'selector' => '{{WRAPPER}} .leffect-1',
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'section_slider_set',
            [
                'label' =>   esc_html__('Carousel Customiser', 'thepack'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'dot-pos',
            [
                'label' =>   esc_html__('Dot position', 'thepack'),
                'type' => Controls_Manager::NUMBER,    
                'selectors' => [
                    '{{WRAPPER}} .slick-dots' => 'bottom: {{VALUE}}px;',
                ],                            
            ]
        );

        $this->add_control(
            'dotprihacti',
            [
                'label' =>   esc_html__('Active background color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-dots li button' => 'background:{{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
    }

    protected function render( ) {
        $settings = $this->get_settings();
        require dirname(__FILE__) .'/style_two.php';
    }
}

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new thepack_theme_related_post () );