<?php

namespace thepack_themebuilderr;

use Elementor;
use Elementor\Plugin;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use WP_Query;

class thepack_post_taxolist extends Widget_Base{
    public function get_name() {
        return 'th-post-taxo';
    }

    public function get_title() {
        return   esc_html__( 'TAXONOMY', 'thepack' );
    }

    public function get_icon() {
        return 'eicon-align-left';
    }

    public function get_categories() {
        return [ 'ae-template-elements' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_info',
            [
                'label' =>   esc_html__('Taxonomy', 'thepack'),
            ]
        );

        $this->add_control(
            'style',
            [
                'label' =>   esc_html__('Show as', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'list' => [
                        'title' =>   esc_html__('List', 'thepack'),
                        'icon' => 'eicon-editor-list-ul',
                    ],
                    'full' => [
                        'title' =>   esc_html__('Full width', 'thepack'),
                        'icon' => 'eicon-slider-push',
                    ],
                ],
                'default' => 'list',               
            ]
        );

        $helper = new thepack_helper_theme();
        $this->add_control(
            'taxonomy',
            [
                'label' =>   esc_html__('Taxonomy', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'options' =>  $helper->thepaack_drop_taxolist(), 
                'multiple' => false,
                'label_block' => true,               
            ]
        );

          $this->add_control(
            'show_count',
            [
                'label' =>   esc_html__( 'Hide count', 'thepack' ),
                'type' => Controls_Manager::SWITCHER,
                'selectors' => [
                    '{{WRAPPER}} .aetaxo span' => 'display: none;',
                ],                
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'section_general_style',
            [
                'label' =>   esc_html__( 'General', 'thepack' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
                'selector' => '{{WRAPPER}} .aetaxo li',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'number_typography',
                'label' =>   esc_html__( 'Number Typography', 'thepack' ),
                'selector' => '{{WRAPPER}} .aetaxo span',
            ]
        );

        $this->add_control(
            'li_margin',
            [
                'label' =>   esc_html__('List padding', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px','em'],
                'selectors' => [
                    '{{WRAPPER}} .aetaxo li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'li_pad',
            [
                'label' =>   esc_html__('List link padding', 'thepack'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px','em'],
                'selectors' => [
                    '{{WRAPPER}} .aetaxo a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'bg_color',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .aetaxo li' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'txt_color',
            [
                'label' =>   esc_html__('Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .aetaxo a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'num_color',
            [
                'label' =>   esc_html__('Number Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .aetaxo li span' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'border_color',
            [
                'label' =>   esc_html__('Border Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .aetaxo li:not(:last-child) a' => 'border-bottom:1px solid {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'border_colorer',
            [
                'label' =>   esc_html__('Border Hover Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .aetaxo li a:hover' => 'border:1px solid {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'hbg_color',
            [
                'label' =>   esc_html__('Hover Background', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .aetaxo li:hover a' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'htxt_color',
            [
                'label' =>   esc_html__('Hover Color', 'thepack'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .aetaxo li:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'border_color',
            [
                'label' =>   esc_html__( 'Border color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .aetaxo li a' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'border-width',
            [
                'label' =>   esc_html__( 'Border width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .aetaxo li a' => 'border-width: {{SIZE}}{{UNIT}};border-style:solid;',
                ],

            ]
        ); 


        $this->add_control(
            'border-radius',
            [
                'label' =>   esc_html__( 'Border radius', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    
                ],
                'size_units' => [ 'px'],
                'selectors' => [
                    '{{WRAPPER}} .aetaxo li' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->end_controls_section();
    }

    protected function render( ) {
        $settings = $this->get_settings();
        require dirname(__FILE__) .'/view.php';
    }
}

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new thepack_post_taxolist() );