<?php
namespace thepack_themebuilderr;
use Elementor;
use Elementor\Plugin;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Image_Size;
use WP_Query;

class thepack_post_background extends Widget_Base{
    public function get_name() {
        return 'post-bg';
    }

    public function get_title() {
        return   esc_html__( 'BACKGROUND', 'thepack' );
    }

    public function get_icon() {
        return 'eicon-align-left';
    }

    public function get_categories() {
        return [ 'ae-template-elements' ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_layout_settings',
            [
                'label' =>   esc_html__( 'Background', 'thepack' )
            ]
        );

        $this->add_control(
          'style',
          [
             'label'       =>   esc_html__( 'Style', 'thepack' ),
             'type' => Controls_Manager::SELECT,
             'label_block' => true,
             'options' => [
                'no-overlay'  =>   esc_html__( 'Only Background', 'thepack' ),
                'overlay-meta' =>   esc_html__( 'Post meta overlay', 'thepack' ),
             ],
          ]
        );

        $helper = new thepack_helper_theme();
        $this->add_control(
            'metas',
            [
                'type' => Controls_Manager::REPEATER,
                'prevent_empty' => false,
                'fields' => [
                    [
                        'name' => 'meta',
                        'type' => Controls_Manager::SELECT2,
                        'label' =>   esc_html__('Post meta', 'thepack'),
                        'default' => '',
                        'options' =>  $helper->thepack_get_metas(),
                        'multiple' => false,
                        'label_block' => true                                   
                    ],

                ],
                'title_field' => '{{{ meta }}}',
                'condition' => [
                    'style' => 'overlay-meta',
                ],                 
            ]
        );

        $this->add_control(
            'img_size',
            [
                'label' =>   esc_html__('Image size', 'thepack'),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' =>  $helper->thepack_image_size_choose(), 
                'multiple' => false,                                
            ]
        );        
 
        $this->end_controls_section();

        $this->start_controls_section(
            'section_spacing',
            [
                'label' =>   esc_html__('Background', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $this->add_control(
            'max-wid',
            [
                'label' =>   esc_html__( 'Max wrapper width', 'thepack' ),
                'type' =>  Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 300,
                        'max' => 1400,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .overlaymeta' => 'max-width: {{SIZE}}{{UNIT}}',
                ],
                'condition' => [
                    'style' => 'overlay-meta',
                ],
            ]
        );        

        $this->add_responsive_control(
          'pad',
          [
             'label' =>   esc_html__( 'Padding', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px', '%', 'em' ],
             'selectors' => [
                    '{{WRAPPER}} .bgpostthumb' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );        

        $this->add_control(
            'align',
            [
                'label' =>   esc_html__('Alignment', 'thepack'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' =>   esc_html__('Left', 'thepack'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' =>   esc_html__('Center', 'thepack'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' =>   esc_html__('Right', 'thepack'),
                        'icon' => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' =>   esc_html__('Justified', 'thepack'),
                        'icon' => 'fa fa-align-justify',
                    ],
                ],
                'default' => 'center',
                'selectors' => [
                    '{{WRAPPER}} .overlaymeta' => 'text-align: {{VALUE}};',
                ], 
                                
            ]
        );

        $this->add_control(
          'background-size',
          [
             'label'       =>   esc_html__( 'Background size', 'thepack' ),
             'type' => Controls_Manager::SELECT,
             'options' => [
                'inherit'  =>   esc_html__( 'Inherit', 'thepack' ),
                'contain' =>   esc_html__( 'Contain', 'thepack' ),
                'cover' =>   esc_html__( 'Cover', 'thepack' ),
             ],
             'selectors' => [
                '{{WRAPPER}} .bgpostthumb' => 'background-size: {{VALUE}}',
             ],
          ]
        );

        $this->add_control(
          'background-attach',
          [
             'label'       =>   esc_html__( 'Background attachment', 'thepack' ),
             'type' => Controls_Manager::SELECT,
             'options' => [
                'inherit'  =>   esc_html__( 'Inherit', 'thepack' ),
                'fixed' =>   esc_html__( 'Fixed', 'thepack' ),
             ],
             'selectors' => [
                '{{WRAPPER}} .bgpostthumb' => 'background-attachment: {{VALUE}}',
             ],
          ]
        );

        $this->add_control(
          'background-position',
          [
             'label'       =>   esc_html__( 'Background position', 'thepack' ),
             'type' => Controls_Manager::SELECT,
             'options' => [
                'inherit'  =>   esc_html__( 'Inherit', 'thepack' ),
                'center top' =>   esc_html__( 'Center top', 'thepack' ),
                'center center' =>   esc_html__( 'Center center', 'thepack' ),
                'left center' =>   esc_html__( 'Left center', 'thepack' ),
                'right center' =>   esc_html__( 'Right center', 'thepack' ),                
             ],
             'selectors' => [
                '{{WRAPPER}} .bgpostthumb' => 'background-position: {{VALUE}}',
             ],
          ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'overlay_color',
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'types' => [ 'none', 'classic','gradient' ],
                'selector' => '{{WRAPPER}} .bgpostthumb::before',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_title',
            [
                'label' =>   esc_html__('Post title', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typo',
                'selector' => '{{WRAPPER}} .post-title-builder',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
            ]
        );

        $this->add_control(
          'title-margin',
          [
             'label' =>   esc_html__( 'Margin', 'thepack' ),
             'type' => Controls_Manager::DIMENSIONS,
             'size_units' => [ 'px','em'],
             'selectors' => [
                    '{{WRAPPER}} .post-title-builder' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             ],
          ]
        );

        $this->add_control(
            'title-color',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .post-title-builder' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'section_links',
            [
                'label' =>   esc_html__('Linked meta', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'link_typo',
                'selector' => '{{WRAPPER}} .leffect-1 a',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
            ]
        );


        $this->add_control(
            'link-color',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .leffect-1 a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'link-color-h',
            [
                'label' =>   esc_html__( 'Hover Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .leffect-1 a:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_nlinks',
            [
                'label' =>   esc_html__('Other meta', 'thepack'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'nlink_typo',
                'selector' => '{{WRAPPER}} .leffect-1',
                'label' =>   esc_html__( 'Typography', 'thepack' ),
            ]
        );


        $this->add_control(
            'nlink-color',
            [
                'label' =>   esc_html__( 'Color', 'thepack' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .leffect-1' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render( ) {
        $settings = $this->get_settings();
        require dirname(__FILE__) .'/'. $settings['style'] .'.php';
    }
}

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new thepack_post_background() ); 