<?php

namespace thepack_themebuilderr;

use Elementor;
use Elementor\Plugin;
use WP_Query;
use Elementor\Group_Control_Border;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Box_Shadow;


class thepack_themebuilder_frontend{

    private static $_instance = null;

    public static function instance() {
        if ( is_null( self::$_instance ) ) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }

    private function __construct() {

        add_filter('thepack_themebuilder_single_data', [ $this, 'thepack_apply_ae_single_post_template'],10,1);
        add_action('template_redirect', [ $this, 'thepack_ae_template_hook']);
        add_action('thepack_themebuilder_404', [$this, 'thepack_apply_404_template']);
        add_action('thepack_search_builder', [$this, 'thepack_search_builder']);
        add_action('thepack_author_builder', [$this, 'thepack_author_builder']);
        add_action('thepack_archive_builder', [$this, 'thepack_archive_builder']);
    }


    public function thepack_render_insert_tmpl($template_id,$with_css = false){
        if(!isset($template_id) || empty($template_id)){
            return '';
        }

        $post_id = $template_id;
        $edit_mode = get_post_meta($post_id,'_elementor_edit_mode','');

        ob_start();
        if(Plugin::$instance->db->is_built_with_elementor( $post_id )) {
            ?>
            <div class="ae_data elementor elementor-<?php echo esc_attr($post_id); ?>" data-aetid="<?php echo esc_attr($post_id); ?>">
                <?php echo Elementor\Plugin::instance()->frontend->get_builder_content( $post_id,$with_css ); ?>
            </div>
            <?php
        }else{
            echo   esc_html__('Not a valid elementor page','thepack');
        }
        $response = ob_get_contents();
        ob_end_clean();
        return $response;
    }


    public function thepack_apply_ae_single_post_template($content){
        $helper = new thepack_helper_theme();
        if(!is_single() && !is_page()){
            return $content;
        }
        $post_id = $GLOBALS['post']->ID;
        $ae_post_template = $helper->thepack_get_active_post_template($post_id,$GLOBALS['post']->post_type);
        if(isset($ae_post_template) && is_numeric($ae_post_template)){
            $template_content = $this->thepack_render_insert_tmpl($ae_post_template);
            echo $template_content;
        }

        return $content;
    }


    function thepack_search_builder(){
        $helper = new thepack_helper_theme();
        $tid = $helper->thepack_has_search_template();
        if($tid){
            echo $this->thepack_render_insert_tmpl($tid);
        }
    }

    function thepack_author_builder(){
        $helper = new thepack_helper_theme();
        $tid = $helper->thepack_has_author_template();
        if($tid){
            echo $this->thepack_render_insert_tmpl($tid);
        }
    }

    function thepack_apply_404_template(){
        $helper = new thepack_helper_theme();
        $tid = $helper->thepack_has_404_template();
        if($tid){
            echo $this->thepack_render_insert_tmpl($tid);
        }
    }

    function thepack_archive_builder(){
        $helper = new thepack_helper_theme();
        $tid = $helper->thepack_has_archive_template();
        if($tid){
            echo $this->thepack_render_insert_tmpl($tid);
        }
    }    


    /**
     * Remove hooks for post single page
     */
    public function thepack_ae_template_hook(){
        $helper = new thepack_helper_theme();
        $is_blog = $helper->is_blog();

        if( is_single() &&  'post' == get_post_type() ){
            $post = get_post();
            if(!$helper->thepack_get_active_post_template($post->ID,$post->post_type)){
                return false;
            }

            // Todo:: Move remove actions to separate file. Run only after theme detect.
            if(class_exists('thepack_themebuilderr\thepack_my_Theme')){
                $theme_obj = new thepack_my_Theme();
                $theme_obj->thepack_manage_actions();
            }

        }elseif(is_404()){
            $tid_404 = $helper->thepack_has_404_template();
            if($tid_404){
                if(class_exists('thepack_themebuilderr\thepack_my_Theme')){
                    $theme_obj = new thepack_my_Theme();
                    $theme_obj->thepack_manage_actions();
                }
            }
        }elseif(is_archive() && 'post' == get_post_type() && !is_author()){
            $tid = $helper->thepack_has_archive_template();
            if(!$tid ){
                return false;
            }
            if(class_exists('thepack_themebuilderr\thepack_my_Theme')){
                $theme_obj = new thepack_my_Theme();
                $theme_obj->thepack_manage_actions();
            }
        }elseif(is_author()){
            $tid_404 = $helper->thepack_has_author_template();
            //var_dump($tid_404);
            if($tid_404){
                if(class_exists('thepack_themebuilderr\thepack_my_Theme')){
                    $theme_obj = new thepack_my_Theme();
                    $theme_obj->thepack_manage_actions();
                }
            }
        }elseif(is_search()){
            $tid_404 = $helper->thepack_has_search_template();
            if($tid_404){
                if(class_exists('thepack_themebuilderr\thepack_my_Theme')){
                    $theme_obj = new thepack_my_Theme();
                    $theme_obj->thepack_manage_actions();
                }
            }
        } elseif($is_blog){
            $template_id = $helper->thepack_has_posts_page_template();
            if(!$template_id){
                return false;
            }
            // is blog - force load archive template
            if(class_exists('thepack_themebuilderr\thepack_my_Theme')){
                // get override mode

                $theme_obj = new thepack_my_Theme();
                $theme_obj->thepack_manage_actions();
            }
        }

    }

}

thepack_themebuilder_frontend::instance();


class thepack_helper_theme{

    function thepack_has_404_template(){
        $args = array(
            'post_type' => 'elementor_library',
        );

        $templates = new WP_Query($args);

        if($templates->found_posts){
            $templates->the_post();
            $ae_tid = cs_get_option('error_tpl','',TBOPT);
            wp_reset_postdata();
            return $ae_tid;
        }else{
            return false;
        }
    }

    function thepack_has_search_template(){
        $args = array(
            'post_type' => 'elementor_library',
        );

        $templates = new WP_Query($args);
        if($templates->found_posts){
            $templates->the_post();
            $ae_tid = cs_get_option('search_tpl','',TBOPT);
            wp_reset_postdata();
            return $ae_tid;
        }else{
            return false;
        }
    }


    function thepack_has_author_template(){
        $args = array(
            'post_type' => 'elementor_library',
        );

        $templates = new WP_Query($args);
        if($templates->found_posts){
            $templates->the_post();
            $ae_tid = cs_get_option('author_tpl','',TBOPT);
            wp_reset_postdata();
            return $ae_tid;
        }else{
            return false;
        }
    }


    function thepack_has_posts_page_template(){
        $args = array(
            'post_type' => 'elementor_library',
        );

        $templates = new WP_Query($args);
        if($templates->found_posts){
            $templates->the_post();
            $ae_tid = cs_get_option('single_tpl','',TBOPT);
            wp_reset_postdata();
            return $ae_tid;
        }else{
            return false;
        }
    }


    function thepack_has_archive_template(){
        $args = array(
            'post_type' => 'elementor_library',
        );

        $templates = new WP_Query($args);
        if($templates->found_posts){
            $templates->the_post();
            $term = get_category( get_query_var( 'cat' ) );
            $term_data = get_term_meta( $term->term_id, '_custom_taxonomy_options', true );
            $ae_tid = cs_get_option('archive_tpl','',TBOPT); 
            if ($term_data){
                $ae_cat = $term_data["cat_tpl"];
            }
            $copy = $ae_cat ? $ae_cat :$ae_tid;
            wp_reset_postdata();
           
            return $copy;

        }else{
            return false;
        }
    }

    function thepack_get_demo_post_data()
    {
        $post_data = array();
        $preview_post_ID = '';
        if($GLOBALS['post']->post_type == 'ae_global_templates'){
            $ae_post_ID = $GLOBALS['post']->ID;
            $preview_post_ID = get_post_meta($ae_post_ID,'ae_preview_post_ID',true);
            if ($preview_post_ID != '' && $preview_post_ID != 0):
                $post_data = get_post($preview_post_ID);
            else:
                $args = array(
                    'post_type' => 'post',
                    'post_status' => 'publish',
                    'posts_per_page' => 1
                );
                $demo_data = get_posts( $args );
                $post_data = $demo_data[0];
            endif;
        }else{
            $post_data = $GLOBALS['post'];
        }

        return $post_data;
    }

    function thepack_get_active_post_template($post_id,$post_type){
        global $wp_query; 
        $postid = $wp_query->post->ID;
        $layout = get_post_meta($postid, 'tb_pagemeta', 'false');
        $meta = $layout ? $layout['post_template'] : '';
        $tpl = cs_get_option('single_tpl','',TBOPT);
        if(!isset($meta) || empty($meta)){
            $args = array(
                'post_type' => 'elementor_library',
            );
            $templates = new WP_Query($args);
            if($templates->found_posts){
                $templates->the_post();
                $ae_tid = $tpl;
            }else{
                return false;
            }
            wp_reset_postdata();
 
        }else{

            $ae_tid = $meta;
        }
        return $ae_tid;
    }


    function is_blog(){
        if ( is_front_page() && is_home() ) {
            return true;
        } elseif ( is_front_page() ) {
            return false;
        } elseif ( is_home() ) {
            return true;
        } else {
            return false;
        }
    }

    function limit_title_length_thm($title,$words){
        if( $words > 10 ){
            return mb_strimwidth($title, 0, $words, '..');
        } else {
            return $title;
        }
    }
    function thepack_get_previous_post_id( $post_id ) {
        global $post;
        $oldGlobal = $post;
        $post = get_post( $post_id );
        $previous_post = get_previous_post();
        $post = $oldGlobal;
        if ( '' == $previous_post )
            return false;
        return $previous_post->ID;
    }

    function thepack_get_next_post_id( $post_id ) {

        global $post;
        $oldGlobal = $post;
        $post = get_post( $post_id );
        $next_post = get_next_post();
        $post = $oldGlobal;
        if ( '' == $next_post )
            return false;
        return $next_post->ID;
    }


    function thepack_archive_title()
    {
        if ( is_category() ) {
            $title = single_cat_title( _x( 'Category: ', 'thepack' ),false);
        } elseif ( is_tag() ) {
            $title = single_tag_title( 'Tag: ', false );
        } elseif ( is_author() ) {
            $title = sprintf(   esc_html__( 'Author: %s', 'kausik' ), '<span>' . get_the_author() . '</span>' );
            // we can use $title = get_the_author( 'Author: ', true );
        } elseif ( is_year() ) {
            $title = get_the_date( _x( 'Year: ', 'yearly archives date format' ),false );
        } elseif ( is_month() ) {
            $title = get_the_date( _x( 'F Y', 'monthly archives date format' ) );
        } elseif ( is_404() ) {
            $title = 'Page not found!';
        } elseif ( is_tax( 'post_format' ) ) {
            if ( is_tax( 'post_format', 'post-format-aside' ) ) {
                $title =   esc_html__( 'Asides', 'post format archive title' );
            } elseif ( is_tax( 'post_format', 'post-format-gallery' ) ) {
                $title =   esc_html__( 'Galleries', 'post format archive title' );
            } elseif ( is_tax( 'post_format', 'post-format-image' ) ) {
                $title =   esc_html__( 'Images', 'post format archive title' );
            } elseif ( is_tax( 'post_format', 'post-format-video' ) ) {
                $title =   esc_html__( 'Videos', 'post format archive title' );
            } elseif ( is_tax( 'post_format', 'post-format-quote' ) ) {
                $title =   esc_html__( 'Quotes', 'post format archive title' );
            } elseif ( is_tax( 'post_format', 'post-format-link' ) ) {
                $title =   esc_html__( 'Links', 'post format archive title' );
            } elseif ( is_tax( 'post_format', 'post-format-status' ) ) {
                $title =   esc_html__( 'Statuses', 'post format archive title' );
            } elseif ( is_tax( 'post_format', 'post-format-audio' ) ) {
                $title =   esc_html__( 'Audio', 'post format archive title' );
            } elseif ( is_tax( 'post_format', 'post-format-chat' ) ) {
                $title =   esc_html__( 'Chats', 'post format archive title' );
            }
        } elseif ( is_post_type_archive() ) {
            $title = post_type_archive_title( '', false );
        } elseif ( is_tax() ) {
            $tax = get_taxonomy( get_queried_object()->taxonomy );
            $title = single_term_title( '', false ) ;
        } elseif (is_search()){
            $title = sprintf(   esc_html__( 'Search Results for: %s', 'kausik' ), '<span>' . get_search_query() . '</span>' );
        } else {
            $title =   esc_html__( 'Archives' );
        }

        return '<h3>'.$title.'</h3>';
    }

    function thepaack_drop_taxolist(){

        $args = array(
          'public'   => true,
          '_builtin' => false
          
        ); 
        $output = 'names'; 
        $operator = 'or'; 

        $taxonomies = get_taxonomies( $args, $output, $operator ); 
        return $taxonomies;

    }


    function thepack_image_size_choose() {
      $image_sizes = get_intermediate_image_sizes(); 

        $addsizes = array(
            "full" => 'Full size'
        );
        $newsizes = array_merge($image_sizes, $addsizes);

      return array_combine($newsizes, $newsizes);
    }

    function thepack_drop_cat($tax) {

            $categories_obj = get_categories('taxonomy='.$tax.'');
            $categories = array();

            foreach ($categories_obj as $pn_cat) {
                $categories[$pn_cat->cat_ID] = $pn_cat->cat_name;
            }
            return $categories;         
    }

    function thepack_drop_posts($post_type){
        $args = array(
          'numberposts' => -1,
          'post_type'   => $post_type
        );

        $posts = get_posts( $args );        
        $list = array();
        foreach ($posts as $cpost){

            $list[$cpost->ID] = $cpost->post_title;
        }
        return $list;
    }

    function thepack_get_metas(){
        $date_format = array( 
        'tag' =>   esc_html__('Tag', 'thepack') ,
        'cat' =>   esc_html__('Category color', 'thepack') ,
        'title' =>   esc_html__('Post title & permalink', 'thepack') ,
        'title_nolink' =>   esc_html__('Post title no permalink', 'thepack') ,
        'title_single' =>   esc_html__('Single post title', 'thepack') ,
        'time' =>   esc_html__('Date', 'thepack') ,
        'share' =>   esc_html__('Share button', 'thepack') ,
        'view' =>   esc_html__('Post views', 'thepack') ,
        'excerpt' =>   esc_html__('Excerpt', 'thepack') ,
        'space' =>   esc_html__('Space with separator', 'thepack') ,
        'space10' =>   esc_html__('Space 10px', 'thepack') ,
        'clear' =>   esc_html__('Clear section', 'thepack') ,
        'space_blank' =>   esc_html__('Space', 'thepack') ,
        'btn' =>   esc_html__('Readmore Button', 'thepack') ,
        'author' =>   esc_html__('Author', 'thepack') ,
        'author_img' =>   esc_html__('Author Image', 'thepack') ,
        'comment' =>   esc_html__('Comment No', 'thepack') ,
        );
        return $date_format;
    }

function thepack_buildermeta_to_string($items) {
    if (!is_array($items)){
        return;
    }
     foreach( $items as $item ){
        $metaf[] =$item['meta'];
      }
      return implode(',' , $metaf);
}


/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function thepack_theme_posted_on() {
    
    $time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

    $time_string = sprintf( $time_string,
        esc_attr( get_the_date( 'c' ) ),
        esc_html( get_the_date() )
    );

    $posted_on = sprintf(
        _x( '%s', 'post date', 'thepack' ),
         $time_string
    );


    return '<span class="magnews-posted-on leffect-1">'.$posted_on.'</span>';
}


function thepack_theme_comment(){
    if ( ! post_password_required() ) {
        
        $num_comments = get_comments_number();

        if ( comments_open() ) {
            if ( $num_comments == 0 ) {
                $comments =   esc_html__('0 Comment', 'thepack');
            } elseif ( $num_comments > 1 ) {
                $comments = $num_comments .   esc_html__('Comments', 'thepack');
            } else {
                $comments =   esc_html__('1 Comment','thepack');
            }
            $write_comments = '<a href="'.get_comments_link().'">'.$comments.'</a>';
            
        } else {
            $write_comments =    esc_html__('off', 'thepack');
        }
        return '<span class="post-comment leffect-1">'.$write_comments.'</span>';
    }   
}

function thepack_theme_author(){

        return'<span class="post-meta-author">
            <span class="meta-author-name leffect-1">'.get_the_author_posts_link().'</span>
        </span>';
}
function thepack_theme_author_img(){

        return'<span class="post-info-author">
            '.get_avatar( get_the_author_meta( 'ID' ), 50 ).'<span class="inner-info-author leffect-1">'.get_the_author_posts_link().'</span>
        </span>';
}


function thepack_theme_post_title(){
        global $post;
        $id = $post->ID;
        return'<h3 class="post-title-builder"><a href="'.get_the_permalink($id).'">'.get_the_title($id).'</a></h3>';
}

function thepack_theme_readmore_btn(){
        global $post;
        $id = $post->ID;
        return'<a class="btn-more" href="'.get_the_permalink($id).'">'.  esc_html__('READ ON','thepack').'</a>';
}

function thepack_theme_space10_spacer(){

    $out='<span class="meta-space ten"></span>';
    return $out;

}



function thepack_theme_post_title_nolink(){
        global $post;
        $id= $post->ID;
        return'<h3 class="post-title-builder">'.get_the_title($id).'</h3>';
}


/*Space*/

function thepack_theme_post_spacer(){
    $out='<div class="meta-space-height" style=" height: 15px;"></div>';
    return $out;
}

/*Space*/

function thepack_theme_space_meta(){
    $out='<span class="meta-space leffect-1"> - </span>';
    return $out;
}

function thepack_theme_clearifix(){
    $out='<div class="meta-clearing"></div>';
    return $out;
}


/**
 * Display category based on theme options 
 */
 

        function thepack_theme_single_category($default = true) {
                            
            if ( 'post' == get_post_type() ) {
                $categories = get_the_category();
                if($default==true){
                    $separator = ', ';
                }else {
                    $separator = ', ';              
                }
                
                $output = '';
                if($categories){
                    foreach($categories as $category) {

                        $output .= '<a class="cat-links" href="'.get_category_link( $category->term_id ).'">'.$category->cat_name.'</a>'.$separator;

                    }
                $cat= trim($output, $separator);
                return '<span class="post-cat leffect-1">'.$cat.'</span>';
                }
            }

}

/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function thepack_theme_post_tag() {
    
    if ( 'post' == get_post_type() ) {
        
    $posttags = get_the_tags();
    $separator = ' ';
    $output = '';
    if ($posttags) {

        foreach($posttags as $tag) {
            $output .='<span><a href="' . get_tag_link($tag->term_id) . '">' . $tag->name . '</a></span>'.$separator; 
        }

        $tags= trim($output, $separator);
        return '<span class="tags-links leffect-1">'.$output.'</span>';
    }
    }
}



//Custom excerpt 

function thepack_theme_excerpt_shortcode($limit) {
    if($limit > "0"){
    global $post;
    $id = $post->ID;
    $outpu = wp_trim_words(get_the_content(), $limit,'');
    
        return '<p class="post-entry">'.$outpu.'</p>';
    
    }
    
}

/**
 * Display post tag,category,date,author 
 */


function thepack_theme_build_postmeta($metas = '',$excerpt_length = ''){


        if ( !is_array($metas) ) {
            $metas = explode(',' , $metas); 
        }


        if ( is_array($metas) ) {
                 $outz='';
            foreach( $metas as $meta ) {

                    $out = '';

                    switch ( $meta ) {

                    case 'tag':
                        $out = $this->thepack_theme_post_tag() ;
                        break;

                    case 'cat':
                        $out = $this->thepack_theme_single_category(false);
                        break;

                    case 'time':
                        $out = $this->thepack_theme_posted_on() ;
                        break;  

                    case 'title':
                        $out = $this->thepack_theme_post_title() ;
                        break;

                    case 'space_blank':
                        $out = $this->thepack_theme_post_spacer() ;
                        break;

                    case 'space10':
                        $out = $this->thepack_theme_space10_spacer() ;
                        break;

                        
                    case 'clear':
                        $out = $this->thepack_theme_clearifix() ;
                        break;

                    case 'btn':
                        $out = $this->thepack_theme_readmore_btn() ;
                        break;

                    case 'share':
                        $out = $this->magnews_share_post() ;
                        break;

                    case 'space':
                        $out = $this->thepack_theme_space_meta() ;
                        break;


                    case 'title_nolink':
                        $out = $this->thepack_theme_post_title_nolink() ;
                        break;  

                    case 'author':
                        $out = $this->thepack_theme_author();
                        break;

                    case 'author_img':
                        $out = $this->thepack_theme_author_img();
                        break;

                    case 'comment':
                        $out = $this->thepack_theme_comment() ;
                        break;

                    case 'excerpt':
                        $out = $this->thepack_theme_excerpt_shortcode($excerpt_length);
                        break;

                    }

                if ( !empty( $meta ) ) {
                    $outz .= $out;
                }       

                }   
            return '<div class="meta-wrap">'.$outz.'</div>';   

            }   

}


}


class thepack_backend_meta_preview{

/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function thepack_theme_posted_on() {
    
    $time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

    $time_string = sprintf( $time_string,
        esc_attr( get_the_date( 'c' ) ),
        esc_html( get_the_date() )
    );

    $posted_on = sprintf(
        _x( '%s', 'post date', 'thepack' ),
         $time_string
    );


    return '<span class="magnews-posted-on leffect-1">'.$posted_on.'</span>';
}


function thepack_theme_comment(){
    if ( ! post_password_required() ) {
        
        $num_comments = get_comments_number();

        if ( comments_open() ) {
            if ( $num_comments == 0 ) {
                $comments =   esc_html__('0 Comment', 'thepack');
            } elseif ( $num_comments > 1 ) {
                $comments = $num_comments .   esc_html__('Comments', 'thepack');
            } else {
                $comments =   esc_html__('1 Comment','thepack');
            }
            $write_comments = '<a href="'.get_comments_link().'">'.$comments.'</a>';
            
        } else {
            $write_comments =    esc_html__('off', 'thepack');
        }
        return '<span class="post-comment leffect-1">'.$write_comments.'</span>';
    }   
}

function thepack_theme_author(){

        return'<span class="post-meta-author">
            <span class="meta-author-name leffect-1">'.get_the_author_posts_link().'</span>
        </span>';
}
function thepack_theme_author_img(){

        return'<span class="post-info-author">
            '.get_avatar( get_the_author_meta( 'ID' ), 50 ).'<span class="inner-info-author leffect-1">'.get_the_author_posts_link().'</span>
        </span>';
}


function theme_catbg_color(){

        return'<span class="catbg-wrap"><a class="cat-bg" href="#">Food</a></span>';
}


function thepack_theme_post_title(){
        global $post;
        $id = $post->ID;
        return'<h3 class="post-title-builder"><a href="'.get_the_permalink($id).'">'.get_the_title($id).'</a></h3>';
}

function thepack_theme_readmore_btn(){
        global $post;
        $id = $post->ID;
        return'<a class="btn-more" href="'.get_the_permalink($id).'">'.  esc_html__('READ ON','wb').'</a>';
}


function thepack_theme_post_title_nolink(){
        global $post;
        $id= $post->ID;
        return'<h3 class="post-title-builder">'.get_the_title($id).'</h3>';
}


/*Space*/

function thepack_theme_post_spacer(){
    $out='<div class="meta-space-height" style=" height: 15px;"></div>';
    return $out;
}

/*Space*/

function thepack_theme_space_meta(){
    $out='<span class="meta-space leffect-1"> - </span>';
    return $out;
}

function thepack_theme_clearifix(){
    $out='<div class="meta-clearing"></div>';
    return $out;
}


/**
 * Display category based on theme options 
 */
 

        function thepack_theme_single_category() {
                            
           return '<span class="post-cat leffect-1"><a class="cat-links" href="#">Travel</a></span>';

}

/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function thepack_theme_post_tag() {
    return '<span class="tags-links leffect-1"><span><a href="#">Comic</a></span> <span><a href="#">Illustration</a></span> <span><a href="#">Sweet</a></span> </span>';
} 

function thepack_theme_excerpt_shortcode($limit) {
    if($limit > "0"){
    global $post;
    $id = $post->ID;
    $outpu = wp_trim_words(get_the_content(), $limit,'');
    
        return '<p class="post-entry">'.$outpu.'</p>';
    
    }
    
}

/**
 * Display post tag,category,date,author 
 */


function thepack_backendmetapreview($metas = '',$excerpt_length = ''){


        if ( !is_array($metas) ) {
            $metas = explode(',' , $metas); 
        }


        if ( is_array($metas) ) {
                 $outz='';
            foreach( $metas as $meta ) {

                    $out = '';

                    switch ( $meta ) {

                    case 'tag':
                        $out = $this->thepack_theme_post_tag() ;
                        break;

                    case 'cat':
                        $out = $this->thepack_theme_single_category(false);
                        break;

                    case 'cat_bg':
                        $out = $this->theme_catbg_color();
                        break;

                    case 'time':
                        $out = $this->thepack_theme_posted_on() ;
                        break;  

                    case 'title':
                        $out = $this->thepack_theme_post_title() ;
                        break;

                    case 'space_blank':
                        $out = $this->thepack_theme_post_spacer() ;
                        break;

                    case 'clear':
                        $out = $this->thepack_theme_clearifix() ;
                        break;

                    case 'btn':
                        $out = $this->thepack_theme_readmore_btn() ;
                        break;

                    case 'share':
                        $out = $this->magnews_share_post() ;
                        break;

                    case 'space':
                        $out = $this->thepack_theme_space_meta() ;
                        break;


                    case 'title_nolink':
                        $out = $this->thepack_theme_post_title_nolink() ;
                        break;  

                    case 'author':
                        $out = $this->thepack_theme_author();
                        break;

                    case 'author_img':
                        $out = $this->thepack_theme_author_img();
                        break;

                    case 'comment':
                        $out = $this->thepack_theme_comment() ;
                        break;

                    case 'excerpt':
                        $out = $this->thepack_theme_excerpt_shortcode($excerpt_length);
                        break;

                    }

                if ( !empty( $meta ) ) {
                    $outz .= $out;
                }       

                }   
            return '<div class="meta-wrap">'.$outz.'</div>'; 

            }   

}

}
